@@ -10,7 +10,7 @@
 /* define if extended WM hints are enabled */
 #undef HAVE_EWMH
 
-/* Where to search for images.  */
+/* Where to search for images.	*/
 #undef FVWM_IMAGEPATH
 
 /* Define if Xpm library is used.  */
@@ -20,7 +20,7 @@
 #undef HAVE_PNG
 
 /* Define if your processor stores words with the most significant
-   byte first (like Motorola and SPARC, unlike Intel and VAX).  */
+   byte first (like Motorola and SPARC, unlike Intel and VAX).	*/
 #undef WORDS_BIGENDIAN
 
 /* Define if rplay library is used.  */
@@ -38,6 +38,9 @@
 /* Define if Xft library is used. */
 #undef HAVE_XFT
 
+/* Define if Xft 2 library is used. */
+#undef HAVE_XFT2
+
 /* Define if Xft library can handle utf8 encoding  */
 #undef HAVE_XFT_UTF8
 
@@ -67,7 +70,7 @@
 
 #ifdef USE_LIBICONV
 /* define to use locale_charset in the place of nl_langinfog if libiconv
- * is used */ 
+ * is used */
 #undef HAVE_LIBCHARSET
 #endif
 
@@ -88,7 +91,7 @@
  * don't normally use a shaped window, you have to decide for yourself.
  *
  * Note: if it is compiled in, run time detection is used to make sure that
- * the currently running X server supports it.  */
+ * the currently running X server supports it.	*/
 #undef SHAPE
 
 /* Define if fribidi library is used.  */
@@ -97,7 +100,7 @@
 /* Enables the "MiniIcon" Style option to specify a small pixmap which
  * can be used as one of the title-bar buttons, shown in window list,
  * utilized by modules, etc.  Requires PIXMAP_BUTTONS to be defined
- * (see below).  */
+ * (see below).	 */
 /* #undef MINI_ICONS */
 /* NOTE: hard coded to 1 */
 #if 1
@@ -121,12 +124,6 @@
 /* Enables session management functionality. */
 #undef SESSION
 
-/* Enables X11 multibyte character support (was I18N_MB) */
-#undef MULTIBYTE
-
-/* Enables compund text */
-#undef COMPOUND_TEXT
-
 /* Enables to use setlocale() provided by X */
 #undef X_LOCALE
 
@@ -198,7 +195,7 @@
 /* Define if the X11 ConnectionNumber is actually a file descriptor. */
 #define HAVE_X11_FD 1
 
-/* Define if fork() has unix semantics.  On VMS, no child process is created
+/* Define if fork() has unix semantics.	 On VMS, no child process is created
    until after a successful exec(). */
 #define FORK_CREATES_CHILD 1
 
@@ -228,7 +225,7 @@
        #pragma alloca
 #  else
 #    ifndef alloca /* predefined by HP cc +Olibcalls */
-         char *alloca ();
+	 char *alloca ();
 #    endif
 #  endif
 #endif
