@@ -6,42 +6,42 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 /****************************************************************************
  * This module is based on Twm, but has been siginificantly modified
  * by Rob Nation
  ****************************************************************************/
 /*****************************************************************************/
-/**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
-/**                          Salt Lake City, Utah                           **/
+/**	  Copyright 1988 by Evans & Sutherland Computer Corporation,	    **/
+/**			     Salt Lake City, Utah			    **/
 /**  Portions Copyright 1989 by the Massachusetts Institute of Technology   **/
-/**                        Cambridge, Massachusetts                         **/
-/**                                                                         **/
-/**                           All Rights Reserved                           **/
-/**                                                                         **/
+/**			   Cambridge, Massachusetts			    **/
+/**									    **/
+/**			      All Rights Reserved			    **/
+/**									    **/
 /**    Permission to use, copy, modify, and distribute this software and    **/
 /**    its documentation  for  any  purpose  and  without  fee is hereby    **/
-/**    granted, provided that the above copyright notice appear  in  all    **/
-/**    copies and that both  that  copyright  notice  and  this  permis-    **/
+/**    granted, provided that the above copyright notice appear	 in  all    **/
+/**    copies and that both  that  copyright  notice  and  this	 permis-    **/
 /**    sion  notice appear in supporting  documentation,  and  that  the    **/
 /**    names of Evans & Sutherland and M.I.T. not be used in advertising    **/
-/**    in publicity pertaining to distribution of the  software  without    **/
-/**    specific, written prior permission.                                  **/
-/**                                                                         **/
+/**    in publicity pertaining to distribution of the  software	 without    **/
+/**    specific, written prior permission.				    **/
+/**									    **/
 /**    EVANS & SUTHERLAND AND M.I.T. DISCLAIM ALL WARRANTIES WITH REGARD    **/
 /**    TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES  OF  MERCHANT-    **/
-/**    ABILITY  AND  FITNESS,  IN  NO  EVENT SHALL EVANS & SUTHERLAND OR    **/
+/**    ABILITY	AND  FITNESS,  IN  NO  EVENT SHALL EVANS & SUTHERLAND OR    **/
 /**    M.I.T. BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL  DAM-    **/
-/**    AGES OR  ANY DAMAGES WHATSOEVER  RESULTING FROM LOSS OF USE, DATA    **/
+/**    AGES OR	ANY DAMAGES WHATSOEVER	RESULTING FROM LOSS OF USE, DATA    **/
 /**    OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER    **/
-/**    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH  THE  USE    **/
-/**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
+/**    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH	THE  USE    **/
+/**    OR PERFORMANCE OF THIS SOFTWARE.					    **/
 /*****************************************************************************/
 
 /* ---------------------------- included header files ----------------------- */
@@ -108,8 +108,8 @@ char NoResource[] = "NoResource"; /* Class if no res_name in class hints */
 /***********************************************************************
  *
  *  Procedure:
- *      CaptureOneWindow
- *      CaptureAllWindows
+ *	CaptureOneWindow
+ *	CaptureAllWindows
  *
  *   Decorates windows at start-up and during recaptures
  *
@@ -140,7 +140,7 @@ static void CaptureOneWindow(
 	 * recapture. */
 	MyXGrabServer(dpy);
 	if (!XGetGeometry(dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY, &JunkWidth,
-			  &JunkHeight, &JunkBW,  &JunkDepth))
+			  &JunkHeight, &JunkBW,	 &JunkDepth))
 	{
 		/* The window has already died, do not recapture it! */
 		MyXUngrabServer(dpy);
@@ -240,7 +240,7 @@ static void hide_screen(
 		hide_win = XCreateWindow(
 			dpy, Scr.Root, 0, 0, Scr.MyDisplayWidth,
 			Scr.MyDisplayHeight, 0, Pdepth, InputOutput,
-		        Pvisual, valuemask, &xswa);
+			Pvisual, valuemask, &xswa);
 		if (hide_win)
 		{
 			/* When recapturing, all windows are reparented to this
@@ -309,7 +309,7 @@ static int MappedNotOverride(
 	Window w, initial_window_options_type *win_opts)
 {
 	XWindowAttributes wa;
-        Atom atype;
+	Atom atype;
 	int aformat;
 	unsigned long nitems, bytes_remain;
 	unsigned char *prop;
@@ -405,6 +405,8 @@ static Bool setup_window_structure(
 	{
 		(*pfw)->Desk = savewin->Desk;
 		SET_SHADED(*pfw, IS_SHADED(savewin));
+		SET_USED_TITLE_DIR_FOR_SHADING(
+			*pfw, USED_TITLE_DIR_FOR_SHADING(savewin));
 		SET_SHADED_DIR(*pfw, SHADED_DIR(savewin));
 		SET_PLACED_WB3(*pfw,IS_PLACED_WB3(savewin));
 		SET_PLACED_BY_FVWM(*pfw, IS_PLACED_BY_FVWM(savewin));
@@ -430,16 +432,16 @@ static Bool setup_window_structure(
 			*pfw, HAS_EWMH_INIT_SHADED_STATE(savewin));
 		SET_HAS_EWMH_INIT_STICKY_STATE(
 			*pfw, HAS_EWMH_INIT_STICKY_STATE(savewin));
-                CLEAR_USER_STATES(*pfw, ~0);
-                SET_USER_STATES(*pfw, GET_USER_STATES(savewin));
+		CLEAR_USER_STATES(*pfw, ~0);
+		SET_USER_STATES(*pfw, GET_USER_STATES(savewin));
 	}
 
 	(*pfw)->cmap_windows = (Window *)NULL;
-        if (FMiniIconsSupported)
-        {
-        	(*pfw)->mini_pixmap_file = NULL;
-                (*pfw)->mini_icon = NULL;
-        }
+	if (FMiniIconsSupported)
+	{
+		(*pfw)->mini_pixmap_file = NULL;
+		(*pfw)->mini_icon = NULL;
+	}
 
 	return True;
 }
@@ -556,6 +558,8 @@ static void setup_window_attr(
 	fw->attr_backup.backing_store = ret_attr->backing_store;
 	fw->attr_backup.border_width = ret_attr->border_width;
 	fw->attr_backup.depth = ret_attr->depth;
+	fw->attr_backup.bit_gravity = ret_attr->bit_gravity;
+	fw->attr_backup.is_bit_gravity_stored = 0;
 	fw->attr_backup.visual = ret_attr->visual;
 	fw->attr_backup.colormap = ret_attr->colormap;
 
@@ -613,16 +617,24 @@ static void adjust_fvwm_internal_windows(FvwmWindow *fw)
 	{
 		Scr.StolenFocusWin = None;
 	}
+	if (Scr.focus_in_pending_window == fw)
+	{
+		Scr.focus_in_pending_window = NULL;
+	}
+	if (Scr.cascade_window == fw)
+	{
+		Scr.cascade_window = NULL;
+	}
 
 	return;
 }
 
 static void broadcast_mini_icon(FvwmWindow *fw)
 {
-        if (!FMiniIconsSupported)
-        {
-                return;
-        }
+	if (!FMiniIconsSupported)
+	{
+		return;
+	}
 	if (fw->mini_pixmap_file && fw->mini_icon)
 	{
 		BroadcastFvwmPicture(
@@ -636,10 +648,10 @@ static void broadcast_mini_icon(FvwmWindow *fw)
 
 static void setup_mini_icon(FvwmWindow *fw, window_style *pstyle)
 {
-        if (!FMiniIconsSupported)
-        {
-                return;
-        }
+	if (!FMiniIconsSupported)
+	{
+		return;
+	}
 	if (SHAS_MINI_ICON(&pstyle->flags))
 	{
 		fw->mini_pixmap_file = SGET_MINI_ICON_NAME(*pstyle);
@@ -899,11 +911,6 @@ void setup_style_and_decor(
 		}
 	}
 
-	/*  Assume that we'll decorate */
-	SET_HAS_BORDER(fw, 1);
-	SET_HAS_HANDLES(fw, 1);
-	SET_HAS_TITLE(fw, 1);
-
 #ifdef USEDECOR
 	/* search for a UseDecor tag in the style */
 	if (!IS_DECOR_CHANGED(fw))
@@ -942,7 +949,7 @@ void setup_style_and_decor(
 		if (fw->wShaped)
 		{
 			set_window_border_size(fw, 0);
-			SET_HAS_BORDER(fw, 0);
+			SET_HAS_NO_BORDER(fw, 1);
 			SET_HAS_HANDLES(fw, 0);
 		}
 	}
@@ -1260,7 +1267,7 @@ void setup_title_window(
 
 	FW_W_TITLE(fw) = XCreateWindow(
 		dpy, FW_W_FRAME(fw), 0, 0, 1, 1, 0, Pdepth, InputOutput,
-                Pvisual, valuemask, pattributes);
+		Pvisual, valuemask, pattributes);
 	XSaveContext(dpy, FW_W_TITLE(fw), FvwmContext, (caddr_t) fw);
 
 	return;
@@ -1407,7 +1414,7 @@ void setup_resize_handle_cursors(FvwmWindow *fw)
 	XSetWindowAttributes attributes;
 	int i;
 
-	if (!HAS_BORDER(fw))
+	if (HAS_NO_BORDER(fw))
 	{
 		return;
 	}
@@ -1451,7 +1458,7 @@ void setup_resize_handle_windows(FvwmWindow *fw)
 		NorthWestGravity
 	};
 
-	if (!HAS_BORDER(fw))
+	if (HAS_NO_BORDER(fw))
 	{
 		return;
 	}
@@ -1469,13 +1476,13 @@ void setup_resize_handle_windows(FvwmWindow *fw)
 		attributes.win_gravity = c_grav[i];
 		FW_W_CORNER(fw, i) = XCreateWindow(
 			dpy, FW_W_FRAME(fw), -1, -1, 1, 1, 0, Pdepth,
-                        InputOutput, Pvisual, valuemask, &attributes);
+			InputOutput, Pvisual, valuemask, &attributes);
 		XSaveContext(
 			dpy, FW_W_CORNER(fw, i), FvwmContext, (caddr_t)fw);
 		attributes.win_gravity = s_grav[i];
 		FW_W_SIDE(fw, i) = XCreateWindow(
 			dpy, FW_W_FRAME(fw), -1, -1, 1, 1, 0, Pdepth,
-                        InputOutput, Pvisual, valuemask, &attributes);
+			InputOutput, Pvisual, valuemask, &attributes);
 		XSaveContext(dpy, FW_W_SIDE(fw, i), FvwmContext, (caddr_t)fw);
 	}
 	setup_resize_handle_cursors(fw);
@@ -1506,11 +1513,11 @@ void destroy_resize_handle_windows(
 
 void change_resize_handle_windows(FvwmWindow *fw)
 {
-	if (HAS_BORDER(fw) && FW_W_SIDE(fw, 0) == None)
+	if (!HAS_NO_BORDER(fw) && FW_W_SIDE(fw, 0) == None)
 	{
 		setup_resize_handle_windows(fw);
 	}
-	else if (!HAS_BORDER(fw) && FW_W_SIDE(fw, 0) != None)
+	else if (HAS_NO_BORDER(fw) && FW_W_SIDE(fw, 0) != None)
 	{
 		destroy_resize_handle_windows(fw, False);
 	}
@@ -1695,7 +1702,7 @@ void destroy_auxiliary_windows(
 	{
 		destroy_button_windows(fw, True);
 	}
-	if (HAS_BORDER(fw))
+	if (!HAS_NO_BORDER(fw))
 	{
 		destroy_resize_handle_windows(fw, True);
 	}
@@ -1752,13 +1759,13 @@ static void setup_icon(FvwmWindow *fw, window_style *pstyle)
 		    SICON_OVERRIDE(pstyle->flags) == ICON_OVERRIDE)
 		{
 			ICON_DBG((stderr,"si: iwh ignored '%s'\n",
-                                  fw->name.name));
+				  fw->name.name));
 			fw->icon_bitmap_file = SGET_ICON_NAME(*pstyle);
 		}
 		else
 		{
 			ICON_DBG((stderr,"si: using iwh '%s'\n",
-                                  fw->name.name));
+				  fw->name.name));
 			fw->icon_bitmap_file = NULL;
 		}
 	}
@@ -1768,13 +1775,13 @@ static void setup_icon(FvwmWindow *fw, window_style *pstyle)
 		    SICON_OVERRIDE(pstyle->flags) != NO_ICON_OVERRIDE)
 		{
 			ICON_DBG((stderr,"si: iph ignored '%s'\n",
-                                  fw->name.name));
+				  fw->name.name));
 			fw->icon_bitmap_file = SGET_ICON_NAME(*pstyle);
 		}
 		else
 		{
 			ICON_DBG((stderr,"si: using iph '%s'\n",
-                                  fw->name.name));
+				  fw->name.name));
 			fw->icon_bitmap_file = NULL;
 		}
 	}
@@ -1840,7 +1847,6 @@ static void destroy_icon(FvwmWindow *fw)
 			{
 				XFreePixmap(dpy, fw->icon_alphaPixmap);
 			}
-			
 		}
 		XDestroyWindow(dpy, FW_W_ICON_TITLE(fw));
 		XDeleteContext(dpy, FW_W_ICON_TITLE(fw), FvwmContext);
@@ -1960,14 +1966,11 @@ FvwmWindow *AddWindow(
 	/* used for faster access */
 	style_flags *sflags;
 	short buttons;
-	extern FvwmWindow *colormap_win;
-	int do_shade = 0;
-	int shade_dir = 0;
-	int do_maximize = 0;
 	Bool used_sm = False;
 	Bool do_resize_too = False;
 	size_borders b;
 	frame_move_resize_args mr_args;
+	mwtsm_state_args state_args;
 
 	/****** init window structure ******/
 	if (!setup_window_structure(&tmpfw, w, ReuseWin))
@@ -1988,7 +1991,7 @@ FvwmWindow *AddWindow(
 	}
 
 	/****** Make sure the client window still exists.  We don't want to
-	 * leave an orphan frame window if it doesn't.  Since we now have the
+	 * leave an orphan frame window if it doesn't.	Since we now have the
 	 * server grabbed, the window can't disappear later without having been
 	 * reparented, so we'll get a DestroyNotify for it.  We won't have
 	 * gotten one for anything up to here, however. ******/
@@ -2010,7 +2013,7 @@ FvwmWindow *AddWindow(
 
 	/****** basic style and decor ******/
 	/* If the window is in the NoTitle list, or is a transient, dont
-	 * decorate it.  If its a transient, and DecorateTransients was
+	 * decorate it.	 If its a transient, and DecorateTransients was
 	 * specified, decorate anyway. */
 	/* get merged styles */
 	lookup_style(fw, &style);
@@ -2041,7 +2044,7 @@ FvwmWindow *AddWindow(
 	/*
 	 * Reparenting generates an UnmapNotify event, followed by a MapNotify.
 	 * Set the map state to FALSE to prevent a transition back to
-	 * WithdrawnState in HandleUnmapNotify.  Map state gets set corrected
+	 * WithdrawnState in HandleUnmapNotify.	 Map state gets set corrected
 	 * again in HandleMapNotify.
 	 */
 	SET_MAPPED(fw, 0);
@@ -2080,8 +2083,8 @@ FvwmWindow *AddWindow(
 	 * stacking order initialization.
 	 */
 	get_window_borders(fw, &b);
-	used_sm = MatchWinToSM(
-		fw, &do_shade, &shade_dir, &do_maximize, win_opts);
+	memset(&state_args, 0, sizeof(state_args));
+	used_sm = MatchWinToSM(fw, &state_args, win_opts);
 	if (used_sm)
 	{
 		/* read the requested absolute geometry */
@@ -2102,7 +2105,7 @@ FvwmWindow *AddWindow(
 			(unsigned int *)&fw->frame_g.height, 0, 0, 0);
 
 		/****** maximize ******/
-		if (do_maximize)
+		if (state_args.do_max)
 		{
 			SET_MAXIMIZED(fw, 1);
 			constrain_size(
@@ -2122,8 +2125,10 @@ FvwmWindow *AddWindow(
 
 		if (IS_SHADED(fw))
 		{
-			do_shade = 1;
-			shade_dir = SHADED_DIR(fw);
+			state_args.do_shade = 1;
+			state_args.used_title_dir_for_shading =
+				USED_TITLE_DIR_FOR_SHADING(fw);
+			state_args.shade_dir = SHADED_DIR(fw);
 			SET_SHADED(fw, 0);
 		}
 		/* Tentative size estimate */
@@ -2190,10 +2195,10 @@ FvwmWindow *AddWindow(
 	MyXUngrabServer(dpy);
 
 	/* need to set up the mini icon before drawing */
-        if (FMiniIconsSupported)
-        {
-                setup_mini_icon(fw, &style);
-        }
+	if (FMiniIconsSupported)
+	{
+		setup_mini_icon(fw, &style);
+	}
 
 	/****** arrange the frame ******/
 
@@ -2211,8 +2216,6 @@ FvwmWindow *AddWindow(
 			fw, FRAME_MR_FORCE_SETUP, NULL, &fw->frame_g, 0,
 			DIR_NONE);
 	}
-	mr_args = frame_create_move_resize_args(
-		fw, FRAME_MR_FORCE_SETUP, NULL, &fw->frame_g, 0, DIR_NONE);
 	frame_move_resize(fw, mr_args);
 	frame_free_move_resize_args(fw, mr_args);
 
@@ -2239,10 +2242,10 @@ FvwmWindow *AddWindow(
 	/* migo (20-Jan-2000): the logic is to unset this flag on NULL values */
 	SET_WAS_ICON_NAME_PROVIDED(fw, 1);
 	setup_icon(fw, &style);
-        if (FMiniIconsSupported)
-        {
-                broadcast_mini_icon(fw);
-        }
+	if (FMiniIconsSupported)
+	{
+		broadcast_mini_icon(fw);
+	}
 	BroadcastName(M_RES_CLASS,FW_W(fw),FW_W_FRAME(fw),
 		      (unsigned long)fw,fw->class.res_class);
 	BroadcastName(M_RES_NAME,FW_W(fw),FW_W_FRAME(fw),
@@ -2262,7 +2265,7 @@ FvwmWindow *AddWindow(
 			SET_STICKY(fw, 0);
 			handle_stick(
 				NULL, &Event, FW_W_FRAME(fw), fw, C_FRAME, "",
-			        0, 1);
+				0, 1);
 		}
 	}
 
@@ -2285,7 +2288,7 @@ FvwmWindow *AddWindow(
 	}
 
 	/****** window colormap ******/
-	InstallWindowColormaps(colormap_win);
+	ReInstallActiveColormap();
 
 	/****** ewmh setup *******/
 	EWMH_WindowInit(fw);
@@ -2298,26 +2301,32 @@ FvwmWindow *AddWindow(
 	GNOME_SetWinArea(fw);
 
 	/****** windowshade ******/
-	if (do_shade)
+	if (state_args.do_shade)
 	{
 		rectangle big_g;
 		rectangle new_g;
 		frame_move_resize_args mr_args;
 
+		if (state_args.used_title_dir_for_shading)
+		{
+			state_args.shade_dir = GET_TITLE_DIR(fw);
+		}
 		big_g = (IS_MAXIMIZED(fw)) ? fw->max_g : fw->frame_g;
 		new_g = big_g;
-		get_shaded_geometry_with_dir(fw, &new_g, &new_g, shade_dir);
+		get_shaded_geometry_with_dir(
+			fw, &new_g, &new_g, state_args.shade_dir);
 		mr_args = frame_create_move_resize_args(
-			fw, FRAME_MR_SHRINK, &big_g, &new_g, 0, shade_dir);
+			fw, FRAME_MR_SHRINK, &big_g, &new_g, 0,
+			state_args.shade_dir);
 		frame_move_resize(fw, mr_args);
 		SET_SHADED(fw, 1);
-		SET_SHADED_DIR(fw, shade_dir);
+		SET_SHADED_DIR(fw, state_args.shade_dir);
 		frame_free_move_resize_args(fw, mr_args);
 	}
 	if (!XGetGeometry(dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY, &JunkWidth,
-			  &JunkHeight, &JunkBW,  &JunkDepth))
+			  &JunkHeight, &JunkBW,	 &JunkDepth))
 	{
-		/* The window has disappeared somehow.  For some reason we do
+		/* The window has disappeared somehow.	For some reason we do
 		 * not always get a DestroyNotify on the window, so make sure
 		 * it is destroyed. */
 		destroy_window(fw);
@@ -2605,13 +2614,13 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 		/*
 		** The math looks like this:
 		**
-		**   minAspectX    maxAspectX
+		**   minAspectX	   maxAspectX
 		**   ---------- <= ----------
-		**   minAspectY    maxAspectY
+		**   minAspectY	   maxAspectY
 		**
 		** If that is multiplied out, this must be satisfied:
 		**
-		**   minAspectX * maxAspectY <=  maxAspectX * minAspectY
+		**   minAspectX * maxAspectY <=	 maxAspectX * minAspectY
 		**
 		** So, what to do if this isn't met?  Ignoring it entirely
 		** seems safest.
@@ -2637,7 +2646,7 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 				WARN, "GetWindowSizeHints", "%s window %#lx"
 				" has broken aspect ratio: %d/%d - %d/%d\n",
 				tmp->name.name, FW_W(tmp), minAspectX,
-                                minAspectY, maxAspectX, maxAspectY);
+				minAspectY, maxAspectX, maxAspectY);
 		}
 		else
 		{
@@ -2869,8 +2878,8 @@ void destroy_window(FvwmWindow *fw)
 
 	/****** adjust fvwm internal windows II ******/
 
-	/* restore_focus_after_unmap takes care of Scr.pushed_window and
-	 * colormap_win */
+	/* restore_focus_after_unmap takes care of Scr.pushed_window and the
+	 * colormap window */
 	if (fw == Scr.Ungrabbed)
 	{
 		Scr.Ungrabbed = NULL;
