@@ -6,12 +6,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /****************************************************************************
@@ -171,38 +171,6 @@ static void add_to_env_list(char *var, char *env)
 	return;
 }
 
-static void refresh_window(Window w)
-{
-	XSetWindowAttributes attributes;
-	unsigned long valuemask;
-
-	valuemask = CWOverrideRedirect | CWBackingStore | CWSaveUnder |
-		CWBackPixmap;
-	attributes.override_redirect = True;
-	attributes.save_under = False;
-	attributes.background_pixmap = None;
-	attributes.backing_store = NotUseful;
-	w = XCreateWindow(dpy,
-			  w,
-			  0, 0,
-			  (unsigned int) Scr.MyDisplayWidth,
-			  (unsigned int) Scr.MyDisplayHeight,
-			  (unsigned int) 0,
-			  CopyFromParent, (unsigned int) CopyFromParent,
-			  CopyFromParent, valuemask,
-			  &attributes);
-	XMapWindow(dpy, w);
-	if (Scr.flags.do_need_window_update)
-	{
-		flush_window_updates();
-	}
-	XDestroyWindow(dpy, w);
-	XSync(dpy, 0);
-	handle_all_expose();
-
-	return;
-}
-
 /** Prepend rather than replace the image path.
     Used for obsolete PixmapPath and IconPath **/
 static void obsolete_imagepaths( const char* pre_path )
@@ -880,6 +848,38 @@ static void do_button_style(F_CMD_ARGS, Bool do_add)
 
 /* ---------------------------- interface functions ------------------------- */
 
+void refresh_window(Window w, Bool window_update)
+{
+	XSetWindowAttributes attributes;
+	unsigned long valuemask;
+
+	valuemask = CWOverrideRedirect | CWBackingStore | CWSaveUnder |
+		CWBackPixmap;
+	attributes.override_redirect = True;
+	attributes.save_under = False;
+	attributes.background_pixmap = None;
+	attributes.backing_store = NotUseful;
+	w = XCreateWindow(dpy,
+			  w,
+			  0, 0,
+			  (unsigned int) Scr.MyDisplayWidth,
+			  (unsigned int) Scr.MyDisplayHeight,
+			  (unsigned int) 0,
+			  CopyFromParent, (unsigned int) CopyFromParent,
+			  CopyFromParent, valuemask,
+			  &attributes);
+	XMapWindow(dpy, w);
+	if (Scr.flags.do_need_window_update && window_update)
+	{
+		flush_window_updates();
+	}
+	XDestroyWindow(dpy, w);
+	XSync(dpy, 0);
+	handle_all_expose();
+
+	return;
+}
+
 void ApplyDefaultFontAndColors(void)
 {
 	XGCValues gcv;
@@ -1272,7 +1272,7 @@ Bool ReadDecorFace(char *s, DecorFace *df, int button, int verbose)
 		}
 #endif
 		else if (FMiniIconsSupported &&
-                         strncasecmp (style, "MiniIcon", 8) == 0)
+			 strncasecmp (style, "MiniIcon", 8) == 0)
 		{
 			memset(&df->style, 0, sizeof(df->style));
 			DFS_FACE_TYPE(df->style) = MiniIconButton;
@@ -1530,68 +1530,6 @@ void CMD_Beep(F_CMD_ARGS)
 	return;
 }
 
-void CMD_Plus(F_CMD_ARGS)
-{
-	if (Scr.last_added_item.type == ADDED_MENU)
-		add_another_menu_item(action);
-	else if (Scr.last_added_item.type == ADDED_FUNCTION)
-		AddToFunction(Scr.last_added_item.item, action);
-#ifdef USEDECOR
-	else if (Scr.last_added_item.type == ADDED_DECOR) {
-		FvwmDecor *tmp = &Scr.DefaultDecor;
-		for (; tmp; tmp = tmp->next)
-			if (tmp == Scr.last_added_item.item)
-				break;
-		if (!tmp)
-			return;
-		AddToDecor(tmp, action);
-	}
-#endif /* USEDECOR */
-
-	return;
-}
-
-void CMD_DestroyFunc(F_CMD_ARGS)
-{
-	FvwmFunction *func;
-	char *token;
-
-	GetNextToken(action,&token);
-	if (!token)
-		return;
-	func = FindFunction(token);
-	free(token);
-	if (!func)
-		return;
-	if (Scr.last_added_item.type == ADDED_FUNCTION)
-		set_last_added_item(ADDED_NONE, NULL);
-	DestroyFunction(func);
-
-	return;
-}
-
-void CMD_AddToFunc(F_CMD_ARGS)
-{
-	FvwmFunction *func;
-	char *token;
-
-	action = GetNextToken(action,&token);
-	if (!token)
-		return;
-	func = FindFunction(token);
-	if (func == NULL)
-		func = NewFvwmFunction(token);
-
-	/* Set + state to last function */
-	set_last_added_item(ADDED_FUNCTION, func);
-
-	free(token);
-	AddToFunction(func, action);
-
-	return;
-}
-
-
 void CMD_Nop(F_CMD_ARGS)
 {
 	return;
@@ -1880,7 +1818,7 @@ void CMD_Exec(F_CMD_ARGS)
 
 void CMD_Refresh(F_CMD_ARGS)
 {
-	refresh_window(Scr.Root);
+	refresh_window(Scr.Root, True);
 
 	return;
 }
@@ -1892,7 +1830,8 @@ void CMD_RefreshWindow(F_CMD_ARGS)
 		return;
 	}
 	refresh_window(
-		(context == C_ICON) ? FW_W_ICON_TITLE(fw) : FW_W_FRAME(fw));
+		(context == C_ICON) ? FW_W_ICON_TITLE(fw) : FW_W_FRAME(fw),
+		True);
 
 	return;
 }
@@ -3035,12 +2974,12 @@ void CMD_Emulate(F_CMD_ARGS)
 /*
  * The ColorLimit command is  ignored if the  user has no reason to limit
  * color.  This is so the   same configuration will work on  colorlimited
- * and   non-colorlimited  displays  without    resorting   to using    a
+ * and	 non-colorlimited  displays  without	resorting   to using	a
  * preprocessor.
  *
- * Lets assume  the display is  no more  than  2000x1000 pixels. Ie.  the
- * display can display no more than 2,000,000 million  pixels at once.  A
- * display depth of 21 will display 2  million colors at once.  Hence the
+ * Lets assume	the display is	no more	 than  2000x1000 pixels. Ie.  the
+ * display can display no more than 2,000,000 million  pixels at once.	A
+ * display depth of 21 will display 2  million colors at once.	Hence the
  * logic below.
  *
  * dje 03/22/99
@@ -3055,8 +2994,8 @@ void CMD_ColorLimit(F_CMD_ARGS)
 	 * dynamically changeable ones are odd numbered */
 	if (!(Pvisual->class & 1))
 		return;
-	if (Pdepth > 20) {               /* if more than 20 bit color */
-		return;                             /* ignore the limit */
+	if (Pdepth > 20) {		 /* if more than 20 bit color */
+		return;				    /* ignore the limit */
 	}
 	if (GetIntegerArguments(action, NULL, &val, 1) != 1)
 	{
