@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /*
@@ -35,6 +35,7 @@
 
 #include "libs/fvwmlib.h"
 #include "fvwm.h"
+#include "externs.h"
 #include "cursor.h"
 #include "functions.h"
 #include "bindings.h"
@@ -50,11 +51,10 @@ void FreeColors(Pixel *pixels, int n)
 {
   int i;
 
-  /* We don't ever free "black" - dirty hack to allow freeing colours at all */
+  /* We don't ever free black - dirty hack to allow freeing colours at all */
   for (i = 0; i < n; i++)
   {
     if (pixels[i] != 0)
       XFreeColors(dpy, Pcmap, pixels + i, 1, 0);
   }
 }
-
