@@ -3,7 +3,7 @@
  * http://www.streetmap.co.uk/streetmap.dll?postcode2map?BS24+9TZ
  *
  * No guarantees or warranties or anything are provided or implied in any way
- * whatsoever.  Use this program at your own risk.  Permission to use this
+ * whatsoever.	Use this program at your own risk.  Permission to use this
  * program for any purpose is given, as long as the copyright is kept intact.
  */
 /*
@@ -14,7 +14,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -25,20 +25,22 @@
 /* ---------------------------- included header files ----------------------- */
 
 #include "config.h"
-#define FVWM_COLORSET_PRIVATE
+
 #include "libs/fvwmlib.h"
+#include "libs/PictureBase.h"
+#include "colorset.h"
 #include "externs.h"
 #include "fvwm.h"
 #include "cursor.h"
 #include "functions.h"
 #include "misc.h"
 #include "screen.h"
-#include "colorset.h"
 #include "module_interface.h"
 #include "commands.h"
 #include "libs/FShape.h"
 #include "libs/Picture.h"
 #include "libs/PictureGraphics.h"
+#include "libs/FRenderInit.h"
 
 /* ---------------------------- local definitions --------------------------- */
 
@@ -46,7 +48,7 @@
 
 /* ---------------------------- imports ------------------------------------- */
 
-extern int nColorsets;  /* in libs/Colorset.c */
+extern int nColorsets;	/* in libs/Colorset.c */
 
 /* ---------------------------- included code files ------------------------- */
 
@@ -58,7 +60,8 @@ extern int nColorsets;  /* in libs/Colorset.c */
  * change while the second change is happening. If the module renders something
  * with the colorset affected by the second change there is a chance it may
  * reference pixmaps that FvwmTheme has destroyed, bad things would happen */
-struct junklist {
+struct junklist
+{
 	struct junklist *prev;
 	Pixmap pixmap;
 };
@@ -94,6 +97,9 @@ static char *csetopts[] =
 	"Shade",
 	"sh",
 
+	"fgsh",
+	"fg_alpha",
+
 	/* these strings are used inside the cases in the switch below! */
 	"Pixmap",
 	"TiledPixmap",
@@ -131,11 +137,14 @@ static void add_to_junk(Pixmap pixmap)
 	junk = (struct junklist *)safemalloc(sizeof(struct junklist));
 	junk->prev = oldjunk;
 	junk->pixmap = pixmap;
-	if (!cleanup_scheduled) {
+	if (!cleanup_scheduled)
+	{
 		CMD_Schedule(
 			NULL, NULL, 0, NULL, 0, "3000 CleanupColorsets", NULL);
 		cleanup_scheduled = True;
 	}
+
+	return;
 }
 
 static void MyXParseColor(
@@ -183,7 +192,9 @@ static char *get_simple_color(
 		}
 	}
 	else
+	{
 		cs->color_flags &= ~(supplied_color | special_flag);
+	}
 
 	return rest;
 }
@@ -212,17 +223,20 @@ static void SafeDestroyPicture(Display *dpy, FvwmPicture *picture)
 	}
 	/* all that this will now do is free the colors and the name */
 	PDestroyFvwmPicture(dpy, picture);
+
+	return;
 }
 
 static void free_colorset_background(colorset_struct *cs)
 {
-	if (cs->picture) {
+	if (cs->picture != NULL)
+	{
 		if (cs->picture->picture != cs->pixmap)
 		{
 			add_to_junk(cs->pixmap);
 		}
 		SafeDestroyPicture(dpy, cs->picture);
-		cs->picture = None;
+		cs->picture = NULL;
 		cs->pixmap = None;
 		cs->alpha_pixmap = None; /* alaways equal to picture->alpha */
 	}
@@ -250,6 +264,230 @@ static void free_colorset_background(colorset_struct *cs)
 	}
 }
 
+static void reset_cs_pixmap(colorset_struct *cs, GC gc)
+{
+	if (Pdepth == cs->picture->depth)
+	{
+		XCopyArea(dpy, cs->picture->picture, cs->pixmap, gc,
+			  0, 0, cs->width, cs->height, 0, 0);
+	}
+	else
+	{
+		XCopyPlane(dpy, cs->picture->picture, cs->pixmap, gc,
+			   0, 0, cs->width, cs->height, 0, 0, 1);
+	}
+
+	return;
+}
+
+static void parse_pixmap(Window win, GC gc, colorset_struct *cs, int i,
+			 char *args, Bool *pixmap_is_a_bitmap)
+{
+	char *token;
+	static char *name = "parse_colorset(pixmap)";
+
+	/* set the flags */
+	if (csetopts[i][0] == 'T')
+	{
+		cs->pixmap_type = PIXMAP_TILED;
+	}
+	else if (csetopts[i][0] == 'A')
+	{
+		cs->pixmap_type = PIXMAP_STRETCH_ASPECT;
+	}
+	else
+	{
+		cs->pixmap_type = PIXMAP_STRETCH;
+	}
+
+	/* read filename */
+	token = PeekToken(args, &args);
+	if (!token)
+	{
+		return;
+	}
+	/* load the file using the color reduction routines */
+	/* in Picture.c */
+	cs->picture = PCacheFvwmPicture(dpy, win, NULL, token, Scr.ColorLimit);
+	if (cs->picture == NULL)
+	{
+		fvwm_msg(ERR, name, "can't load picture %s", token);
+		return;
+	}
+	if (cs->picture->depth != Pdepth)
+	{
+		*pixmap_is_a_bitmap = True;
+		cs->pixmap = None; /* build cs->pixmap later */
+	}
+	/* copy the picture pixmap into the public structure */
+	cs->width = cs->picture->width;
+	cs->height = cs->picture->height;
+	cs->alpha_pixmap = cs->picture->alpha;
+
+	if (!*pixmap_is_a_bitmap)
+	{
+		cs->pixmap = XCreatePixmap(dpy, win,
+					   cs->width, cs->height,
+					   Pdepth);
+		XSetClipMask(dpy, gc, cs->picture->mask);
+		XCopyArea(dpy, cs->picture->picture, cs->pixmap, gc,
+			  0, 0, cs->width, cs->height, 0, 0);
+		XSetClipMask(dpy, gc, None);
+	}
+	if (cs->pixmap)
+	{
+		if (cs->picture->mask != None)
+		{
+			/* make an inverted copy of the mask */
+			cs->mask = XCreatePixmap(dpy, win,
+						 cs->width, cs->height,
+						 1);
+			if (cs->mask)
+			{
+				XCopyArea(dpy, cs->picture->mask, cs->mask,
+					  Scr.MonoGC,
+					  0, 0, cs->width, cs->height, 0, 0);
+				/* Invert the mask. We use it to draw the
+				 * background. */
+				XSetFunction(dpy, Scr.MonoGC, GXinvert);
+				XFillRectangle(dpy, cs->mask, Scr.MonoGC,
+					       0, 0, cs->width, cs->height);
+				XSetFunction(dpy, Scr.MonoGC, GXcopy);
+			}
+		}
+	}
+}
+
+static void parse_shape(Window win, colorset_struct *cs, int i, char *args,
+			int *has_shape_changed)
+{
+	char *token;
+	static char *name = "parse_colorset(shape)";
+	FvwmPicture *picture;
+
+	if (!FHaveShapeExtension)
+	{
+		cs->shape_mask = None;
+		return;
+	}
+
+	/* read filename */
+	token = PeekToken(args, &args);
+	*has_shape_changed = True;
+	if (cs->shape_mask)
+	{
+		add_to_junk(cs->shape_mask);
+		cs->shape_mask = None;
+	}
+
+	/* set the flags */
+	if (csetopts[i][0] == 'T')
+	{
+		cs->shape_type = SHAPE_TILED;
+	}
+	else if (csetopts[i][0] == 'A')
+	{
+		cs->shape_type = SHAPE_STRETCH_ASPECT;
+	}
+	else
+	{
+		cs->shape_type = SHAPE_STRETCH;
+	}
+
+	/* try to load the shape mask */
+	if (!token)
+	{
+		return;
+	}
+
+	/* load the shape mask */
+	picture = PCacheFvwmPicture(dpy, win, NULL, token, Scr.ColorLimit);
+	if (!picture)
+	{
+		fvwm_msg(ERR, name, "can't load picture %s", token);
+	}
+	else if (picture->depth != 1 && picture->mask == None)
+	{
+		fvwm_msg(ERR, name, "shape pixmap must be of depth 1");
+		SafeDestroyPicture(dpy, picture);
+	}
+	else
+	{
+		Pixmap mask;
+
+		/* okay, we have what we want */
+		if (picture->mask != None)
+		{
+			mask = picture->mask;
+		}
+		else
+		{
+			mask = picture->picture;
+		}
+		cs->shape_width = picture->width;
+		cs->shape_height = picture->height;
+
+		if (mask != None)
+		{
+			cs->shape_mask = XCreatePixmap(
+				dpy, mask, picture->width, picture->height, 1);
+			if (cs->shape_mask != None)
+			{
+				XCopyPlane(dpy, mask, cs->shape_mask,
+					   Scr.MonoGC, 0, 0, picture->width,
+					   picture->height, 0, 0, 1);
+			}
+		}
+	}
+	if (picture)
+	{
+		SafeDestroyPicture(dpy, picture);
+		picture = None;
+	}
+	return;
+}
+
+static void parse_tint(Window win, GC gc, colorset_struct *cs, int i, char *args,
+		       char **tint, int *has_tint_changed,
+		       int *has_pixmap_changed)
+{
+	char *rest;
+	static char *name = "parse_colorset(tint)";
+	int tint_percent;
+
+	if (!XRenderSupport || !FRenderGetExtensionSupported())
+	{
+		return;
+	}
+
+	rest = get_simple_color(args, tint, cs, TINT_SUPPLIED, 0, NULL);
+	if (!GetIntegerArguments(rest, NULL, &tint_percent, 1))
+	{
+		fvwm_msg(WARN, name,
+			 "Tint must have two arguments a color and an integer");
+		tint_percent = -1;
+		return;
+	}
+	*has_tint_changed = True;
+	if (!*has_pixmap_changed && cs->picture != NULL && cs->picture->picture)
+	{
+		XSetClipMask(dpy, gc, cs->picture->mask);
+		XCopyArea(dpy, cs->picture->picture, cs->pixmap, gc,
+			  0, 0, cs->width, cs->height, 0, 0);
+		XSetClipMask(dpy, gc, None);
+		*has_pixmap_changed = True;
+	}
+	cs->tint_percent = (tint_percent > 100)? 100:tint_percent;
+	if (i == 22)
+	{
+		cs->do_tint_use_mask = True;
+	}
+	else
+	{
+		cs->do_tint_use_mask = False;
+	}
+}
+
 /* ---------------------------- interface functions ------------------------- */
 
 void cleanup_colorsets()
@@ -272,9 +510,8 @@ void parse_colorset(int n, char *line)
 	int i;
 	int w;
 	int h;
-	int tint_percent;
+	int tmp;
 	colorset_struct *cs;
-	char *token;
 	char *optstring;
 	char *args;
 	char *option;
@@ -283,27 +520,29 @@ void parse_colorset(int n, char *line)
 	char *bg = NULL;
 	char *hi = NULL;
 	char *sh = NULL;
+	char *fgsh = NULL;
 	char *tint = NULL;
-	Bool do_remove_shape;
 	Bool have_pixels_changed = False;
 	Bool has_fg_changed = False;
 	Bool has_bg_changed = False;
 	Bool has_sh_changed = False;
 	Bool has_hi_changed = False;
+	Bool has_fgsh_changed = False;
+	Bool has_fg_alpha_changed = False;
 	Bool has_tint_changed = False;
 	Bool has_pixmap_changed = False;
 	Bool has_shape_changed = False;
+	Bool pixmap_is_a_bitmap = False;
 	XColor color;
 	XGCValues xgcv;
 	static char *name = "parse_colorset";
 	Window win = Scr.NoFocusWin;
-	static GC gc = None, monoGC = None;
+	static GC gc = None;
 
 	/* initialize statics */
 	if (gc == None)
 	{
 		gc = fvwmlib_XCreateGC(dpy, win, 0, &xgcv);
-		monoGC = fvwmlib_XCreateGC(dpy, Scr.ScratchMonoPixmap,0, &xgcv);
 	}
 
 	/* make sure it exists and has sensible contents */
@@ -324,7 +563,6 @@ void parse_colorset(int n, char *line)
 			break;
 		}
 
-		do_remove_shape = False;
 		switch((i = GetTokenIndex(option, csetopts, 0, NULL)))
 		{
 		case 0: /* Foreground */
@@ -355,184 +593,44 @@ void parse_colorset(int n, char *line)
 			get_simple_color(args, &sh, cs, SH_SUPPLIED, 0, NULL);
 			has_sh_changed = True;
 			break;
-		case 12: /* TiledPixmap */
-		case 13: /* Pixmap */
-		case 14: /* AspectPixmap */
-			has_pixmap_changed = True;
-			free_colorset_background(cs);
-			/* set the flags */
-			if (csetopts[i][0] == 'T')
-				cs->pixmap_type = PIXMAP_TILED;
-			else if (csetopts[i][0] == 'A')
-				cs->pixmap_type = PIXMAP_STRETCH_ASPECT;
-			else
-				cs->pixmap_type = PIXMAP_STRETCH;
-
-			/* read filename */
-			token = PeekToken(args, &args);
-			if (!token)
-				break;
-			/* load the file using the color reduction routines */
-			/* in Picture.c */
-			cs->picture = PCacheFvwmPicture(
-				dpy, win, NULL, token, Scr.ColorLimit);
-			if (!cs->picture)
-			{
-				fvwm_msg(
-					ERR, name, "can't load picture %s",
-					token);
-				break;
-			}
-			/* don't try to be smart with bitmaps */
-			if (cs->picture->depth != Pdepth)
-			{
-				fvwm_msg(ERR, name, "bitmaps not supported");
-				SafeDestroyPicture(dpy, cs->picture);
-				cs->picture = None;
-				break;
-			}
-			/* copy the picture pixmap into the public structure */
-			cs->width = cs->picture->width;
-			cs->height = cs->picture->height;
-			cs->alpha_pixmap = cs->picture->alpha;
-
-			if (cs->picture->picture)
-			{
-				cs->pixmap = XCreatePixmap(
-					dpy, win, cs->width,
-					cs->height, Pdepth);
-				XSetClipMask(dpy, gc, cs->picture->mask);
-				XCopyArea(
-					dpy, cs->picture->picture, cs->pixmap,
-					gc, 0, 0, cs->width, cs->height, 0, 0);
-				XSetClipMask(dpy, gc, None);
-			}
-			if (cs->pixmap)
-			{
-				if (cs->picture->mask != None)
-				{
-					/* make an inverted copy of the mask */
-					cs->mask = XCreatePixmap(
-						dpy, win, cs->width,
-						cs->height, 1);
-					if (cs->mask)
-					{
-						XCopyArea(
-							dpy, cs->picture->mask,
-							cs->mask, monoGC,
-							0, 0,
-							cs->width, cs->height,
-							0, 0);
-						/* Invert the mask. We use it
-						 * to draw the background. */
-						XSetFunction(
-							dpy, monoGC, GXinvert);
-						XFillRectangle(
-							dpy, cs->mask,
-							monoGC, 0, 0,
-							cs->width, cs->height);
-						XSetFunction(
-							dpy, monoGC, GXcopy);
-					}
-				}
-			}
+		case 12: /* fgsh */
+			get_simple_color(args, &fgsh, cs, FGSH_SUPPLIED, 0,NULL);
+			has_fgsh_changed = True;
 			break;
-		case 15: /* Shape */
-		case 16: /* TiledShape */
-		case 17: /* AspectShape */
-			if (FHaveShapeExtension)
+		case 13: /* fg_alpha */
+			if (GetIntegerArguments(args, NULL, &tmp, 1))
 			{
-				/* read filename */
-				token = PeekToken(args, &args);
-				has_shape_changed = True;
-				if (cs->shape_mask)
-				{
-					add_to_junk(cs->shape_mask);
-					cs->shape_mask = None;
-				}
-				if (do_remove_shape == True)
-					break;
-				/* set the flags */
-				if (csetopts[i][0] == 'T')
-					cs->shape_type = SHAPE_TILED;
-				else if (csetopts[i][0] == 'A')
-					cs->shape_type = SHAPE_STRETCH_ASPECT;
+				if (tmp > 100)
+					cs->fg_alpha = 100;
+				else if (cs->fg_alpha < 0)
+					cs->fg_alpha = 0;
 				else
-					cs->shape_type = SHAPE_STRETCH;
-
-				/* try to load the shape mask */
-				if (token)
-				{
-					FvwmPicture *picture;
-
-					/* load the shape mask */
-					picture = PCacheFvwmPicture(
-						dpy, win, NULL, token,
-						Scr.ColorLimit);
-					if (!picture)
-						fvwm_msg(
-							ERR, name, "can't load "
-							"picture %s", token);
-					else if (picture->depth != 1 &&
-						 picture->mask == None)
-					{
-						fvwm_msg(
-							ERR, name,
-							"shape pixmap must be "
-							"of depth 1");
-						SafeDestroyPicture(dpy, picture);
-					}
-					else
-					{
-						Pixmap mask;
-
-						/* okay, we have what we want */
-						if (picture->mask != None)
-							mask = picture->mask;
-						else
-							mask = picture->picture;
-						cs->shape_width = picture->width;
-						cs->shape_height =
-							picture->height;
-
-						if (mask != None)
-						{
-							cs->shape_mask =
-								XCreatePixmap(
-								dpy, mask,
-								picture->width,
-								picture->height,
-								1);
-							if (cs->shape_mask !=
-							    None)
-							{
-								XCopyPlane(
-								dpy, mask,
-								cs->shape_mask,
-								monoGC, 0, 0,
-								picture->width,
-								picture->height,
-								0, 0, 1);
-							}
-						}
-					}
-					if (picture)
-					{
-						SafeDestroyPicture(dpy, picture);
-						picture = None;
-					}
-				}
+					cs->fg_alpha = tmp;
 			}
 			else
 			{
-				cs->shape_mask = None;
+				cs->fg_alpha = 100;
 			}
+			has_fg_alpha_changed = True;
 			break;
-		case 18: /* Plain */
+		case 14: /* TiledPixmap */
+		case 15: /* Pixmap */
+		case 16: /* AspectPixmap */
 			has_pixmap_changed = True;
 			free_colorset_background(cs);
+			parse_pixmap(win, gc, cs, i, args, &pixmap_is_a_bitmap);
 			break;
-		case 19: /* NoShape */
+		case 17: /* Shape */
+		case 18: /* TiledShape */
+		case 19: /* AspectShape */
+			parse_shape(win, cs, i, args, &has_shape_changed);
+			break;
+		case 20: /* Plain */
+			has_pixmap_changed = True;
+			pixmap_is_a_bitmap = False;
+			free_colorset_background(cs);
+			break;
+		case 21: /* NoShape */
 			has_shape_changed = True;
 			if (cs->shape_mask)
 			{
@@ -540,7 +638,7 @@ void parse_colorset(int n, char *line)
 				cs->shape_mask = None;
 			}
 			break;
-		case 20: /* Transparent */
+		case 22: /* Transparent */
 
 			/* This is only allowable when the root depth == fvwm
 			 * visual depth otherwise bad match errors happen,
@@ -559,55 +657,19 @@ void parse_colorset(int n, char *line)
 			cs->pixmap = ParentRelative;
 			cs->pixmap_type = PIXMAP_STRETCH;
 			break;
-		case 21: /* Tint */
-		case 22: /* TintMask */
-			if (XRenderSupport)
-			{
-				char *rest;
-
-				rest = get_simple_color(args, &tint, cs,
-							TINT_SUPPLIED, 0, NULL);
-				if (!GetIntegerArguments(rest, NULL,
-							 &tint_percent, 1))
-				{
-					fvwm_msg(WARN, name,
-						 "Tint must have two arguments "
-						 "a color and an integer");
-					tint_percent = -1;
-					break;
-				}
-				has_tint_changed = True;
-				if (!has_pixmap_changed && cs->picture &&
-				    cs->picture->picture)
-				{
-					XSetClipMask(dpy, gc, cs->picture->mask);
-					XCopyArea(dpy, cs->picture->picture,
-						  cs->pixmap, gc, 0, 0,
-						  cs->width, cs->height, 0, 0);
-					XSetClipMask(dpy, gc, None);
-					has_pixmap_changed = True;
-				}
-				cs->tint_percent = (tint_percent > 100)?
-					100:tint_percent;
-				if (i == 22)
-				{
-					cs->do_tint_use_mask = True;
-				}
-				else
-				{
-					cs->do_tint_use_mask = False;
-				}
-			}
+		case 23: /* Tint */
+		case 24: /* TintMask */
+			parse_tint(win, gc, cs, i, args, &tint,
+				   &has_tint_changed,
+				   &has_pixmap_changed);
 			break;
-		case 23: /* NoTint */
+		case 25: /* NoTint */
 			has_pixmap_changed = True;
 			/* restore the pixmap */
-			if (cs->picture != None && cs->pixmap)
+			if (cs->picture != NULL && cs->pixmap)
 			{
 				XSetClipMask(dpy, gc, cs->picture->mask);
-				XCopyArea(dpy, cs->picture->picture, cs->pixmap,
-					  gc, 0, 0,
-					  cs->width, cs->height, 0, 0);
+				reset_cs_pixmap(cs, gc);
 				XSetClipMask(dpy, gc, None);
 			}
 			cs->tint_percent = -1;
@@ -653,6 +715,10 @@ void parse_colorset(int n, char *line)
 		optstring = NULL;
 	} /* while (line && *line) */
 
+	if (cs->picture != NULL && cs->picture->depth != Pdepth)
+	{
+		pixmap_is_a_bitmap = True;
+	}
 	/*
 	 * ---------- change the background colour ----------
 	 */
@@ -660,8 +726,11 @@ void parse_colorset(int n, char *line)
 	{
 		Bool do_set_default_background = False;
 
-		if ((cs->color_flags & BG_AVERAGE) && cs->pixmap != None &&
-			cs->pixmap != ParentRelative)
+		/* note: no average for bitmap */
+		if ((cs->color_flags & BG_AVERAGE) &&
+		    cs->pixmap != None &&
+		    cs->pixmap != ParentRelative &&
+		    !pixmap_is_a_bitmap)
 		{
 			/* calculate average background color */
 			XColor *colors;
@@ -669,31 +738,47 @@ void parse_colorset(int n, char *line)
 			XImage *mask_image = None;
 			unsigned int i, j, k = 0;
 			unsigned long red = 0, blue = 0, green = 0;
+			unsigned long tred, tblue, tgreen;
+			double dred = 0.0, dblue = 0.0, dgreen = 0.0;
+			Pixmap pix;
 
+			/* chose the good pixmap (tint problems) */
+			pix =
+			   (cs->picture != NULL &&
+			    cs->picture->picture != None) ?
+				cs->picture->picture : cs->pixmap;
 			/* create an array to store all the pixmap colors in */
 			colors = (XColor *)safemalloc(
 				cs->width * cs->height * sizeof(XColor));
 			/* get the pixmap and mask into an image */
 			image = XGetImage(
-				dpy, cs->pixmap, 0, 0, cs->width, cs->height,
+				dpy, pix, 0, 0, cs->width, cs->height,
 				AllPlanes, ZPixmap);
 			if (cs->mask != None)
+			{
 				mask_image = XGetImage(
 					dpy, cs->mask, 0, 0, cs->width,
 					cs->height, AllPlanes, ZPixmap);
+			}
 			/* only fetch the pixels that are not masked out */
 			for (i = 0; i < cs->width; i++)
+			{
 				for (j = 0; j < cs->height; j++)
+				{
 					if ((cs->mask == None) || (XGetPixel(
 						mask_image, i, j) == 0))
 					{
 						colors[k++].pixel =
 							XGetPixel(image, i, j);
 					}
+				}
+			}
 
 			XDestroyImage(image);
 			if (mask_image != None)
+			{
 				XDestroyImage(mask_image);
+			}
 			if (k == 0)
 			{
 				do_set_default_background = True;
@@ -703,22 +788,45 @@ void parse_colorset(int n, char *line)
 				/* look them all up, XQueryColors() can't
 				 * handle more than 256 */
 				for (i = 0; i < k; i += 256)
+				{
 					XQueryColors(
 						dpy, Pcmap, &colors[i],
 						min(k - i, 256));
-				/* calculate average, ignore overflow:
+				}
+				/* calculate average, add overflows in a double
 				 * .red is short, red is long */
 				for (i = 0; i < k; i++)
 				{
+					tred = red;
 					red += colors[i].red;
+					if (red < tred)
+					{
+						dred += (double)tred;
+						red = colors[i].red;
+					}
+					tgreen = green;
 					green += colors[i].green;
+					if (green < tgreen)
+					{
+						dgreen += (double)tgreen;
+						green = colors[i].green;
+					}
+					tblue = blue;
 					blue += colors[i].blue;
+					if (blue < tblue)
+					{
+						dblue += (double)tblue;
+						blue = colors[i].blue;
+					}
 				}
+				dred += red;
+				dgreen += green;
+				dblue += blue;
 				free(colors);
 				/* get it */
-				color.red = red / k;
-				color.green = green / k;
-				color.blue = blue / k;
+				color.red = dred / k;
+				color.green = dgreen / k;
+				color.blue = dblue / k;
 				if (privateCells)
 				{
 					color.pixel = cs->bg;
@@ -732,14 +840,17 @@ void parse_colorset(int n, char *line)
 					XAllocColor(dpy, Pcmap, &color);
 					cs->bg = color.pixel;
 					if (old_bg != cs->bg)
+					{
 						have_pixels_changed = True;
+					}
 				}
 			}
 		} /* average */
 		else if ((cs->color_flags & BG_SUPPLIED) && bg != NULL)
 		{
 			/* user specified colour */
-			if (privateCells) {
+			if (privateCells)
+			{
 				unsigned short red, green, blue;
 
 				MyXParseColor(bg, &color);
@@ -756,11 +867,15 @@ void parse_colorset(int n, char *line)
 				XFreeColors(dpy, Pcmap, &cs->bg, 1, 0);
 				cs->bg = GetColor(bg);
 				if (old_bg != cs->bg)
+				{
 					have_pixels_changed = True;
+				}
 			}
 		} /* user specified */
-		else if ((bg == NULL && has_bg_changed) || ((cs->color_flags &
-			BG_AVERAGE) && cs->pixmap == ParentRelative))
+		else if ((bg == NULL && has_bg_changed) ||
+			 ((cs->color_flags & BG_AVERAGE) &&
+			  (cs->pixmap == None || cs->pixmap == ParentRelative ||
+			   pixmap_is_a_bitmap)))
 		{
 			/* default */
 			do_set_default_background = True;
@@ -789,7 +904,8 @@ void parse_colorset(int n, char *line)
 	/*
 	 * ---------- change the foreground colour ----------
 	 */
-	if (has_fg_changed || (has_bg_changed && (cs->color_flags & FG_CONTRAST)))
+	if (has_fg_changed ||
+	    (has_bg_changed && (cs->color_flags & FG_CONTRAST)))
 	{
 		has_fg_changed = 1;
 		if (cs->color_flags & FG_CONTRAST)
@@ -948,17 +1064,65 @@ void parse_colorset(int n, char *line)
 		}
 	} /* has_sh_changed */
 
+	/*
+	 * ---------- change the shadow foreground colour ----------
+	 */
+	if (has_fgsh_changed || has_fg_changed)
+	{
+		has_fgsh_changed = 1;
+		if ((cs->color_flags & FGSH_SUPPLIED) && fgsh != NULL)
+		{
+			/* user specified colour */
+			if (privateCells)
+			{
+				MyXParseColor(fgsh, &color);
+				color.pixel = cs->fgsh;
+				XStoreColor(dpy, Pcmap, &color);
+			}
+			else
+			{
+				Pixel old_fgsh = cs->fgsh;
+
+				XFreeColors(dpy, Pcmap, &cs->fgsh, 1, 0);
+				cs->fgsh = GetColor(fgsh);
+				if (old_fgsh != cs->fgsh)
+					have_pixels_changed = True;
+			}
+		} /* user specified */
+		else if (fgsh == NULL)
+		{
+			if (privateCells)
+			{
+				XColor *colorp;
+
+				colorp = GetForeShadowColor(cs->fg, cs->bg);
+				colorp->pixel = cs->fgsh;
+				XStoreColor(dpy, Pcmap, colorp);
+			}
+			else
+			{
+				Pixel old_fgsh = cs->fgsh;
+
+				XFreeColors(dpy, Pcmap, &cs->fgsh, 1, 0);
+				cs->fgsh = GetForeShadow(cs->fg, cs->bg);
+				if (old_fgsh != cs->fgsh)
+					have_pixels_changed = True;
+			}
+		}
+	} /* has_fgsh_changed */
+
 	/*
 	 * ------- change the masked out parts of the background pixmap -------
 	 */
-	if (cs->picture != None &&
+	if (cs->picture != NULL &&
 	    (cs->mask != None || cs->alpha_pixmap != None) &&
 	    (has_pixmap_changed || has_bg_changed))
 	{
 		/* Now that we know the background colour we can update the
 		 * pixmap background. */
 		XSetForeground(dpy, gc, cs->bg);
-		if (XRenderSupport && cs->alpha_pixmap != None)
+		if (XRenderSupport && cs->alpha_pixmap != None &&
+		    FRenderGetExtensionSupported())
 		{
 			Pixmap temp = XCreatePixmap(
 				dpy, win, cs->width, cs->height, Pdepth);
@@ -973,49 +1137,74 @@ void parse_colorset(int n, char *line)
 		}
 		else
 		{
-			XSetClipMask(dpy, gc, cs->mask);
 			XFillRectangle(
-				dpy, cs->pixmap, gc, 0, 0, cs->width,
-				cs->height);
+				dpy, cs->pixmap, gc,
+				0, 0, cs->width, cs->height);
+			XSetClipMask(dpy, gc, cs->picture->mask);
+			reset_cs_pixmap(cs, gc);
 		}
 		XSetClipMask(dpy, gc, None);
 		has_pixmap_changed = True;
 	} /* has_pixmap_changed */
 
+	/*
+	 * ------- the pixmap is a bitmap: create here cs->pixmap -------
+	 */
+	if (cs->picture != None && pixmap_is_a_bitmap &&
+	    (has_pixmap_changed || has_bg_changed))
+	{
+		cs->pixmap = XCreatePixmap(
+			dpy, win, cs->width, cs->height, Pdepth);
+		XSetBackground(dpy, gc, cs->bg);
+		XSetForeground(dpy, gc, cs->fg);
+		reset_cs_pixmap(cs, gc);
+	}
+
 	/*
 	 * ---------- change the tint colour ----------
 	 */
-	if (XRenderSupport && has_tint_changed)
+	if (XRenderSupport && has_tint_changed &&
+	    FRenderGetExtensionSupported())
 	{
 		/* user specified colour */
 		if (tint != NULL)
 		{
-			if (privateCells) {
+			if (privateCells)
+			{
 				MyXParseColor(tint, &color);
 				color.pixel = cs->tint;
 				XStoreColor(dpy, Pcmap, &color);
-			} else {
+			}
+			else
+			{
 				Pixel old_tint = cs->tint;
 				XFreeColors(dpy, Pcmap, &cs->tint, 1, 0);
 				cs->tint = GetColor(tint);
 				if (old_tint != cs->tint)
+				{
 					have_pixels_changed = True;
+				}
 			}
 		}
 		else if (tint == NULL)
 		{
 			/* default */
-			if (privateCells) {
+			if (privateCells)
+			{
 				/* query it */
 				MyXParseColor(black, &color);
 				color.pixel = cs->tint;
 				XStoreColor(dpy, Pcmap, &color);
-			} else {
+			}
+			else
+			{
 				Pixel old_tint = cs->tint;
 				XFreeColors(dpy, Pcmap, &cs->tint, 1, 0);
 				cs->tint = GetColor(black);
 				if (old_tint != cs->tint)
+				{
 					have_pixels_changed = True;
+				}
 			}
 		}
 	}
@@ -1024,8 +1213,9 @@ void parse_colorset(int n, char *line)
 	 * ---------- tint the pixmap ----------
 	 */
 	/* FIXME: recompute the bg/fg if BG_AVERAGE/FG_CONTRASTE ? */
-	if (XRenderSupport && cs->picture != None && cs->tint_percent > 0 &&
-	    (has_pixmap_changed || has_bg_changed || has_tint_changed))
+	if (XRenderSupport && cs->picture != NULL && cs->tint_percent > 0 &&
+	    (has_pixmap_changed || has_bg_changed || has_tint_changed) &&
+	    FRenderGetExtensionSupported())
 	{
 		PGraphicsTintRectangle(
 			dpy, win, cs->tint_percent, cs->tint,
@@ -1041,19 +1231,38 @@ void parse_colorset(int n, char *line)
 	XSync(dpy, False);
 
 	/* inform modules of the change */
-	if (have_pixels_changed || has_pixmap_changed || has_shape_changed)
+	if (have_pixels_changed || has_pixmap_changed || has_shape_changed ||
+	    has_fg_alpha_changed)
+	{
 		BroadcastColorset(n);
+	}
 
 	if (fg)
+	{
 		free(fg);
+	}
 	if (bg)
+	{
 		free(bg);
+	}
 	if (hi)
+	{
 		free(hi);
+	}
 	if (sh)
+	{
 		free(sh);
+	}
+	if (fgsh)
+	{
+		free(fgsh);
+	}
 	if (tint)
+	{
 		free(tint);
+	}
+
+	return;
 }
 
 /*****************************************************************************
@@ -1065,8 +1274,11 @@ void alloc_colorset(int n)
 {
 	/* do nothing if it already exists */
 	if (n < nColorsets)
+	{
 		return;
-	else {
+	}
+	else
+	{
 		Colorset = (colorset_struct *)saferealloc(
 			(char *)Colorset, (n + 1) * sizeof(colorset_struct));
 		memset(
@@ -1081,8 +1293,8 @@ void alloc_colorset(int n)
 
 		/* try to allocate private colormap entries if required */
 		if (privateCells && XAllocColorCells(
-			/* grab four writeable cells */
-			dpy, Pcmap, False, NULL, 0, &(ncs->fg), 4))
+			/* grab 5 writeable cells */
+			dpy, Pcmap, False, NULL, 0, &(ncs->fg), 5))
 		{
 			XColor color;
 			XColor *colorp;
@@ -1103,6 +1315,10 @@ void alloc_colorset(int n)
 			colorp = GetShadowColor(ncs->bg);
 			colorp->pixel = ncs->shadow;
 			XStoreColor(dpy, Pcmap, colorp);
+			/* calculate and set the fg shadow */
+			colorp = GetForeShadowColor(ncs->fg, ncs->bg);
+			colorp->pixel = ncs->fgsh;
+			XStoreColor(dpy, Pcmap, colorp);
 			/* set the tint color */
 			MyXParseColor(black, &color);
 			color.pixel = ncs->tint;
@@ -1124,6 +1340,7 @@ void alloc_colorset(int n)
 				ncs->bg = GetColor(white);
 				ncs->hilite = GetColor(white);
 				ncs->shadow = GetColor(black);
+				ncs->fgsh = GetColor(white);
 				ncs->tint = GetColor(black);
 				ncs->pixmap = XCreatePixmapFromBitmapData(
 					dpy, Scr.NoFocusWin,
@@ -1139,12 +1356,14 @@ void alloc_colorset(int n)
 				ncs->bg = GetColor(gray);
 				ncs->hilite = GetHilite(ncs->bg);
 				ncs->shadow = GetShadow(ncs->bg);
+				ncs->fgsh = GetForeShadow(ncs->fg, ncs->bg);
 				ncs->tint = GetColor(black);
 			}
 			/* set flags for fg contrast, bg average */
 			/* in case just a pixmap is given */
 			ncs->color_flags = FG_CONTRAST | BG_AVERAGE;
 		}
+		ncs->fg_alpha = 100;
 		nColorsets++;
 	}
 }
@@ -1156,14 +1375,22 @@ void CMD_ReadWriteColors(F_CMD_ARGS)
 	static char *name = "ReadWriteColors";
 
 	if (sharedCells)
+	{
 		fvwm_msg(
 			ERR, name, "%s must come first, already allocated "
 			"shared pixels", name);
+	}
 	else if (Pvisual->class != PseudoColor)
+	{
 		fvwm_msg(
 			ERR, name, "%s only works with PseudoColor visuals",
 			name);
+	}
 	else
+	{
 		privateCells = True;
+	}
+
+	return;
 }
 
