@@ -5,18 +5,21 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
-#define FVWM_COLORSET_PRIVATE
+#ifndef __COLORSET_H
+#define __COLORSET_H
+
 #include "libs/Colorset.h"
-#undef  FVWM_COLORSET_PRIVATE
 
 void parse_colorset(int n, char *line);
 void cleanup_colorsets();
 void alloc_colorset(int n);
+
+#endif /* __COLORSET_H */
