@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef DECORATIONS_H
@@ -19,7 +19,8 @@
 void GetMwmHints(FvwmWindow *t);
 void GetOlHints(FvwmWindow *t);
 void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons);
-int check_if_function_allowed(int function, FvwmWindow *t,
-			      Bool override_allowed, char *menu_string);
+Bool is_function_allowed(
+	int function, char *action_string, FvwmWindow *t, Bool is_user_request,
+	Bool do_allow_override_mwm_hints);
 
 #endif /* DECORATIONS_H */
