@@ -18,30 +18,30 @@
  * by Rob Nation
  ****************************************************************************/
 /*****************************************************************************/
-/**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
-/**                          Salt Lake City, Utah                           **/
+/**	  Copyright 1988 by Evans & Sutherland Computer Corporation,	    **/
+/**			     Salt Lake City, Utah			    **/
 /**  Portions Copyright 1989 by the Massachusetts Institute of Technology   **/
-/**                        Cambridge, Massachusetts                         **/
-/**                                                                         **/
-/**                           All Rights Reserved                           **/
-/**                                                                         **/
+/**			   Cambridge, Massachusetts			    **/
+/**									    **/
+/**			      All Rights Reserved			    **/
+/**									    **/
 /**    Permission to use, copy, modify, and distribute this software and    **/
 /**    its documentation  for  any  purpose  and  without  fee is hereby    **/
-/**    granted, provided that the above copyright notice appear  in  all    **/
-/**    copies and that both  that  copyright  notice  and  this  permis-    **/
+/**    granted, provided that the above copyright notice appear	 in  all    **/
+/**    copies and that both  that  copyright  notice  and  this	 permis-    **/
 /**    sion  notice appear in supporting  documentation,  and  that  the    **/
 /**    names of Evans & Sutherland and M.I.T. not be used in advertising    **/
-/**    in publicity pertaining to distribution of the  software  without    **/
-/**    specific, written prior permission.                                  **/
-/**                                                                         **/
+/**    in publicity pertaining to distribution of the  software	 without    **/
+/**    specific, written prior permission.				    **/
+/**									    **/
 /**    EVANS & SUTHERLAND AND M.I.T. DISCLAIM ALL WARRANTIES WITH REGARD    **/
 /**    TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES  OF  MERCHANT-    **/
-/**    ABILITY  AND  FITNESS,  IN  NO  EVENT SHALL EVANS & SUTHERLAND OR    **/
+/**    ABILITY	AND  FITNESS,  IN  NO  EVENT SHALL EVANS & SUTHERLAND OR    **/
 /**    M.I.T. BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL  DAM-    **/
-/**    AGES OR  ANY DAMAGES WHATSOEVER  RESULTING FROM LOSS OF USE, DATA    **/
+/**    AGES OR	ANY DAMAGES WHATSOEVER	RESULTING FROM LOSS OF USE, DATA    **/
 /**    OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER    **/
-/**    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH  THE  USE    **/
-/**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
+/**    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH	THE  USE    **/
+/**    OR PERFORMANCE OF THIS SOFTWARE.					    **/
 /*****************************************************************************/
 
 /* ---------------------------- included header files ----------------------- */
@@ -62,10 +62,12 @@
 #include "libs/fvwmlib.h"
 #include "libs/FShape.h"
 #include <libs/gravity.h>
+#include "libs/FRenderInit.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
 #include "functions.h"
+#include "commands.h"
 #include "bindings.h"
 #include "misc.h"
 #include "screen.h"
@@ -100,7 +102,7 @@
 /* ---------------------------- local definitions --------------------------- */
 
 #ifndef XUrgencyHint
-#define XUrgencyHint            (1L << 8)
+#define XUrgencyHint		(1L << 8)
 #endif
 
 /*
@@ -200,7 +202,7 @@ static Bool test_map_request(
 	Bool rc;
 
 	cie_args = (check_if_event_args *)arg;
-        cie_args->ret_does_match = False;
+	cie_args->ret_does_match = False;
 	if (event->type == MapRequest &&
 	    event->xmaprequest.window == cie_args->w)
 	{
@@ -225,7 +227,7 @@ static Bool test_resizing_event(
 	Bool rc;
 
 	cie_args = (check_if_event_args *)arg;
-        cie_args->ret_does_match = False;
+	cie_args->ret_does_match = False;
 	if (event->xany.window != cie_args->w)
 	{
 		return False;
@@ -378,11 +380,18 @@ void HandleButtonPress(void)
 		SetFocusWindow(Fw, True, True);
 	}
 	/* click to focus stuff goes here */
-	if ((Fw)&&(HAS_CLICK_FOCUS(Fw))&&(Fw != Scr.Ungrabbed))
+	if (Fw && HAS_CLICK_FOCUS(Fw) && Fw != Scr.Ungrabbed)
 	{
+		unsigned was_already_focused;
+
 		if (Fw != get_focus_window())
 		{
 			SetFocusWindow(Fw, True, True);
+			was_already_focused = 0;
+		}
+		else
+		{
+			was_already_focused = 1;
 		}
 		/* RBW - 12/09/.1999- I'm not sure we need to check both cases,
 		 * but I'll leave this as is for now.  */
@@ -406,8 +415,8 @@ void HandleButtonPress(void)
 			 * raised after the binding is executed. Functions that
 			 * modify the stacking order will reset this flag. */
 			SET_SCHEDULED_FOR_RAISE(Fw, 1);
-			do_regrab_buttons = True;
 		}
+		do_regrab_buttons = True;
 
 		Context = GetContext(Fw, &Event, &PressedW);
 		if (!IS_ICONIFIED(Fw) && Context == C_WINDOW)
@@ -417,26 +426,22 @@ void HandleButtonPress(void)
 				RaiseWindow(Fw);
 				SET_SCHEDULED_FOR_RAISE(Fw, 0);
 			}
-			if (do_regrab_buttons)
-			{
-				focus_grab_buttons(
-					Fw, (Fw == get_focus_window()));
-			}
+			focus_grab_buttons(Fw, (Fw == get_focus_window()));
 			XFlush(dpy);
 			/* Pass click event to just clicked to focus window? Do
 			 * not swallow the click if the window didn't accept
 			 * the focus. */
 			if (!DO_NOT_PASS_CLICK_FOCUS_CLICK(Fw) ||
-			    get_focus_window() != Fw)
+			    get_focus_window() != Fw || was_already_focused)
 			{
-				XAllowEvents(dpy,ReplayPointer,CurrentTime);
-				/*	return;*/
+				/* fall through and pass the click to the app
+				 * later. */
 			}
 			else /* don't pass click to just focused window */
 			{
 				XAllowEvents(dpy,AsyncPointer,CurrentTime);
+				UngrabEm(GRAB_PASSIVE);
 			}
-			UngrabEm(GRAB_PASSIVE);
 		}
 		if (!IS_ICONIFIED(Fw))
 		{
@@ -784,7 +789,8 @@ void HandleConfigureRequest(void)
 	 * Event.xany.window is Event.xconfigurerequest.parent, so Fw will
 	 * be wrong
 	 */
-	Event.xany.window = cre->window;	/* mash parent field */
+	/* mash parent field */
+	Event.xany.window = cre->window;
 	if (XFindContext (dpy, cre->window, FvwmContext, (caddr_t *) &Fw) ==
 	    XCNOENT)
 	{
@@ -793,10 +799,10 @@ void HandleConfigureRequest(void)
 
 	/*
 	 * According to the July 27, 1988 ICCCM draft, we should ignore size
-         * and position fields in the WM_NORMAL_HINTS property when we map a
-         * window. Instead, we'll read the current geometry.  Therefore, we
-         * should respond to configuration requests for windows which have
-         * never been mapped.
+	 * and position fields in the WM_NORMAL_HINTS property when we map a
+	 * window. Instead, we'll read the current geometry.  Therefore, we
+	 * should respond to configuration requests for windows which have
+	 * never been mapped.
 	 */
 	if (!Fw || cre->window == FW_W_ICON_TITLE(Fw) ||
 	    cre->window == FW_W_ICON_PIXMAP(Fw))
@@ -878,17 +884,17 @@ void HandleConfigureRequest(void)
 		}
 	}
 
-	/*  Stacking order change requested...  */
+	/*  Stacking order change requested...	*/
 	/*  Handle this *after* geometry changes, since we need the new
 	    geometry in occlusion calculations */
-	if ( (cre->value_mask & CWStackMode) && !DO_IGNORE_RESTACK(Fw) )
+	if ((cre->value_mask & CWStackMode) && !DO_IGNORE_RESTACK(Fw))
 	{
 		FvwmWindow *otherwin = NULL;
 
 		if (cre->value_mask & CWSibling)
 		{
-			if (XFindContext (dpy, cre->above, FvwmContext,
-					  (caddr_t *) &otherwin) == XCNOENT)
+			if (XFindContext(dpy, cre->above, FvwmContext,
+					 (caddr_t *) &otherwin) == XCNOENT)
 			{
 				otherwin = NULL;
 			}
@@ -899,8 +905,9 @@ void HandleConfigureRequest(void)
 		}
 		if ((cre->detail != Above) && (cre->detail != Below))
 		{
-			HandleUnusualStackmodes (cre->detail, Fw, cre->window,
-						 otherwin, cre->above);
+			HandleUnusualStackmodes(
+				cre->detail, Fw, cre->window, otherwin,
+				cre->above);
 		}
 		/* only allow clients to restack windows within their layer */
 		else if (!otherwin || compare_window_layers(otherwin, Fw) != 0)
@@ -920,7 +927,7 @@ void HandleConfigureRequest(void)
 			xwc.sibling = FW_W_FRAME(otherwin);
 			xwc.stack_mode = cre->detail;
 			xwcm = CWSibling | CWStackMode;
-			XConfigureWindow (dpy, FW_W_FRAME(Fw), xwcm, &xwc);
+			XConfigureWindow(dpy, FW_W_FRAME(Fw), xwcm, &xwc);
 
 			/* Maintain the condition that icon windows are stacked
 			   immediately below their frame */
@@ -1012,8 +1019,14 @@ void HandleConfigureRequest(void)
 		args.do_return_true_cr = True;
 		args.cr_value_mask =
 			(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
+#if 0
 		/* free some CPU */
+		/* dv (7 May 2002): No, it's better to reschedule processes here
+		 * because some funny applications (XMMS, GTK) seem to expect
+		 * that ConfigureRequests are handles instantly or they will
+		 * freak out. */
 		usleep(1);
+#endif
 		while (1)
 		{
 			unsigned long vma;
@@ -1033,7 +1046,7 @@ void HandleConfigureRequest(void)
 			{
 				/* Can't merge events with a PropertyNotify in
 				 * between.  The event is still on the queue.
-                                 */
+				 */
 				break;
 			}
 			else if (args.ret_type != ConfigureRequest)
@@ -1092,12 +1105,14 @@ void HandleConfigureRequest(void)
 
 #if 0
 		fprintf(stderr,
-			"cre: %d(%d) %d(%d) %d(%d)x%d(%d) w 0x%08x '%s'\n",
+			"cre: %d(%d) %d(%d) %d(%d)x%d(%d) fw 0x%08x w 0x%08x "
+			"ew 0x%08x  '%s'\n",
 			cre->x, (int)(cre->value_mask & CWX),
 			cre->y, (int)(cre->value_mask & CWY),
 			cre->width, (int)(cre->value_mask & CWWidth),
 			cre->height, (int)(cre->value_mask & CWHeight),
-			(int)FW_W(Fw), (Fw->name) ? Fw->name : "");
+			(int)FW_W_FRAME(Fw), (int)FW_W(Fw), (int)cre->window,
+			(Fw->name.name) ? Fw->name.name : "");
 #endif
 		/* Don't modify frame_XXX fields before calling SetupWindow! */
 		dx = 0;
@@ -1173,7 +1188,7 @@ void HandleConfigureRequest(void)
 		/*
 		 * SetupWindow (x,y) are the location of the upper-left outer
 		 * corner and are passed directly to XMoveResizeWindow (frame).
-		 *  The (width,height) are the inner size of the frame.  The
+		 *  The (width,height) are the inner size of the frame.	 The
 		 * inner width is the same as the requested client window
 		 * width; the inner height is the same as the requested client
 		 * window height plus any title bar slop.
@@ -1227,7 +1242,7 @@ void HandleConfigureRequest(void)
 			{
 				get_shaded_geometry(Fw, &new_g, &new_g);
 			}
-			frame_setup_window(
+			frame_setup_window_app_request(
 				Fw, new_g.x, new_g.y, new_g.width,
 				new_g.height, False);
 			/* make sure the window structure has the new position
@@ -1293,6 +1308,30 @@ void HandleEnterNotify(void)
 
 	DBUG("HandleEnterNotify","Routine Entered");
 
+	if (Scr.ColormapFocus == COLORMAP_FOLLOWS_MOUSE)
+	{
+		if (Fw && !IS_ICONIFIED(Fw) && Event.xany.window == FW_W(Fw))
+		{
+			InstallWindowColormaps(Fw);
+		}
+		else
+		{
+			/* make sure its for one of our windows */
+			/* handle a subwindow cmap */
+			InstallWindowColormaps(NULL);
+		}
+	}
+	else if (!Fw)
+	{
+		EnterSubWindowColormap(Event.xany.window);
+	}
+	if (Scr.focus_in_pending_window != NULL)
+	{
+		/* Ignore EnterNotify event while we are waiting for a window to
+		 * receive focus via Focus or FlipFocus commands. */
+
+		return;
+	}
 	if (Scr.flags.is_wire_frame_displayed)
 	{
 		/* Ignore EnterNotify events while a window is resized or moved
@@ -1338,7 +1377,7 @@ void HandleEnterNotify(void)
 		/* Ignore events generated by grabbing or ungrabbing the
 		 * pointer.  However, there is no way to prevent the client
 		 * application from handling this event and, for example,
-		 * grabbing the focus.  This will interfere with functions that
+		 * grabbing the focus.	This will interfere with functions that
 		 * transferred the focus to a different window. */
 		if (is_initial_ungrab_pending)
 		{
@@ -1378,8 +1417,8 @@ void HandleEnterNotify(void)
 	    XCheckTypedWindowEvent(dpy, ewp->window, LeaveNotify, &d))
 	{
 		StashEventTime(&d);
-		if ((d.xcrossing.mode==NotifyNormal)&&
-		   (d.xcrossing.detail!=NotifyInferior))
+		if (d.xcrossing.mode == NotifyNormal &&
+		    d.xcrossing.detail!=NotifyInferior)
 		{
 			return;
 		}
@@ -1423,52 +1462,64 @@ void HandleEnterNotify(void)
 		Scr.flags.is_pointer_on_this_screen = 1;
 	}
 
-	/* an EnterEvent in one of the PanFrameWindows activates the Paging or 
+	/* an EnterEvent in one of the PanFrameWindows activates the Paging or
 	   an EdgeCommand */
 	if (ewp->window==Scr.PanFrameTop.win
 	    || ewp->window==Scr.PanFrameLeft.win
 	    || ewp->window==Scr.PanFrameRight.win
-	    || ewp->window==Scr.PanFrameBottom.win )
+	    || ewp->window==Scr.PanFrameBottom.win)
 	{
 
-	  /* check for edge commands */
-	  if ( ewp->window == Scr.PanFrameTop.win &&
-	       Scr.PanFrameTop.command != NULL ) {
-	    old_execute_function(NULL,Scr.PanFrameTop.command, Fw, &Event,C_WINDOW, -1, 0, NULL);
-	  }
-	  else if ( ewp->window == Scr.PanFrameBottom.win &&
-		    Scr.PanFrameBottom.command != NULL )  {
-	    old_execute_function(NULL,Scr.PanFrameBottom.command, Fw, &Event,C_WINDOW, -1, 0, NULL);
-	  }
-	  else if ( ewp->window == Scr.PanFrameLeft.win &&
-		    Scr.PanFrameLeft.command != NULL )  {
-	    old_execute_function(NULL,Scr.PanFrameLeft.command, Fw, &Event,C_WINDOW, -1, 0, NULL);
-	  }
-	  else if ( ewp->window == Scr.PanFrameRight.win &&
-		    Scr.PanFrameRight.command != NULL )  {
-	    old_execute_function(NULL,Scr.PanFrameRight.command, Fw, &Event,C_WINDOW, -1, 0, NULL);
-	  }
-	  else {
-	    /* no edge command for this pan frame - so we do HandlePaging */
+		/* check for edge commands */
+		if (ewp->window == Scr.PanFrameTop.win &&
+		    Scr.PanFrameTop.command != NULL)
+		{
+			old_execute_function(
+				NULL, Scr.PanFrameTop.command, Fw, &Event,
+				C_WINDOW, -1, 0, NULL);
+		}
+		else if (ewp->window == Scr.PanFrameBottom.win &&
+			 Scr.PanFrameBottom.command != NULL)
+		{
+			old_execute_function(
+				NULL, Scr.PanFrameBottom.command, Fw, &Event,
+				C_WINDOW, -1, 0, NULL);
+		}
+		else if (ewp->window == Scr.PanFrameLeft.win &&
+			 Scr.PanFrameLeft.command != NULL)
+		{
+			old_execute_function(
+				NULL, Scr.PanFrameLeft.command, Fw, &Event,
+				C_WINDOW, -1, 0, NULL);
+		}
+		else if (ewp->window == Scr.PanFrameRight.win &&
+			 Scr.PanFrameRight.command != NULL)
+		{
+			old_execute_function(
+				NULL, Scr.PanFrameRight.command, Fw, &Event,
+				C_WINDOW, -1, 0, NULL);
+		}
+		else
+		{
+			/* no edge command for this pan frame - so we do
+			 * HandlePaging */
 
-		int delta_x=0, delta_y=0;
+			int delta_x = 0;
+			int delta_y = 0;
 
-		/* this was in the HandleMotionNotify before, HEDU */
-		Scr.flags.is_pointer_on_this_screen = 1;
-		HandlePaging(Scr.EdgeScrollX,Scr.EdgeScrollY,
-			     &ewp->x_root,&ewp->y_root,
-			     &delta_x,&delta_y,True,True,False);
-		return;
-	  }
+			/* this was in the HandleMotionNotify before, HEDU */
+			Scr.flags.is_pointer_on_this_screen = 1;
+			HandlePaging(
+				Scr.EdgeScrollX,Scr.EdgeScrollY, &ewp->x_root,
+				&ewp->y_root, &delta_x, &delta_y, True, True,
+				False);
+			return;
+		}
 	}
-	/* make sure its for one of our windows */
 	if (!Fw)
 	{
-		/* handle a subwindow cmap */
-		EnterSubWindowColormap(Event.xany.window);
 		return;
 	}
-
 	BroadcastPacket(
 		MX_ENTER_WINDOW, 3, FW_W(Fw), FW_W_FRAME(Fw),
 		(unsigned long)Fw);
@@ -1495,22 +1546,11 @@ void HandleEnterNotify(void)
 		 do_accept_input_focus(Fw))
 	{
 		/* We have to refresh the focus window here in case we left the
-		 * focused fvwm window.  Motif apps may lose the input focus
+		 * focused fvwm window.	 Motif apps may lose the input focus
 		 * otherwise.  But do not try to refresh the focus of
 		 * applications that want to handle it themselves. */
 		FOCUS_SET(FW_W(Fw));
 	}
-	if (Scr.ColormapFocus == COLORMAP_FOLLOWS_MOUSE)
-	{
-		if ((!IS_ICONIFIED(Fw))&&(Event.xany.window == FW_W(Fw)))
-		{
-			InstallWindowColormaps(Fw);
-		}
-		else
-		{
-			InstallWindowColormaps(NULL);
-		}
-	}
 	/* We get an EnterNotify with mode == UnGrab when fvwm releases the
 	 * grab held during iconification. We have to ignore this, or icon
 	 * title will be initially raised. */
@@ -1541,8 +1581,8 @@ void HandleExpose(void)
 {
 #if 0
 	/* This doesn't work well. Sometimes, the expose count is zero although
-	 * dozens of expose events are pending.  This happens all the time
-	 * during a shading animation.  Simply flush expose events
+	 * dozens of expose events are pending.	 This happens all the time
+	 * during a shading animation.	Simply flush expose events
 	 * unconditionally. */
 	if (Event.xexpose.count != 0)
 	{
@@ -1596,16 +1636,21 @@ void HandleFocusIn(void)
 
 	DBUG("HandleFocusIn","Routine Entered");
 
+	Scr.focus_in_pending_window = NULL;
 	/* This is a hack to make the PointerKey command work */
 	if (Event.xfocus.detail != NotifyPointer)
+	{
 		/**/
-		w= Event.xany.window;
+		w = Event.xany.window;
+	}
 	while (XCheckTypedEvent(dpy, FocusIn, &d))
 	{
 		/* dito */
 		if (d.xfocus.detail != NotifyPointer)
+		{
 			/**/
 			w = d.xany.window;
+		}
 	}
 	/* dito */
 	if (w == None)
@@ -1709,6 +1754,8 @@ void HandleFocusIn(void)
 		focus_grab_buttons(sf, True);
 		focus_grab_buttons(ffw_old, False);
 	}
+
+	return;
 }
 
 void HandleFocusOut(void)
@@ -1745,7 +1792,7 @@ void HandleKeyPress(void)
 	 * the cases to one keycode. */
 	Event.xkey.keycode =
 		XKeysymToKeycode(
-			dpy,XKeycodeToKeysym(dpy,Event.xkey.keycode,0));
+			dpy, XKeycodeToKeysym(dpy, Event.xkey.keycode, 0));
 
 	/* Check if there is something bound to the key */
 	action = CheckBinding(
@@ -1797,10 +1844,10 @@ void HandleLeaveNotify(void)
 		/* Ignore events generated by grabbing or ungrabbing the
 		 * pointer.  However, there is no way to prevent the client
 		 * application from handling this event and, for example,
-		 * grabbing the focus.  This will interfere with functions that
+		 * grabbing the focus.	This will interfere with functions that
 		 * transferred the focus to a different window. */
 		if (Event.xcrossing.mode == NotifyGrab && Fw &&
-		    (Event.xcrossing.window == FW_W(Fw) ||
+		    (Event.xcrossing.window == FW_W_FRAME(Fw) ||
 		     Event.xcrossing.window == FW_W_ICON_TITLE(Fw) ||
 		     Event.xcrossing.window == FW_W_ICON_PIXMAP(Fw)))
 		{
@@ -1827,11 +1874,11 @@ void HandleLeaveNotify(void)
 	 * another screen on a multiple screen display, and we
 	 * need to de-focus and unhighlight to make sure that we
 	 * don't end up with more than one highlighted window at a time */
-	if (Event.xcrossing.window == Scr.Root
+	if (Event.xcrossing.window == Scr.Root &&
 	   /* domivogt (16-May-2000): added this test because somehow fvwm
 	    * sometimes gets a LeaveNotify on the root window although it is
 	    * single screen. */
-	   && Scr.NumberOfScreens > 1)
+	    Scr.NumberOfScreens > 1)
 	{
 		if (Event.xcrossing.mode == NotifyNormal)
 		{
@@ -1946,20 +1993,9 @@ void HandleMapNotify(void)
 			SetFocusWindow(Fw, True, True);
 		}
 	}
-	if (!HAS_BORDER(Fw) && !HAS_TITLE(Fw) &&
-	    is_window_border_minimal(Fw))
-	{
-		border_draw_decorations(
-			Fw, PART_ALL, False, True, CLEAR_ALL, NULL, NULL);
-	}
-	else if (Fw == get_focus_window() && Fw != Scr.Hilite)
-	{
-		/* BUG 679: must redraw decorations here to make sure the
-		 * window is properly hilighted after being de-iconified by a
-		 * key press. */
-		border_draw_decorations(
-			Fw, PART_ALL, True, True, CLEAR_ALL, NULL, NULL);
-	}
+	border_draw_decorations(
+		Fw, PART_ALL, (Fw == get_focus_window()) ? True : False, True,
+		CLEAR_ALL, NULL, NULL);
 	MyXUngrabServer (dpy);
 	SET_MAPPED(Fw, 1);
 	SET_ICONIFIED(Fw, 0);
@@ -2284,12 +2320,12 @@ void HandlePropertyNotify(void)
 	{
 		/* background change */
 		/* _XA_XSETROOT_ID is used by fvwm-root, xli and more (xv sends
-		 * no property  notify?).  _XA_XROOTPMAP_ID is used by Esetroot
+		 * no property	notify?).  _XA_XROOTPMAP_ID is used by Esetroot
 		 * compatible program: the problem here is that with some
 		 * Esetroot compatible program we get the message _before_ the
 		 * background change. This is fixed with Esetroot 9.2 (not yet
 		 * released, 2002-01-14) */
-		if (XRenderSupport)
+		if (XRenderSupport && FRenderGetExtensionSupported())
 		{
 			/* update icon window with some alpha */
 			FvwmWindow *t;
@@ -2441,13 +2477,13 @@ void HandlePropertyNotify(void)
 		 * pixmap or window or has reset the hints to `no icon'.
 		 */
 		if ((Fw->wmhints->flags & IconPixmapHint) ||
-		    (old_wmhints_flags       & IconPixmapHint))
+		    (old_wmhints_flags	     & IconPixmapHint))
 		{
 ICON_DBG((stderr,"hpn: iph changed (%d) '%s'\n", !!(int)(Fw->wmhints->flags & IconPixmapHint), Fw->name));
 			has_icon_pixmap_hint_changed = True;
 		}
 		if ((Fw->wmhints->flags & IconWindowHint) ||
-		    (old_wmhints_flags       & IconWindowHint))
+		    (old_wmhints_flags	     & IconWindowHint))
 		{
 ICON_DBG((stderr,"hpn: iwh changed (%d) '%s'\n", !!(int)(Fw->wmhints->flags & IconWindowHint), Fw->name));
 			has_icon_window_hint_changed = True;
@@ -2566,11 +2602,15 @@ ICON_DBG((stderr,"hpn: icon changed '%s'\n", Fw->name));
 		cie_args.do_return_true_cr = False;
 		cie_args.cr_value_mask = 0;
 		XCheckIfEvent(dpy, &e, test_resizing_event, (char *)&cie_args);
+#if 0
+		/* dv (7 May 2002): Must handle this immediately since xterm
+		 * relies on that behaviour. */
 		if (cie_args.ret_type == PropertyNotify)
 		{
 			/* do nothing */
 			break;
 		}
+#endif
 		was_size_inc_set = IS_SIZE_INC_SET(Fw);
 		old_width_inc = Fw->hints.width_inc;
 		old_height_inc = Fw->hints.height_inc;
@@ -2642,7 +2682,7 @@ ICON_DBG((stderr,"hpn: icon changed '%s'\n", Fw->name));
 				get_relative_geometry(&new_g, &Fw->normal_g);
 				if (IS_SHADED(Fw))
 					get_shaded_geometry(Fw, &new_g, &new_g);
-				frame_setup_window(
+				frame_setup_window_app_request(
 					Fw, new_g.x, new_g.y, new_g.width,
 					new_g.height, False);
 			}
@@ -2655,7 +2695,7 @@ ICON_DBG((stderr,"hpn: icon changed '%s'\n", Fw->name));
 				/* domivogt (07-Apr-2000): as terrible hack to
 				 * work around a xterm bug: when the font size
 				 * is changed in a xterm, xterm simply assumes
-				 * that the wm will grant its new size.  Of
+				 * that the wm will grant its new size.	 Of
 				 * course this is wrong if the xterm is
 				 * maximised.  To make xterm happy, we first
 				 * send a ConfigureNotify with the current
@@ -2685,7 +2725,7 @@ ICON_DBG((stderr,"hpn: icon changed '%s'\n", Fw->name));
 						get_shaded_geometry(
 							Fw, &new_g, &new_g);
 					}
-					frame_setup_window(
+					frame_setup_window_app_request(
 						Fw, new_g.x, new_g.y,
 						new_g.width, new_g.height,
 						False);
@@ -2799,7 +2839,7 @@ void HandleReparentNotify(void)
 /***********************************************************************
  *
  *  Procedure:
- *      HandleShapeNotify - shape notification event handler
+ *	HandleShapeNotify - shape notification event handler
  *
  ***********************************************************************/
 void HandleShapeNotify (void)
@@ -2922,7 +2962,7 @@ void HandleUnmapNotify(void)
 
 	/*
 	 * The program may have unmapped the client window, from either
-	 * NormalState or IconicState.  Handle the transition to WithdrawnState.
+	 * NormalState or IconicState.	Handle the transition to WithdrawnState.
 	 *
 	 * We need to reparent the window back to the root (so that fvwm exiting
 	 * won't cause it to get mapped) and then throw away all state (pretend
@@ -2981,7 +3021,7 @@ void HandleUnmapNotify(void)
  *
  *  Procedure:
  *	HandleVisibilityNotify - record fully visible windows for
- *      use in the RaiseLower function and the OnTop type windows.
+ *	use in the RaiseLower function and the OnTop type windows.
  *
  ************************************************************************/
 void HandleVisibilityNotify(void)
@@ -3024,28 +3064,28 @@ void InitEventHandlerJumpTable(void)
 	{
 		EventHandlerJumpTable[i] = NULL;
 	}
-	EventHandlerJumpTable[Expose] =           HandleExpose;
-	EventHandlerJumpTable[DestroyNotify] =    HandleDestroyNotify;
-	EventHandlerJumpTable[MapRequest] =       HandleMapRequest;
-	EventHandlerJumpTable[MapNotify] =        HandleMapNotify;
-	EventHandlerJumpTable[UnmapNotify] =      HandleUnmapNotify;
-	EventHandlerJumpTable[ButtonPress] =      HandleButtonPress;
-	EventHandlerJumpTable[EnterNotify] =      HandleEnterNotify;
-	EventHandlerJumpTable[LeaveNotify] =      HandleLeaveNotify;
-	EventHandlerJumpTable[FocusIn] =          HandleFocusIn;
-	EventHandlerJumpTable[FocusOut] =         HandleFocusOut;
+	EventHandlerJumpTable[Expose] =		  HandleExpose;
+	EventHandlerJumpTable[DestroyNotify] =	  HandleDestroyNotify;
+	EventHandlerJumpTable[MapRequest] =	  HandleMapRequest;
+	EventHandlerJumpTable[MapNotify] =	  HandleMapNotify;
+	EventHandlerJumpTable[UnmapNotify] =	  HandleUnmapNotify;
+	EventHandlerJumpTable[ButtonPress] =	  HandleButtonPress;
+	EventHandlerJumpTable[EnterNotify] =	  HandleEnterNotify;
+	EventHandlerJumpTable[LeaveNotify] =	  HandleLeaveNotify;
+	EventHandlerJumpTable[FocusIn] =	  HandleFocusIn;
+	EventHandlerJumpTable[FocusOut] =	  HandleFocusOut;
 	EventHandlerJumpTable[ConfigureRequest] = HandleConfigureRequest;
-	EventHandlerJumpTable[ClientMessage] =    HandleClientMessage;
-	EventHandlerJumpTable[PropertyNotify] =   HandlePropertyNotify;
-	EventHandlerJumpTable[KeyPress] =         HandleKeyPress;
+	EventHandlerJumpTable[ClientMessage] =	  HandleClientMessage;
+	EventHandlerJumpTable[PropertyNotify] =	  HandlePropertyNotify;
+	EventHandlerJumpTable[KeyPress] =	  HandleKeyPress;
 	EventHandlerJumpTable[VisibilityNotify] = HandleVisibilityNotify;
-	EventHandlerJumpTable[ColormapNotify] =   HandleColormapNotify;
+	EventHandlerJumpTable[ColormapNotify] =	  HandleColormapNotify;
 	if (FShapesSupported)
 	{
 		EventHandlerJumpTable[FShapeEventBase+FShapeNotify] =
 			HandleShapeNotify;
 	}
-	EventHandlerJumpTable[SelectionClear]   = HandleSelectionClear;
+	EventHandlerJumpTable[SelectionClear]	= HandleSelectionClear;
 	EventHandlerJumpTable[SelectionRequest] = HandleSelectionRequest;
 	EventHandlerJumpTable[ReparentNotify] = HandleReparentNotify;
 	STROKE_CODE(EventHandlerJumpTable[ButtonRelease] = HandleButtonRelease);
@@ -3131,7 +3171,7 @@ void HandleEvents(void)
 {
 	DBUG("HandleEvents","Routine Entered");
 	STROKE_CODE(send_motion = FALSE);
-	while ( !isTerminated )
+	while (!isTerminated)
 	{
 		last_event_type = 0;
 		if (Scr.flags.is_window_scheduled_for_destroy)
@@ -3299,9 +3339,11 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 		}
 
 		/* Express route out of FVWM ... */
-		if ( isTerminated ) return 0;
-	}
-	while (num_fd < 0);
+		if (isTerminated)
+		{
+			return 0;
+		}
+	} while (num_fd < 0);
 
 	if (num_fd > 0)
 	{
@@ -3407,8 +3449,8 @@ int GetContext(FvwmWindow *t, XEvent *e, Window *w)
 		XFindContext(dpy, e->xkey.window, FvwmContext, (caddr_t *) &t);
 		Fw = t;
 	}
-	if (e->type == ButtonPress && t && e->xkey.window == FW_W_FRAME(t) &&
-	    e->xkey.subwindow != None)
+	if ((e->type == ButtonPress || e->type == KeyPress) && t &&
+	    e->xkey.window == FW_W_FRAME(t) && e->xkey.subwindow != None)
 	{
 		/* Translate frame coordinates into subwindow coordinates. */
 		e->xkey.window = e->xkey.subwindow;
@@ -3434,13 +3476,16 @@ int GetContext(FvwmWindow *t, XEvent *e, Window *w)
 	{
 		return C_ROOT;
 	}
-	if (e->xkey.subwindow != None && e->xkey.window == FW_W_PARENT(t))
+	if (e->xkey.subwindow != None)
 	{
-		*w = e->xkey.subwindow;
-	}
-	else
-	{
-		e->xkey.subwindow = None;
+		if (e->xkey.window == FW_W_PARENT(t))
+		{
+			*w = e->xkey.subwindow;
+		}
+		else
+		{
+			e->xkey.subwindow = None;
+		}
 	}
 	if (*w == Scr.Root)
 	{
@@ -3565,7 +3610,10 @@ Bool StashEventTime (XEvent *ev)
 	 * old one (in which case the system clock may have changed) */
 	if (NewTimestamp > lastTimestamp ||
 	    lastTimestamp - NewTimestamp > CLOCK_SKEW_MS)
+	{
 		lastTimestamp = NewTimestamp;
+	}
+
 	return True;
 }
 
@@ -3578,25 +3626,48 @@ Bool StashEventTime (XEvent *ev)
  * that behaviour is correct and desirable. --11/08/97 gjb */
 void CoerceEnterNotifyOnCurrentWindow(void)
 {
-	extern FvwmWindow *Fw; /* from events.c */
-	Window child, root;
-	int root_x, root_y;
-	int win_x, win_y;
-	Bool f = XQueryPointer(dpy, Scr.Root, &root,
-			       &child, &root_x, &root_y, &win_x, &win_y,
-			       &JunkMask);
+	Window child;
+	Window root;
+	Bool f;
 
+	f = XQueryPointer(
+		dpy, Scr.Root, &root, &child, &Event.xcrossing.x_root,
+		&Event.xcrossing.y_root, &Event.xcrossing.x, &Event.xcrossing.y,
+		&JunkMask);
 	if (f && child != None)
 	{
-		Event.xany.window = child;
+		Event.xcrossing.type = EnterNotify;
+		Event.xcrossing.window = child;
+		Event.xcrossing.subwindow = None;
+		Event.xcrossing.mode = NotifyNormal;
+		Event.xcrossing.detail = NotifyAncestor;
+		Event.xcrossing.same_screen = True;
+		Event.xcrossing.focus =
+			(Fw == get_focus_window()) ? True : False;
 		if (XFindContext(dpy, child, FvwmContext, (caddr_t *) &Fw) ==
 		    XCNOENT)
 		{
 			Fw = NULL;
 		}
+		else
+		{
+			XTranslateCoordinates(
+				dpy, Scr.Root, child, Event.xcrossing.x_root,
+				Event.xcrossing.y_root, &JunkX, &JunkY, &child);
+			if (child == FW_W_PARENT(Fw))
+			{
+				child = FW_W(Fw);
+			}
+			if (child != None)
+			{
+				Event.xany.window = child;
+			}
+		}
 		HandleEnterNotify();
 		Fw = None;
 	}
+
+	return;
 }
 
 /* This function discards all queued up ButtonPress, ButtonRelease and
@@ -3664,6 +3735,8 @@ void WaitForButtonsUp(Bool do_handle_expose)
 	unsigned int mask;
 	long evmask = ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|
 		KeyPressMask|KeyReleaseMask;
+        unsigned int count;
+        int use_wait_cursor;
 
 	if (XQueryPointer(dpy, Scr.Root, &JunkRoot, &JunkChild, &JunkX, &JunkY,
 			  &JunkX, &JunkY, &mask) == False)
@@ -3675,9 +3748,12 @@ void WaitForButtonsUp(Bool do_handle_expose)
 		return;
 	}
 	if (do_handle_expose)
+        {
 		evmask |= ExposureMask;
-	GrabEm(CRS_WAIT, GRAB_NORMAL);
-	while (mask & (DEFAULT_ALL_BUTTONS_MASK))
+        }
+	GrabEm(None, GRAB_NORMAL);
+        for (count = 0, use_wait_cursor = 0; mask & (DEFAULT_ALL_BUTTONS_MASK);
+             count++)
 	{
 		/* handle expose events */
 		XAllowEvents(dpy, SyncPointer, CurrentTime);
@@ -3708,8 +3784,18 @@ void WaitForButtonsUp(Bool do_handle_expose)
 				 * okay here */
 			}
 		}
+                usleep(1);
+                if (use_wait_cursor == 0 && count == 20)
+                {
+                        GrabEm(CRS_WAIT, GRAB_NORMAL);
+                        use_wait_cursor = 1;
+                }
 	}
 	UngrabEm(GRAB_NORMAL);
+        if (use_wait_cursor)
+        {
+                UngrabEm(GRAB_NORMAL);
+        }
 
 	return;
 }
