@@ -21,23 +21,23 @@
 
 /* ---------------------------- global definitions -------------------------- */
 
-#define XEVMASK_FRAMEW  (SubstructureRedirectMask | VisibilityChangeMask| \
-                         EnterWindowMask | LeaveWindowMask)
-#define XEVMASK_DECORW  (ExposureMask | ButtonPressMask | ButtonReleaseMask | \
-			 KeyPressMask)
-#define XEVMASK_TITLEW  (ButtonPressMask | ButtonReleaseMask | \
+#define XEVMASK_FRAMEW	(SubstructureRedirectMask | VisibilityChangeMask| \
+			 EnterWindowMask | LeaveWindowMask)
+#define XEVMASK_TITLEW	(ButtonPressMask | ButtonReleaseMask | \
 			 OwnerGrabButtonMask | \
-			 ButtonMotionMask | PointerMotionMask)
+			 ButtonMotionMask | PointerMotionMask | \
+			 EnterWindowMask | LeaveWindowMask)
 #define XEVMASK_BUTTONW XEVMASK_TITLEW
 #define XEVMASK_PARENTW (SubstructureRedirectMask)
-#define XEVMASK_BORDERW (ButtonPressMask | ButtonReleaseMask)
+#define XEVMASK_BORDERW (ButtonPressMask | ButtonReleaseMask | \
+			 EnterWindowMask | LeaveWindowMask)
 #define XEVMASK_CLIENTW (StructureNotifyMask | PropertyChangeMask | \
 			 EnterWindowMask | LeaveWindowMask | \
 			 ColormapChangeMask | FocusChangeMask)
-#define XEVMASK_ICONW   (ButtonPressMask | ButtonReleaseMask | \
+#define XEVMASK_ICONW	(ButtonPressMask | ButtonReleaseMask | \
 			 VisibilityChangeMask | ExposureMask | KeyPressMask | \
 			 EnterWindowMask | LeaveWindowMask | FocusChangeMask)
-#define XEVMASK_ICONPW  XEVMASK_ICONW
+#define XEVMASK_ICONPW	XEVMASK_ICONW
 #define XEVMASK_MENU \
   (ButtonPressMask | ButtonReleaseMask | ExposureMask | KeyReleaseMask | \
    KeyPressMask | VisibilityChangeMask | ButtonMotionMask | PointerMotionMask)
@@ -49,18 +49,18 @@
   (XEVMASK_MENUW | EnterWindowMask | LeaveWindowMask | StructureNotifyMask)
 #define XEVMASK_TEAR_OFF_SUBMENUW \
   (XEVMASK_MENUW | LeaveWindowMask)
-#define XEVMASK_PANFW   (ButtonPressMask | ButtonReleaseMask | \
- 		         KeyReleaseMask | KeyPressMask | \
-                         EnterWindowMask | LeaveWindowMask | \
-                         VisibilityChangeMask)
+#define XEVMASK_PANFW	(ButtonPressMask | ButtonReleaseMask | \
+			 KeyReleaseMask | KeyPressMask | \
+			 EnterWindowMask | LeaveWindowMask | \
+			 VisibilityChangeMask)
 #define XEVMASK_NOFOCUSW (KeyPressMask|FocusChangeMask)
-#define XEVMASK_MENUNFW  (KeyPressMask|KeyReleaseMask|FocusChangeMask)
-#define XEVMASK_ORW     (FocusChangeMask)
-#define XEVMASK_ROOTW   (LeaveWindowMask| EnterWindowMask | \
-          PropertyChangeMask | SubstructureRedirectMask | KeyPressMask | \
-          SubstructureNotifyMask | ColormapChangeMask | \
-          STROKE_CODE(ButtonMotionMask | DEFAULT_ALL_BUTTONS_MOTION_MASK |) \
-          ButtonPressMask | ButtonReleaseMask)
+#define XEVMASK_MENUNFW	 (KeyPressMask|KeyReleaseMask|FocusChangeMask)
+#define XEVMASK_ORW	(FocusChangeMask)
+#define XEVMASK_ROOTW	(LeaveWindowMask| EnterWindowMask | \
+	  PropertyChangeMask | SubstructureRedirectMask | KeyPressMask | \
+	  SubstructureNotifyMask | ColormapChangeMask | \
+	  STROKE_CODE(ButtonMotionMask | DEFAULT_ALL_BUTTONS_MOTION_MASK |) \
+	  ButtonPressMask | ButtonReleaseMask)
 
 /* ---------------------------- global macros ------------------------------- */
 
