@@ -7,12 +7,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -26,6 +26,7 @@
 #include "libs/PictureBase.h"
 #include "libs/Picture.h"
 #include "libs/PictureImageLoader.h"
+#include "libs/FRenderInit.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "window_flags.h"
@@ -86,18 +87,18 @@ int ewmh_WMIcon(EWMH_CMD_ARGS)
       /* No net icon or we have set the net icon */
       if (DO_EWMH_DONATE_MINI_ICON(fwin) &&
 	(dummy = ewmh_SetWmIconFromPixmap(fwin,
-                                          (new_list != NULL)? new_list : list,
-                                          &size, True)) != NULL)
+					  (new_list != NULL)? new_list : list,
+					  &size, True)) != NULL)
       {
-        SET_HAS_EWMH_WM_ICON_HINT(fwin, EWMH_FVWM_ICON);
-        free(dummy);
+	SET_HAS_EWMH_WM_ICON_HINT(fwin, EWMH_FVWM_ICON);
+	free(dummy);
       }
     }
     else
     {
       /* the application has a true ewmh icon */
       if (EWMH_SetIconFromWMIcon(fwin, list, size, True))
-        SET_HAS_EWMH_MINI_ICON(fwin, True);
+	SET_HAS_EWMH_MINI_ICON(fwin, True);
     }
   }
 
@@ -377,7 +378,7 @@ CARD32 *ewmh_SetWmIconFromPixmap(FvwmWindow *fwin,
 			}
 		}
 		break;
-		
+
 	}
 	default: /* depth = Pdepth */
 	{
@@ -406,7 +407,7 @@ CARD32 *ewmh_SetWmIconFromPixmap(FvwmWindow *fwin,
 					{
 						cm[m++] = 255;
 					}
-					colors[k++].pixel = 
+					colors[k++].pixel =
 						XGetPixel(image, i, j);
 				}
 			}
@@ -570,7 +571,7 @@ void EWMH_DeleteWmIcon(FvwmWindow *fwin, Bool mini_icon, Bool icon)
   {
     /*SET_HAS_EWMH_WM_ICON_HINT(fwin, EWMH_NO_ICON);*/
     ewmh_DeleteProperty(FW_W(fwin), "_NET_WM_ICON",
-                        EWMH_ATOM_LIST_PROPERTY_NOTIFY);
+			EWMH_ATOM_LIST_PROPERTY_NOTIFY);
   }
 
   if (mini_icon)
@@ -611,7 +612,7 @@ void extract_wm_icon(CARD32 *list, unsigned int size, int wanted_w, int wanted_h
       if (i + 1 + list[i]*list[i+1] < size)
       {
 	if (*best_w == 0 && *best_h == 0)
-        {
+	{
 	  *start_best = i+2;
 	  *best_w = list[i];
 	  *best_h = list[i+1];
@@ -637,7 +638,7 @@ void extract_wm_icon(CARD32 *list, unsigned int size, int wanted_w, int wanted_h
   return;
 }
 
-#define MINI_ICON_WANTED_WIDTH  16
+#define MINI_ICON_WANTED_WIDTH	16
 #define MINI_ICON_WANTED_HEIGHT 16
 #define MINI_ICON_MAX_WIDTH 22
 #define MINI_ICON_MAX_HEIGHT 22
@@ -649,115 +650,153 @@ void extract_wm_icon(CARD32 *list, unsigned int size, int wanted_w, int wanted_h
 int EWMH_SetIconFromWMIcon(FvwmWindow *fwin, CARD32 *list, unsigned int size,
 			   Bool is_mini_icon)
 {
-  int start, width, height;
-  int wanted_w, wanted_h;
-  int max_w, max_h;
-  Pixmap pixmap = None;
-  Pixmap mask = None;
-  Pixmap alpha = None;
-  Bool free_list = False;
-  int have_alpha;
+	int start, width, height;
+	int wanted_w, wanted_h;
+	int max_w, max_h;
+	Pixmap pixmap = None;
+	Pixmap mask = None;
+	Pixmap alpha = None;
+	Bool free_list = False;
+	int have_alpha;
 
-  if (list == NULL)
-  {
-    /* we are called from icons.c or update.c */
-    list = ewmh_AtomGetByName(FW_W(fwin),"_NET_WM_ICON",
-			      EWMH_ATOM_LIST_PROPERTY_NOTIFY, &size);
-    free_list = True;
-    if (list == NULL)
-      return 0;
-  }
+	if (list == NULL)
+	{
+		/* we are called from icons.c or update.c */
+		list = ewmh_AtomGetByName(FW_W(fwin),"_NET_WM_ICON",
+					  EWMH_ATOM_LIST_PROPERTY_NOTIFY, &size);
+		free_list = True;
+		if (list == NULL)
+			return 0;
+	}
 
-  if (is_mini_icon)
-  {
-    wanted_w = MINI_ICON_WANTED_WIDTH;
-    wanted_h = MINI_ICON_WANTED_HEIGHT;
-    max_w = MINI_ICON_MAX_WIDTH;
-    max_h = ICON_MAX_HEIGHT;
-  }
-  else
-  {
-    wanted_w = ICON_WANTED_WIDTH;
-    wanted_h = ICON_WANTED_HEIGHT;
-    max_w = ICON_MAX_WIDTH;
-    max_h = ICON_MAX_HEIGHT;
-  }
+	if (is_mini_icon)
+	{
+		wanted_w = MINI_ICON_WANTED_WIDTH;
+		wanted_h = MINI_ICON_WANTED_HEIGHT;
+		max_w = MINI_ICON_MAX_WIDTH;
+		max_h = ICON_MAX_HEIGHT;
+	}
+	else
+	{
+		wanted_w = ICON_WANTED_WIDTH;
+		wanted_h = ICON_WANTED_HEIGHT;
+		max_w = ICON_MAX_WIDTH;
+		max_h = ICON_MAX_HEIGHT;
+	}
 
-  extract_wm_icon(list, size, wanted_w, wanted_h, &start, &width, &height);
-  if (width == 0 || height == 0 || width > max_w || height > max_h)
-  {
-    if (free_list)
-      free(list);
-    return 0;
-  }
+	extract_wm_icon(list, size, wanted_w, wanted_h, &start, &width, &height);
+	if (width == 0 || height == 0)
+	{
+		if (free_list)
+			free(list);
+		return 0;
+	}
 
-  pixmap = XCreatePixmap(dpy, Scr.NoFocusWin, width, height, Pdepth);
-  mask = XCreatePixmap(dpy, Scr.NoFocusWin, width, height, 1);
-  if (XRenderSupport)
-  {
-	  alpha = XCreatePixmap(dpy, Scr.NoFocusWin, width, height, 8);
-  }
-  if (!PImageCreatePixmapFromArgbData(dpy, Scr.Root, Scr.ColorLimit,
-				      (unsigned char *)list,
-				      start, width, height,
-				      pixmap, mask, alpha, &have_alpha)
-      || pixmap == None)
-  {
-    fvwm_msg(ERR, "EWMH_SetIconFromWMIcon","fail to create a pixmap\n");
-    if (pixmap != None)
-      XFreePixmap(dpy, pixmap);
-    if (mask != None)
-      XFreePixmap(dpy, mask);
-    if (alpha != None)
-      XFreePixmap(dpy, alpha);
-    if (free_list)
-      free(list);
-    return 0;
-  }
-  if (!have_alpha && alpha != None)
-  {
-	  XFreePixmap(dpy, alpha);
-	  alpha = None;
-  }
+	pixmap = XCreatePixmap(dpy, Scr.NoFocusWin, width, height, Pdepth);
+	mask = XCreatePixmap(dpy, Scr.NoFocusWin, width, height, 1);
+	if (XRenderSupport && FRenderGetExtensionSupported())
+	{
+		alpha = XCreatePixmap(dpy, Scr.NoFocusWin, width, height, 8);
+	}
+	if (!PImageCreatePixmapFromArgbData(dpy, Scr.Root, Scr.ColorLimit,
+					    (unsigned char *)list,
+					    start, width, height,
+					    pixmap, mask, alpha, &have_alpha)
+	    || pixmap == None)
+	{
+		fvwm_msg(ERR, "EWMH_SetIconFromWMIcon",
+			 "fail to create a pixmap\n");
+		if (pixmap != None)
+			XFreePixmap(dpy, pixmap);
+		if (mask != None)
+			XFreePixmap(dpy, mask);
+		if (alpha != None)
+			XFreePixmap(dpy, alpha);
+		if (free_list)
+			free(list);
+		return 0;
+	}
+	if (!have_alpha && alpha != None)
+	{
+		XFreePixmap(dpy, alpha);
+		alpha = None;
+	}
 
-  if (FMiniIconsSupported && is_mini_icon && !DO_EWMH_MINI_ICON_OVERRIDE(fwin))
-  {
-    char *name = NULL;
+	if (width > max_w || height > max_h)
+	{
+		Pixmap np = None,nm =None, na = None;
 
-    CopyString(&name,"ewmh_mini_icon");
-    if (fwin->mini_icon)
-    {
-	PDestroyFvwmPicture(dpy,fwin->mini_icon);
-	fwin->mini_icon = 0;
-    }
-    fwin->mini_icon = PCacheFvwmPictureFromPixmap(dpy, Scr.NoFocusWin,
-						  name,pixmap, mask, alpha,
-						  width, height);
-    if (fwin->mini_icon != NULL)
-    {
-      fwin->mini_pixmap_file = name;
-      BroadcastFvwmPicture(M_MINI_ICON,
-			   FW_W(fwin), FW_W_FRAME(fwin), (unsigned long)fwin,
-			   fwin->mini_icon,
-			   fwin->mini_pixmap_file);
-      border_redraw_decorations(fwin);
-    }
-  }
-  if (!is_mini_icon)
-  {
-    fwin->iconPixmap = pixmap;
-    fwin->icon_maskPixmap = mask;
-    fwin->icon_alphaPixmap = alpha;
-    fwin->icon_g.picture_w_g.width = width;
-    fwin->icon_g.picture_w_g.height = height;
-    fwin->iconDepth = Pdepth;
-    SET_PIXMAP_OURS(fwin, 1);
-    if (FShapesSupported && mask && !alpha)
-      SET_ICON_SHAPED(fwin, 1);
-  }
-  if (free_list)
-    free(list);
-  return 1;
+		if (pixmap)
+		{
+			np = CreateStretchPixmap(dpy, pixmap, width, height,
+						 Pdepth, wanted_w, wanted_h,
+						 Scr.TitleGC);
+			XFreePixmap(dpy, pixmap);
+			pixmap = np;
+		}
+		if (mask)
+		{
+			nm = CreateStretchPixmap(dpy, mask, width, height,
+						 1, wanted_w, wanted_h,
+						 Scr.MonoGC);
+			XFreePixmap(dpy, mask);
+			mask = nm;
+		}
+		if (alpha)
+		{
+			GC my_gc = fvwmlib_XCreateGC(dpy, alpha, 0, 0);
+			na = CreateStretchPixmap(dpy, alpha, width, height,
+						 8, wanted_w, wanted_h,
+						 my_gc);
+			XFreePixmap(dpy, alpha);
+			XFreeGC(dpy, my_gc);
+			alpha = na;
+		}
+		width = wanted_w;
+		height = wanted_h;
+	}
+	if (FMiniIconsSupported && is_mini_icon &&
+	    !DO_EWMH_MINI_ICON_OVERRIDE(fwin))
+	{
+		char *name = NULL;
+
+		CopyString(&name,"ewmh_mini_icon");
+		if (fwin->mini_icon)
+		{
+			PDestroyFvwmPicture(dpy,fwin->mini_icon);
+			fwin->mini_icon = 0;
+		}
+		fwin->mini_icon = PCacheFvwmPictureFromPixmap(dpy,
+							      Scr.NoFocusWin,
+							      name,
+							      pixmap,mask,alpha,
+							      width, height);
+		if (fwin->mini_icon != NULL)
+		{
+			fwin->mini_pixmap_file = name;
+			BroadcastFvwmPicture(M_MINI_ICON,
+					     FW_W(fwin), FW_W_FRAME(fwin),
+					     (unsigned long)fwin,
+					     fwin->mini_icon,
+					     fwin->mini_pixmap_file);
+			border_redraw_decorations(fwin);
+		}
+	}
+	if (!is_mini_icon)
+	{
+		fwin->iconPixmap = pixmap;
+		fwin->icon_maskPixmap = mask;
+		fwin->icon_alphaPixmap = alpha;
+		fwin->icon_g.picture_w_g.width = width;
+		fwin->icon_g.picture_w_g.height = height;
+		fwin->iconDepth = Pdepth;
+		SET_PIXMAP_OURS(fwin, 1);
+		if (FShapesSupported && mask && !alpha)
+			SET_ICON_SHAPED(fwin, 1);
+	}
+	if (free_list)
+		free(list);
+	return 1;
 }
 
 #endif /* HAVE_EWMH */
