@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /****************************************************************************
@@ -41,8 +41,10 @@
 #include "libs/fvwmlib.h"
 #include "libs/FScreen.h"
 #include "libs/FShape.h"
+#include "libs/PictureBase.h"
 #include "libs/Flocale.h"
 #include <libs/gravity.h>
+#include "libs/FRenderInit.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
@@ -81,7 +83,7 @@
 #include <X11/Xresource.h>
 
 #if HAVE_SYS_SYSTEMINFO_H
-/* Solaris has sysinfo instead of gethostname.  */
+/* Solaris has sysinfo instead of gethostname.	*/
 #include <sys/systeminfo.h>
 #endif
 
@@ -94,10 +96,10 @@ static char sccsid[] __attribute__((__unused__))
 
 int master_pid;			/* process number of 1st fvwm process */
 
-ScreenInfo Scr;		        /* structures for the screen */
+ScreenInfo Scr;			/* structures for the screen */
 Display *dpy = NULL;		/* which display are we talking to */
 
-Bool fFvwmInStartup = True;     /* Set to False when startup has finished */
+Bool fFvwmInStartup = True;	/* Set to False when startup has finished */
 Bool DoingCommandLine = False;	/* Set True before each cmd line arg */
 
 /* Grab pointer state. Set by GrabEm, UngrabEm, menus.c and StartupStuff */
@@ -265,38 +267,38 @@ int main(int argc, char **argv)
     else if (strncasecmp(argv[i],"-d",2)==0)
     {
       if (++i >= argc)
-        usage();
+	usage();
       display_name = argv[i];
     }
     else if (strncasecmp(argv[i],"-f",2)==0)
     {
       if (++i >= argc)
-        usage();
+	usage();
       if (num_config_commands < MAX_CFG_CMDS)
       {
-        config_commands[num_config_commands] =
-          (char *)malloc(6+strlen(argv[i]));
-        strcpy(config_commands[num_config_commands],"Read ");
-        strcat(config_commands[num_config_commands],argv[i]);
-        num_config_commands++;
+	config_commands[num_config_commands] =
+	  (char *)malloc(6+strlen(argv[i]));
+	strcpy(config_commands[num_config_commands],"Read ");
+	strcat(config_commands[num_config_commands],argv[i]);
+	num_config_commands++;
       }
       else
       {
-        fvwm_msg(ERR,"main","only %d -f and -cmd parms allowed!",MAX_CFG_CMDS);
+	fvwm_msg(ERR,"main","only %d -f and -cmd parms allowed!",MAX_CFG_CMDS);
       }
     }
     else if (strncasecmp(argv[i],"-cmd",4)==0)
     {
       if (++i >= argc)
-        usage();
+	usage();
       if (num_config_commands < MAX_CFG_CMDS)
       {
-        config_commands[num_config_commands] = safestrdup(argv[i]);
-        num_config_commands++;
+	config_commands[num_config_commands] = safestrdup(argv[i]);
+	num_config_commands++;
       }
       else
       {
-        fvwm_msg(ERR,"main","only %d -f and -cmd parms allowed!",MAX_CFG_CMDS);
+	fvwm_msg(ERR,"main","only %d -f and -cmd parms allowed!",MAX_CFG_CMDS);
       }
     }
     else if (strncasecmp(argv[i],"-h",2)==0)
@@ -318,29 +320,29 @@ int main(int argc, char **argv)
     else if (strncasecmp(argv[i],"-visualId",9)==0) {
       visualClass = -1;
       if (++i >= argc)
-        usage();
+	usage();
       if (sscanf(argv[i], "0x%x", &visualId) == 0)
-        if (sscanf(argv[i], "%d", &visualId) == 0)
-          usage();
+	if (sscanf(argv[i], "%d", &visualId) == 0)
+	  usage();
     }
     else if (strncasecmp(argv[i],"-visual",7)==0) {
       visualId = None;
       if (++i >= argc)
-        usage();
+	usage();
       if (strncasecmp(argv[i], "staticg", 7) == 0)
-        visualClass = StaticGray;
+	visualClass = StaticGray;
       else if (strncasecmp(argv[i], "g", 1) == 0)
-        visualClass = GrayScale;
+	visualClass = GrayScale;
       else if (strncasecmp(argv[i], "staticc", 7) == 0)
-        visualClass = StaticColor;
+	visualClass = StaticColor;
       else if (strncasecmp(argv[i], "p", 1) == 0)
-        visualClass = PseudoColor;
+	visualClass = PseudoColor;
       else if (strncasecmp(argv[i], "t", 1) == 0)
-        visualClass = TrueColor;
+	visualClass = TrueColor;
       else if (strncasecmp(argv[i], "d", 1) == 0)
-        visualClass = DirectColor;
+	visualClass = DirectColor;
       else
-        usage();
+	usage();
     }
     else if (strncasecmp(argv[i], "-version", 8) == 0)
     {
@@ -386,25 +388,25 @@ int main(int argc, char **argv)
     {
       if (i != Scr.screen && fork() == 0)
       {
-        myscreen = i;
+	myscreen = i;
 
-        /*
-         * Truncate the string 'whatever:n.n' to 'whatever:n',
-         * and then append the screen number.
-         */
-        cp = strchr(message, ':');
-        if (cp != NULL)
-        {
-          cp = strchr(cp, '.');
-          if (cp != NULL)
-            *cp = '\0';		/* truncate at display part */
-        }
-        sprintf(message + strlen(message), ".%d", myscreen);
-        Pdpy = dpy = XOpenDisplay(message);
-        Scr.screen = myscreen;
-        Scr.NumberOfScreens = ScreenCount(dpy);
+	/*
+	 * Truncate the string 'whatever:n.n' to 'whatever:n',
+	 * and then append the screen number.
+	 */
+	cp = strchr(message, ':');
+	if (cp != NULL)
+	{
+	  cp = strchr(cp, '.');
+	  if (cp != NULL)
+	    *cp = '\0';		/* truncate at display part */
+	}
+	sprintf(message + strlen(message), ".%d", myscreen);
+	Pdpy = dpy = XOpenDisplay(message);
+	Scr.screen = myscreen;
+	Scr.NumberOfScreens = ScreenCount(dpy);
 
-        break;
+	break;
       }
     }
 
@@ -455,7 +457,7 @@ int main(int argc, char **argv)
     gethostname(client,MAXHOSTNAME);
     rdisplay_string = safemalloc(len+14 + strlen(client));
     sprintf(rdisplay_string,"HOSTDISPLAY=%s:%s",client,
-            &display_string[13]);
+	    &display_string[13]);
     putenv(rdisplay_string);
   }
   else
@@ -482,13 +484,13 @@ int main(int argc, char **argv)
     template.screen = Scr.screen;
     template.class = visualClass;
     vizinfo = XGetVisualInfo(dpy, VisualScreenMask | VisualClassMask, &template,
-                             &total);
+			     &total);
     if (total) {
       for (i = 0; i < total; i++) {
-        if (vizinfo[i].depth > Pdepth) {
-          Pvisual = vizinfo[i].visual;
-          Pdepth = vizinfo[i].depth;
-        }
+	if (vizinfo[i].depth > Pdepth) {
+	  Pvisual = vizinfo[i].visual;
+	  Pdepth = vizinfo[i].depth;
+	}
       }
       XFree(vizinfo);
       /* have to have a colormap for non-default visual windows */
@@ -507,7 +509,7 @@ int main(int argc, char **argv)
     template.screen = Scr.screen;
     template.visualid = visualId;
     vizinfo = XGetVisualInfo(dpy, VisualScreenMask | VisualIDMask, &template,
-                             &total);
+			     &total);
     if (total) {
       /* visualID's are unique so there will only be one */
       Pvisual = vizinfo[0].visual;
@@ -534,6 +536,7 @@ int main(int argc, char **argv)
   PictureSaveFvwmVisual();
 
   FShapeInit(dpy);
+  FRenderInit(dpy);
   Scr.pscreen = XScreenOfDisplay(dpy, Scr.screen);
   Scr.use_backing_store = DoesBackingStore(Scr.pscreen);
   Scr.flags.do_save_under = DoesSaveUnders(Scr.pscreen);
@@ -594,17 +597,16 @@ int main(int argc, char **argv)
 
     if (
       XGetWindowProperty(
-        dpy, Scr.Root, _XA_WM_DESKTOP, 0L, 1L, True, _XA_WM_DESKTOP,
-        &atype, &aformat, &nitems, &bytes_remain, &prop
+	dpy, Scr.Root, _XA_WM_DESKTOP, 0L, 1L, True, _XA_WM_DESKTOP,
+	&atype, &aformat, &nitems, &bytes_remain, &prop
       ) == Success
     ) {
       if (prop != NULL) {
-        Restarting = True;
-        /* do_force_single_screen = True; */
+	Restarting = True;
+	/* do_force_single_screen = True; */
       }
     }
   }
-
   restart_state_filename =
     safestrdup(
       CatString3(fvwm_userdir, "/.fs-restart-", getenv("HOSTDISPLAY")));
@@ -630,6 +632,7 @@ int main(int argc, char **argv)
   Scr.gray_bitmap =
     XCreateBitmapFromData(dpy,Scr.Root,g_bits, g_width,g_height);
 
+  EWMH_Init();
 
   DBUG("main","Setting up rc file defaults...");
   SetRCDefaults();
@@ -652,24 +655,24 @@ int main(int argc, char **argv)
     /* Run startup command file in 5 places: FVWM_USERDIR, FVWM_DATADIR,
        and for compatibility: ~/.fvwm2rc, $sysconfdir/system.fvwm2rc */
     if (
-      !run_command_file( CatString3(fvwm_userdir, "/",       FVWMRC),
-        &Event, NULL, C_ROOT, 1 ) &&
-      !run_command_file( CatString3(home_dir,     "/",       FVWMRC),
-        &Event, NULL, C_ROOT, 1 ) &&
-      !run_command_file( CatString3(FVWM_DATADIR, "/",       FVWMRC),
-        &Event, NULL, C_ROOT, 1 ) &&
+      !run_command_file( CatString3(fvwm_userdir, "/",	     FVWMRC),
+	&Event, NULL, C_ROOT, 1 ) &&
+      !run_command_file( CatString3(home_dir,	  "/",	     FVWMRC),
+	&Event, NULL, C_ROOT, 1 ) &&
+      !run_command_file( CatString3(FVWM_DATADIR, "/",	     FVWMRC),
+	&Event, NULL, C_ROOT, 1 ) &&
       !run_command_file( CatString3(FVWM_DATADIR, "/system", FVWMRC),
-        &Event, NULL, C_ROOT, 1 ) &&
+	&Event, NULL, C_ROOT, 1 ) &&
       !run_command_file( CatString3(FVWM_CONFDIR, "/system", FVWMRC),
-        &Event, NULL, C_ROOT, 1 ) )
+	&Event, NULL, C_ROOT, 1 ) )
     {
       fvwm_msg( ERR, "main", "Cannot read startup file, tried: "
-        "\n\t%s/%s\n\t%s/%s\n\t%s/%s\n\t%s/system%s\n\t%s/system%s",
-          fvwm_userdir, FVWMRC,
-          home_dir,     FVWMRC,
-          FVWM_DATADIR, FVWMRC,
-          FVWM_DATADIR, FVWMRC,
-          FVWM_CONFDIR, FVWMRC);
+	"\n\t%s/%s\n\t%s/%s\n\t%s/%s\n\t%s/system%s\n\t%s/system%s",
+	  fvwm_userdir, FVWMRC,
+	  home_dir,	FVWMRC,
+	  FVWM_DATADIR, FVWMRC,
+	  FVWM_DATADIR, FVWMRC,
+	  FVWM_CONFDIR, FVWMRC);
     }
   }
 
@@ -710,7 +713,6 @@ int main(int argc, char **argv)
 
   SessionInit();
 
-  EWMH_Init();
   GNOME_Init();
 
   DBUG("main","Entering HandleEvents loop...");
@@ -758,10 +760,6 @@ void StartupStuff(void)
 #define startFuncName "StartFunction"
   const char *initFuncName;
 
-  /* make sure colorset 0 exists in case modules get started that use colorsets
-   * and the startup files/commands have not created any */
-  alloc_colorset(0);
-
   CaptureAllWindows(False);
   /* Turn off the SM stuff after the initial capture so that new windows will
    * not be matched by accident. */
@@ -786,14 +784,14 @@ void StartupStuff(void)
   XUngrabPointer(dpy, CurrentTime);
 
   /* migo (04-Sep-1999): execute StartFunction */
-  if (FindFunction(startFuncName)) {
+  if (functions_is_complex_function(startFuncName)) {
     char *action = "Function " startFuncName;
     old_execute_function(NULL, action, NULL, &Event, C_ROOT, 1, 0, NULL);
   }
 
   /* migo (03-Jul-1999): execute [Session]{Init|Restart}Function */
   initFuncName = getInitFunctionName(Restarting == True);
-  if (FindFunction(initFuncName)) {
+  if (functions_is_complex_function(initFuncName)) {
     char *action = safestrdup(CatString2("Function ", initFuncName));
     old_execute_function(NULL, action, NULL, &Event, C_ROOT, 1, 0, NULL);
     free(action);
@@ -857,7 +855,7 @@ void SetRCDefaults(void)
  *
  *  Procedure:
  *	InternUsefulAtoms:
- *            Dont really know what it does
+ *	      Dont really know what it does
  *
  ***********************************************************************
  */
@@ -935,7 +933,7 @@ static void InternUsefulAtoms (void)
  *
  *  Procedure:
  *	InstallSignals: install the signal handlers, using whatever
- *         means we have at our disposal. The more POSIXy, the better
+ *	   means we have at our disposal. The more POSIXy, the better
  *
  ************************************************************************/
 void
@@ -983,9 +981,9 @@ InstallSignals(void)
    * leave SIGCHLD handler with unfinished business ...
    *
    * NOTE: We could still receive SIGPIPE signals within the
-   *       SIGCHLD handler, but the SIGPIPE handler has the
-   *       SA_RESTART flag set and so should not affect our
-   *       "wait" system call.
+   *	   SIGCHLD handler, but the SIGPIPE handler has the
+   *	   SA_RESTART flag set and so should not affect our
+   *	   "wait" system call.
    */
   sigact.sa_flags |= SA_NOCLDSTOP;
   sigact.sa_handler = ReapChildren;
@@ -993,10 +991,10 @@ InstallSignals(void)
 #else
 #ifdef USE_BSD_SIGNALS
   fvwmSetSignalMask( sigmask(SIGUSR1) |
-                     sigmask(SIGINT)  |
-                     sigmask(SIGHUP)  |
-                     sigmask(SIGQUIT) |
-                     sigmask(SIGTERM) );
+		     sigmask(SIGINT)  |
+		     sigmask(SIGHUP)  |
+		     sigmask(SIGQUIT) |
+		     sigmask(SIGTERM) );
 #endif
 
   /*
@@ -1296,7 +1294,7 @@ extern void FreeDecorFace(Display *dpy, DecorFace *df);
 /***********************************************************************
  *
  *  ResetOrDestroyAllButtons -- resets all buttons to defaults
- *                              destroys existing buttons
+ *				destroys existing buttons
  *
  ************************************************************************/
 void DestroyAllButtons(FvwmDecor *decor)
@@ -1344,7 +1342,7 @@ void ResetAllButtons(FvwmDecor *decor)
 /***********************************************************************
  *
  *  Procedure:
- *	CreateGCs - open fonts and create all the needed GC's.  I only
+ *	CreateGCs - open fonts and create all the needed GC's.	I only
  *		    want to do this once, hence the first_time flag.
  *
  ***********************************************************************/
@@ -1406,7 +1404,7 @@ static void InitVariables(void)
   /* create graphics contexts */
   CreateGCs();
 
-  if (Pdepth <= 8) {               /* if the color is limited */
+  if (Pdepth <= 8) {		   /* if the color is limited */
     /* a number > than the builtin table! */
     Scr.ColorLimit = 255;
   }
@@ -1419,7 +1417,7 @@ static void InitVariables(void)
   Scr.fvwm_pushes = 0;
   Scr.pushed_window = &Scr.FvwmRoot;
   Scr.FvwmRoot.number_cmap_windows = 0;
-
+  Scr.FvwmRoot.attr_backup.colormap = Pcmap;
 
   Scr.MyDisplayWidth = DisplayWidth(dpy, Scr.screen);
   Scr.MyDisplayHeight = DisplayHeight(dpy, Scr.screen);
@@ -1461,7 +1459,10 @@ static void InitVariables(void)
   /* set major operating modes */
   Scr.NumBoxes = 0;
 
-  Scr.randomx = Scr.randomy = 0;
+  Scr.cascade_x = Scr.cascade_y = 0;
+  /* the last Cascade placed window or NULL, we don't want NULL initially */
+  Scr.cascade_window = &Scr.FvwmRoot;
+
   Scr.buttons2grab = 0;
 
   /* initialisation of the head of the desktops info */
@@ -1490,13 +1491,13 @@ static void InitVariables(void)
      which do not run under NT.
 
      "Hummingbird Communications Ltd."
-        is the ServerVendor string of the Exceed X server under NT,
+	is the ServerVendor string of the Exceed X server under NT,
 
      "Network Computing Devices Inc."
-        is the ServerVendor string of the PCXware X server under Windows.
+	is the ServerVendor string of the PCXware X server under Windows.
 
      "WRQ, Inc."
-        is the ServerVendor string of the Reflection X server under Windows.
+	is the ServerVendor string of the Reflection X server under Windows.
   */
   Scr.bo.RaiseHackNeeded =
     (strcmp (ServerVendor (dpy), "Hummingbird Communications Ltd.") == 0) ||
@@ -1516,10 +1517,16 @@ static void InitVariables(void)
   /* Not the right place for this, should only be called once somewhere .. */
 
   /* EdgeCommands - no edge commands by default */
-  Scr.PanFrameTop.command    = NULL ; 
-  Scr.PanFrameBottom.command = NULL ; 
-  Scr.PanFrameRight.command  = NULL ; 
-  Scr.PanFrameLeft.command   = NULL ; 
+  Scr.PanFrameTop.command    = NULL;
+  Scr.PanFrameBottom.command = NULL;
+  Scr.PanFrameRight.command  = NULL;
+  Scr.PanFrameLeft.command   = NULL;
+  Scr.flags.is_pointer_on_this_screen = !!XQueryPointer(
+	  dpy, Scr.Root, &JunkRoot, &JunkChild, &JunkX, &JunkY, &JunkX, &JunkY,
+	  &JunkMask);
+
+  /* make sure colorset 0 exists */
+  alloc_colorset(0);
 
   return;
 }
@@ -1561,7 +1568,7 @@ void Done(int restart, char *command)
 
   /* migo (03/Jul/1999): execute [Session]ExitFunction */
   exitFuncName = getInitFunctionName(2);
-  if (FindFunction(exitFuncName))
+  if (functions_is_complex_function(exitFuncName))
   {
     char *action = safestrdup(CatString2("Function ", exitFuncName));
     old_execute_function(NULL, action, NULL, &Event, C_ROOT, 1, 0, NULL);
@@ -1584,9 +1591,9 @@ void Done(int restart, char *command)
       while (isspace(command[0])) command++;
       if (strncmp(command, "--dont-preserve-state", 21) == 0)
       {
-        doPreserveState = False;
-        command += 21;
-        while (isspace(command[0])) command++;
+	doPreserveState = False;
+	command += 21;
+	while (isspace(command[0])) command++;
       }
     }
     if (command[0] == '\0')
@@ -1623,61 +1630,61 @@ void Done(int restart, char *command)
 
       if (n <= 0)
       {
-        fvwm_msg(ERR, "Done", "Restart command parsing error in (%s): [%s]",
-          command, errorMsg);
+	fvwm_msg(ERR, "Done", "Restart command parsing error in (%s): [%s]",
+	  command, errorMsg);
       }
       else if (StrEquals(my_argv[0], "--pass-args"))
       {
-        if (n != 2)
+	if (n != 2)
 	{
-          fvwm_msg(ERR, "Done",
+	  fvwm_msg(ERR, "Done",
 		   "Restart --pass-args: single name expected. "
 		   "(restarting '%s' instead)",
-            g_argv[0]);
+	    g_argv[0]);
 
-        }
+	}
 	else
 	{
-          int i;
-          my_argv[0] = my_argv[1];
-          for (i = 1; i < g_argc && i < MAX_ARG_SIZE - 1; i++)
-            my_argv[i] = g_argv[i];
-          my_argv[i] = NULL;
+	  int i;
+	  my_argv[0] = my_argv[1];
+	  for (i = 1; i < g_argc && i < MAX_ARG_SIZE - 1; i++)
+	    my_argv[i] = g_argv[i];
+	  my_argv[i] = NULL;
 
-          execvp(my_argv[0], my_argv);
-          fvwm_msg(ERR, "Done",
+	  execvp(my_argv[0], my_argv);
+	  fvwm_msg(ERR, "Done",
 		   "Call of '%s' failed! (restarting '%s' instead)",
-            my_argv[0], g_argv[0]);
-          perror("  system error description");
-        }
+	    my_argv[0], g_argv[0]);
+	  perror("  system error description");
+	}
 
       }
       else
       {
-        /* Warn against an old 'Restart fvwm2' usage */
-        if (n == 1 && strcmp(my_argv[0], "fvwm2") == 0)
-        {
-          fvwm_msg(WARN, "Done",
-            "`Restart fvwm2' might not do what you want, see the man page.\n\t"
-            "Use Restart without parameters if you mean to restart the same WM."
-          );
-        }
-        /* If we are at it, warn against a 'Restart fvwm' usage as well */
-        if (n == 1 && strcmp(my_argv[0], "fvwm") == 0)
-        {
-          fvwm_msg(WARN, "Done",
-            "`Restart fvwm' might not do what you want, see the man page.\n\t"
-            "Use Restart without parameters if you mean to restart the same WM."
-          );
-        }
-        execvp(my_argv[0], my_argv);
-        fvwm_msg(ERR, "Done", "Call of '%s' failed! (restarting '%s' instead)",
-          my_argv[0], g_argv[0]);
-        perror("  system error description");
+	/* Warn against an old 'Restart fvwm2' usage */
+	if (n == 1 && strcmp(my_argv[0], "fvwm2") == 0)
+	{
+	  fvwm_msg(WARN, "Done",
+	    "`Restart fvwm2' might not do what you want, see the man page.\n\t"
+	    "Use Restart without parameters if you mean to restart the same WM."
+	  );
+	}
+	/* If we are at it, warn against a 'Restart fvwm' usage as well */
+	if (n == 1 && strcmp(my_argv[0], "fvwm") == 0)
+	{
+	  fvwm_msg(WARN, "Done",
+	    "`Restart fvwm' might not do what you want, see the man page.\n\t"
+	    "Use Restart without parameters if you mean to restart the same WM."
+	  );
+	}
+	execvp(my_argv[0], my_argv);
+	fvwm_msg(ERR, "Done", "Call of '%s' failed! (restarting '%s' instead)",
+	  my_argv[0], g_argv[0]);
+	perror("  system error description");
       }
     }
 
-    execvp(g_argv[0], g_argv);    /* that _should_ work */
+    execvp(g_argv[0], g_argv);	  /* that _should_ work */
     fvwm_msg(ERR, "Done", "Call of '%s' failed!", g_argv[0]);
     perror("  system error description");
   }
@@ -1756,9 +1763,9 @@ int FvwmErrorHandler(Display *dpy, XErrorEvent *event)
 
   fvwm_msg(ERR,"FvwmErrorHandler","*** internal error ***");
   fvwm_msg(ERR,"FvwmErrorHandler","Request %d, Error %d, EventType: %d",
-           event->request_code,
-           event->error_code,
-           last_event_type);
+	   event->request_code,
+	   event->error_code,
+	   last_event_type);
   return 0;
 }
 
@@ -1783,12 +1790,12 @@ void SaveDesktopState()
   {
     data[0] = (unsigned long) t->Desk;
     XChangeProperty (dpy, FW_W(t), _XA_WM_DESKTOP, _XA_WM_DESKTOP, 32,
-                     PropModeReplace, (unsigned char *) data, 1);
+		     PropModeReplace, (unsigned char *) data, 1);
   }
 
   data[0] = (unsigned long) Scr.CurrentDesk;
   XChangeProperty (dpy, Scr.Root, _XA_WM_DESKTOP, _XA_WM_DESKTOP, 32,
-                   PropModeReplace, (unsigned char *) data, 1);
+		   PropModeReplace, (unsigned char *) data, 1);
 
   XFlush(dpy);
 }
@@ -1854,7 +1861,7 @@ static int parseCommandArgs(
   const char *cptr = command;
 #define theChar (*cptr)
 #define advChar (cptr++)
-#define topChar (*cptr     == '\\'? *(cptr+1): *cptr)
+#define topChar (*cptr	   == '\\'? *(cptr+1): *cptr)
 #define popChar (*(cptr++) == '\\'? *(cptr++): *(cptr-1))
 #define canAddArgChar (totalArgLen < MAX_TOTAL_ARG_LEN-1)
 #define addArgChar(ch) (++totalArgLen, *(aptr++) = ch)
@@ -1870,30 +1877,30 @@ static int parseCommandArgs(
     if (theChar == '\0') break;
     while ((sQuote || !isspace(theChar)) && theChar != '\0' && canAddArgChar) {
       if (theChar == '"') {
-        if (sQuote) { sQuote = 0; }
-        else { sQuote = 1; }
-        advChar;
+	if (sQuote) { sQuote = 0; }
+	else { sQuote = 1; }
+	advChar;
       } else if (!sQuote && theChar == '\'') {
-        advChar;
-        while (theChar != '\'' && theChar != '\0' && canAddArgChar) {
-          addArgChar(popChar);
-        }
-        if (theChar == '\'') advChar;
-        else if (!canAddArgChar) break;
-        else { *errorMsg = "No closing single quote"; errorCode = -3; break; }
+	advChar;
+	while (theChar != '\'' && theChar != '\0' && canAddArgChar) {
+	  addArgChar(popChar);
+	}
+	if (theChar == '\'') advChar;
+	else if (!canAddArgChar) break;
+	else { *errorMsg = "No closing single quote"; errorCode = -3; break; }
       } else if (!sQuote && theChar == '~') {
-        if (!canAddArgStr(home_dir)) break;
-        addArgStr(home_dir);
-        advChar;
+	if (!canAddArgStr(home_dir)) break;
+	addArgStr(home_dir);
+	advChar;
       } else if (theChar == '$') {
-        int beg, len;
-        const char *str = getFirstEnv(cptr, &beg, &len);
-        if (!str || beg) { addArgChar(theChar); advChar; continue; }
-        if (!canAddArgStr(str)) { break; }
-        addArgStr(str);
-        cptr += len;
+	int beg, len;
+	const char *str = getFirstEnv(cptr, &beg, &len);
+	if (!str || beg) { addArgChar(theChar); advChar; continue; }
+	if (!canAddArgStr(str)) { break; }
+	addArgStr(str);
+	cptr += len;
       } else {
-        if (addArgChar(popChar) == '\0') break;
+	if (addArgChar(popChar) == '\0') break;
       }
     }
     if (*(aptr-1) == '\0')
@@ -1962,7 +1969,7 @@ static void setVersionInfo(void)
 
   /* Set version information string */
   sprintf(version_str, "FVWM version %s compiled on %s at %s",
-          VERSION, __DATE__, __TIME__);
+	  VERSION, __DATE__, __TIME__);
   Fvwm_VersionInfo = safestrdup(version_str);
 
 #ifdef HAVE_READLINE
@@ -1991,9 +1998,6 @@ static void setVersionInfo(void)
 #ifdef SESSION
   strcat(support_str, " SM,");
 #endif
-#ifdef MULTIBYTE
-  strcat(support_str, " Multibyte,");
-#endif
 #ifdef HAVE_BIDI
   strcat(support_str, " bidi text,");
 #endif
