@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /****************************************************************************
@@ -46,6 +46,7 @@
 #include "externs.h"
 #include "cursor.h"
 #include "functions.h"
+#include "commands.h"
 #include "bindings.h"
 #include "events.h"
 #include "misc.h"
@@ -480,300 +481,347 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
  ****************************************************************************/
 void DrawIconWindow(FvwmWindow *fw)
 {
-  GC Shadow;
-  GC Relief;
-  Pixel TextColor;
-  Pixel BackColor;
-  color_quad *draw_colors;
-  int is_expanded = IS_ICON_ENTERED(fw);
-  FlocaleWinString fstr;
+	GC Shadow;
+	GC Relief;
+	Pixel TextColor;
+	Pixel BackColor;
+	color_quad *draw_colors;
+	int cs;
+	int is_expanded = IS_ICON_ENTERED(fw);
+	FlocaleWinString fstr;
 
-  if (IS_ICON_SUPPRESSED(fw))
-    return;
-
-  if (FW_W_ICON_TITLE(fw) != None)
-    flush_expose(FW_W_ICON_TITLE(fw));
-  if (FW_W_ICON_PIXMAP(fw) != None)
-    flush_expose(FW_W_ICON_PIXMAP(fw));
-
-  if (Scr.Hilite == fw)
-    draw_colors = &(fw->hicolors);
-  else
-    draw_colors = &(fw->colors);
-  if (Pdepth < 2 && Scr.Hilite != fw)
-  {
-    Relief = Scr.StdReliefGC;
-    Shadow = Scr.StdShadowGC;
-  }
-  else
-  {
-    if (Pdepth < 2 && Scr.Hilite == fw)
-      Relief = Scr.ScratchGC2;
-    else
-    {
-      Globalgcv.foreground = draw_colors->hilight;
-      Globalgcm = GCForeground;
-      XChangeGC(dpy,Scr.ScratchGC1,Globalgcm,&Globalgcv);
-      Relief = Scr.ScratchGC1;
-    }
-    Globalgcv.foreground = draw_colors->shadow;
-    XChangeGC(dpy,Scr.ScratchGC2, Globalgcm, &Globalgcv);
-    Shadow = Scr.ScratchGC2;
-  }
-  TextColor = draw_colors->fore;
-  BackColor = draw_colors->back;
-
-  if (FW_W_ICON_TITLE(fw) != None)
-  {
-    int x_title;
-    int x_title_min = 0;
-    int w_title = fw->icon_g.title_text_width;
-    int x_title_w = fw->icon_g.picture_w_g.x;
-    int w_title_w = fw->icon_g.picture_w_g.width;
-    int x_stipple = ICON_RELIEF_WIDTH;
-    int w_title_text_gap = 0;
-    int w_stipple = 0;
-    int is_sticky = (IS_STICKY(fw) || IS_ICON_STICKY(fw));
-    int use_unexpanded_size = 1;
-
-    if (is_expanded && FW_W_ICON_PIXMAP(fw) != None)
-    {
-      int sx;
-      int sy;
-      int sw;
-      int sh;
-
-      use_unexpanded_size = 0;
-      w_title_text_gap = ICON_TITLE_TEXT_GAP_EXPANDED;
-      x_title_min = w_title_text_gap + ICON_RELIEF_WIDTH;
-      if (is_sticky)
-      {
-	w_stipple = ICON_TITLE_STICK_MIN_WIDTH;
-	x_title_min += w_stipple + ICON_TITLE_TO_STICK_EXTRA_GAP;
-      }
-      /* resize the icon name window */
-      w_title_w = w_title + 2 * x_title_min;
-      if (w_title_w <= fw->icon_g.picture_w_g.width)
-      {
-	/* the expanded title is smaller, so do not expand at all */
-	is_expanded = 1;
-	w_stipple = 0;
-	use_unexpanded_size = 1;
-      }
-      else
-      {
-	x_title_w = fw->icon_g.picture_w_g.x -
-	  (w_title_w - fw->icon_g.picture_w_g.width) / 2;
-	FScreenGetScrRect(NULL, FSCREEN_CURRENT, &sx, &sy, &sw, &sh);
-	/* start keep label on screen. dje 8/7/97 */
-	if (x_title_w < sx) {  /* if new loc neg (off left edge) */
-	  x_title_w = sx;      /* move to edge */
-	} else {                         /* if not on left edge */
-	  /* if (new loc + width) > screen width (off edge on right) */
-	  if ((x_title_w + w_title_w) >
-	      sx + sw) {      /* off right */
-	    /* position up against right edge */
-	    x_title_w = sx + sw - w_title_w;
-	  }
-	  /* end keep label on screen. dje 8/7/97 */
+	if (IS_ICON_SUPPRESSED(fw))
+	{
+		return;
 	}
-      }
-    }
-    if (use_unexpanded_size)
-    {
-      w_title_text_gap = ICON_TITLE_TEXT_GAP_COLLAPSED;
-      x_title_min = w_title_text_gap + ICON_RELIEF_WIDTH;
-      /* resize the icon name window */
-      if (FW_W_ICON_PIXMAP(fw) != None)
-      {
-	w_title_w = fw->icon_g.picture_w_g.width;
-	x_title_w = fw->icon_g.picture_w_g.x;
-      }
-      else
-      {
-	w_title_w = fw->icon_g.title_w_g.width;
-	x_title_w = fw->icon_g.title_w_g.x;
-      }
-    }
-    fw->icon_g.title_w_g.width = w_title_w;
-    fw->icon_g.title_w_g.x = x_title_w;
 
-    /* set up TitleGC for drawing the icon label */
-    if (fw->icon_font != NULL)
-      NewFontAndColor(fw->icon_font, TextColor, BackColor);
+	if (FW_W_ICON_TITLE(fw) != None)
+	{
+		flush_expose(FW_W_ICON_TITLE(fw));
+	}
+	if (FW_W_ICON_PIXMAP(fw) != None)
+	{
+		flush_expose(FW_W_ICON_PIXMAP(fw));
+	}
 
-    fw->icon_g.title_w_g.height = ICON_HEIGHT(fw);
-    XMoveResizeWindow(
-      dpy, FW_W_ICON_TITLE(fw), fw->icon_g.title_w_g.x,
-      fw->icon_g.title_w_g.y, w_title_w, ICON_HEIGHT(fw));
-    XSetWindowBackground(dpy, FW_W_ICON_TITLE(fw), BackColor);
-    XClearWindow(dpy,FW_W_ICON_TITLE(fw));
+	if (Scr.Hilite == fw)
+	{
+		draw_colors = &(fw->hicolors);
+		cs = fw->cs_hi;
+	}
+	else
+	{
+		draw_colors = &(fw->colors);
+		cs = fw->cs;
+	}
+	if (Pdepth < 2 && Scr.Hilite != fw)
+	{
+		Relief = Scr.StdReliefGC;
+		Shadow = Scr.StdShadowGC;
+	}
+	else
+	{
+		if (Pdepth < 2 && Scr.Hilite == fw)
+			Relief = Scr.ScratchGC2;
+		else
+		{
+			Globalgcv.foreground = draw_colors->hilight;
+			Globalgcm = GCForeground;
+			XChangeGC(dpy,Scr.ScratchGC1,Globalgcm,&Globalgcv);
+			Relief = Scr.ScratchGC1;
+		}
+		Globalgcv.foreground = draw_colors->shadow;
+		XChangeGC(dpy,Scr.ScratchGC2, Globalgcm, &Globalgcv);
+		Shadow = Scr.ScratchGC2;
+	}
+	TextColor = draw_colors->fore;
+	BackColor = draw_colors->back;
 
-    /* text position */
-    x_title = (w_title_w - w_title) / 2;
-    if (x_title < x_title_min)
-      x_title = x_title_min;
-    if (is_sticky)
-    {
-      XRectangle r;
+	if (FW_W_ICON_TITLE(fw) != None)
+	{
+		int x_title;
+		int x_title_min = 0;
+		int w_title = fw->icon_g.title_text_width;
+		int x_title_w = fw->icon_g.picture_w_g.x;
+		int w_title_w = fw->icon_g.picture_w_g.width;
+		int x_stipple = ICON_RELIEF_WIDTH;
+		int w_title_text_gap = 0;
+		int w_stipple = 0;
+		int is_sticky = (IS_STICKY(fw) || IS_ICON_STICKY(fw));
+		int use_unexpanded_size = 1;
 
-      if (w_stipple == 0)
-      {
-	w_stipple = ((w_title_w - 2 * (x_stipple + w_title_text_gap) -
-		      w_title) + 1) / 2;
-      }
-      if (w_stipple < ICON_TITLE_STICK_MIN_WIDTH)
-      {
-	w_stipple = ICON_TITLE_STICK_MIN_WIDTH;
-      }
-      if (x_title < x_stipple + w_stipple + w_title_text_gap)
-      {
-	x_title = x_stipple + w_stipple + w_title_text_gap;
-      }
-      r.x = x_title;
-      r.y = 0;
-      r.width = w_title_w - 2 * x_title;
-      if (r.width < 1)
-	r.width = 1;
-      r.height = ICON_HEIGHT(fw);
-      XSetClipRectangles(dpy, Scr.TitleGC, 0, 0, &r, 1, Unsorted);
-    }
-    memset(&fstr, 0, sizeof(fstr));
-    fstr.str = fw->visible_icon_name;
-    fstr.win =  FW_W_ICON_TITLE(fw);
-    fstr.gc = Scr.TitleGC;
-    fstr.x = x_title;
-    fstr.y = fw->icon_g.title_w_g.height -
-      fw->icon_font->height +
-      fw->icon_font->ascent + ICON_TITLE_VERT_TEXT_OFFSET;
-    FlocaleDrawString(dpy, fw->icon_font, &fstr, 0);
-    RelieveRectangle(
-	    dpy, FW_W_ICON_TITLE(fw), 0, 0, w_title_w - 1,
-	    ICON_HEIGHT(fw) - 1, Relief, Shadow, ICON_RELIEF_WIDTH);
-    if (is_sticky)
-    {
-      /* an odd number of lines every 4 pixels */
-      int num = (ICON_HEIGHT(fw) / ICON_TITLE_STICK_VERT_DIST / 2) * 2 - 1;
-      int min = ICON_HEIGHT(fw) / 2 - num * 2 + 1;
-      int max = ICON_HEIGHT(fw) / 2 + num * 2 -
-	      ICON_TITLE_STICK_VERT_DIST + 1;
-      int i;
+		if (is_expanded && FW_W_ICON_PIXMAP(fw) != None)
+		{
+			int sx;
+			int sy;
+			int sw;
+			int sh;
 
-      for(i = min; w_stipple > 0 && i <= max; i += ICON_TITLE_STICK_VERT_DIST)
-      {
-	RelieveRectangle(
-	  dpy, FW_W_ICON_TITLE(fw), x_stipple, i, w_stipple - 1, 1, Shadow,
-	  Relief, ICON_TITLE_STICK_HEIGHT);
-	RelieveRectangle(
-	  dpy, FW_W_ICON_TITLE(fw), w_title_w - x_stipple - w_stipple, i,
-	  w_stipple - 1, 1, Shadow, Relief, ICON_TITLE_STICK_HEIGHT);
-      }
-      XSetClipMask(dpy, Scr.TitleGC, None);
-    }
-  }
+			use_unexpanded_size = 0;
+			w_title_text_gap = ICON_TITLE_TEXT_GAP_EXPANDED;
+			x_title_min = w_title_text_gap + ICON_RELIEF_WIDTH;
+			if (is_sticky)
+			{
+				w_stipple = ICON_TITLE_STICK_MIN_WIDTH;
+				x_title_min += w_stipple +
+					ICON_TITLE_TO_STICK_EXTRA_GAP;
+			}
+			/* resize the icon name window */
+			w_title_w = w_title + 2 * x_title_min;
+			if (w_title_w <= fw->icon_g.picture_w_g.width)
+			{
+				/* the expanded title is smaller, so do not *
+				 * expand at all */
+				is_expanded = 1;
+				w_stipple = 0;
+				use_unexpanded_size = 1;
+			}
+			else
+			{
+				x_title_w = fw->icon_g.picture_w_g.x -
+					(w_title_w -
+					 fw->icon_g.picture_w_g.width) / 2;
+				FScreenGetScrRect(NULL, FSCREEN_CURRENT,
+						  &sx, &sy, &sw, &sh);
+				/* start keep label on screen. dje 8/7/97 */
+				if (x_title_w < sx) {
+					/* if new loc neg (off left edge) */
+					x_title_w = sx;	     /* move to edge */
+				}
+				else
+				{
+					/* if not on left edge */
+					/* if (new loc + width) > screen width
+					 * (off edge on right) */
+					if ((x_title_w + w_title_w) >sx + sw) {
+						/* off right */
+						/* position up against right edge */
+						x_title_w = sx + sw - w_title_w;
+					}
+					/* end keep label on screen. dje 8/7/97 */
+				}
+			}
+		}
+		if (use_unexpanded_size)
+		{
+			w_title_text_gap = ICON_TITLE_TEXT_GAP_COLLAPSED;
+			x_title_min = w_title_text_gap + ICON_RELIEF_WIDTH;
+			/* resize the icon name window */
+			if (FW_W_ICON_PIXMAP(fw) != None)
+			{
+				w_title_w = fw->icon_g.picture_w_g.width;
+				x_title_w = fw->icon_g.picture_w_g.x;
+			}
+			else
+			{
+				w_title_w = fw->icon_g.title_w_g.width;
+				x_title_w = fw->icon_g.title_w_g.x;
+			}
+		}
+		fw->icon_g.title_w_g.width = w_title_w;
+		fw->icon_g.title_w_g.x = x_title_w;
 
-  if (FW_W_ICON_PIXMAP(fw) != None)
-  {
-    XMoveWindow(
-	    dpy, FW_W_ICON_PIXMAP(fw), fw->icon_g.picture_w_g.x,
-	    fw->icon_g.picture_w_g.y);
-  }
+		/* set up TitleGC for drawing the icon label */
+		if (fw->icon_font != NULL)
+			NewFontAndColor(fw->icon_font, TextColor, BackColor);
 
-  /* only relieve unshaped icons that share fvwm's visual */
-  if ((fw->iconPixmap != None) && !IS_ICON_SHAPED(fw)
-      && (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw)))
-  {
-	  RelieveRectangle(
-			   dpy, FW_W_ICON_PIXMAP(fw), 0, 0,
-			   fw->icon_g.picture_w_g.width - 1,
-			   fw->icon_g.picture_w_g.height - 1,
-			   Relief, Shadow,
-			   ICON_RELIEF_WIDTH);
-  }
+		fw->icon_g.title_w_g.height = ICON_HEIGHT(fw);
+		XMoveResizeWindow(
+			dpy, FW_W_ICON_TITLE(fw), fw->icon_g.title_w_g.x,
+			fw->icon_g.title_w_g.y, w_title_w, ICON_HEIGHT(fw));
+		XSetWindowBackground(dpy, FW_W_ICON_TITLE(fw), BackColor);
+		XClearWindow(dpy,FW_W_ICON_TITLE(fw));
 
-  /* need to locate the icon pixmap */
-  if (fw->iconPixmap != None)
-  {
-    if (fw->iconDepth == 1)
-    {
-      /* it's a bitmap */
-      XCopyPlane(
-	dpy, fw->iconPixmap, FW_W_ICON_PIXMAP(fw), Scr.TitleGC, 0, 0,
-	fw->icon_g.picture_w_g.width - 2 * ICON_RELIEF_WIDTH,
-	fw->icon_g.picture_w_g.height - 2 * ICON_RELIEF_WIDTH,
-	ICON_RELIEF_WIDTH, ICON_RELIEF_WIDTH, 1);
-    }
-    else
-    {
-      if (Pdefault || IS_PIXMAP_OURS(fw))
-      {
-	      if (fw->icon_alphaPixmap)
-	      {
-		      XClearWindow(dpy, FW_W_ICON_PIXMAP(fw));
-		      XSetWindowBackgroundPixmap(dpy, FW_W_ICON_PIXMAP(fw),
-						 ParentRelative);
-	      }
-	      PGraphicsCopyPixmaps(dpy, fw->iconPixmap, None,
-				   fw->icon_alphaPixmap,
-				   Pdepth,
-				   FW_W_ICON_PIXMAP(fw), Scr.TitleGC, 0, 0, 
-				   fw->icon_g.picture_w_g.width - 2 *
-				   ICON_RELIEF_WIDTH,
-				   fw->icon_g.picture_w_g.height - 2 *
-				   ICON_RELIEF_WIDTH, ICON_RELIEF_WIDTH,
-				   ICON_RELIEF_WIDTH);
-      }
-      else
-      {
-        /* it's a client pixmap and fvwm is not using the root visual
-         * The icon window has no 3d border so copy to (0,0)
-         * install the root colormap temporarily to help the Exceed server */
-        if (Scr.bo.InstallRootCmap)
-          InstallRootColormap();
-	XCopyArea(
-	  dpy, fw->iconPixmap, FW_W_ICON_PIXMAP(fw),
-	  DefaultGC(dpy, Scr.screen), 0, 0, fw->icon_g.picture_w_g.width,
-	  fw->icon_g.picture_w_g.height, 0, 0);
-	if (Scr.bo.InstallRootCmap)
-	  UninstallRootColormap();
-      }
-    }
-  }
+		/* text position */
+		x_title = (w_title_w - w_title) / 2;
+		if (x_title < x_title_min)
+			x_title = x_title_min;
+		if (is_sticky)
+		{
+			XRectangle r;
 
-  if (is_expanded)
-  {
-    if (FW_W_ICON_TITLE(fw) != None)
-    {
-      XRaiseWindow(dpy, FW_W_ICON_TITLE(fw));
-      raisePanFrames();
-    }
-  }
-  else
-  {
-    XWindowChanges xwc;
-    int mask;
-    xwc.sibling = FW_W_FRAME(fw);
-    xwc.stack_mode = Below;
-    mask = CWSibling|CWStackMode;
-    if (FW_W_ICON_TITLE(fw) != None)
-    {
-      XConfigureWindow(dpy, FW_W_ICON_TITLE(fw), mask, &xwc);
-    }
-    if (FW_W_ICON_PIXMAP(fw) != None)
-    {
-      XConfigureWindow(dpy, FW_W_ICON_PIXMAP(fw), mask, &xwc);
-    }
-  }
-  /* wait for pending EnterNotify/LeaveNotify events to suppress race condition
-   * w/ expanding/collapsing icon titles */
-  XFlush(dpy);
+			if (w_stipple == 0)
+			{
+				w_stipple = ((w_title_w - 2 *
+					      (x_stipple + w_title_text_gap) -
+					      w_title) + 1) / 2;
+			}
+			if (w_stipple < ICON_TITLE_STICK_MIN_WIDTH)
+			{
+				w_stipple = ICON_TITLE_STICK_MIN_WIDTH;
+			}
+			if (x_title < x_stipple + w_stipple + w_title_text_gap)
+			{
+				x_title = x_stipple + w_stipple +
+					w_title_text_gap;
+			}
+			r.x = x_title;
+			r.y = 0;
+			r.width = w_title_w - 2 * x_title;
+			if (r.width < 1)
+				r.width = 1;
+			r.height = ICON_HEIGHT(fw);
+			XSetClipRectangles(dpy, Scr.TitleGC, 0, 0, &r, 1,
+					   Unsorted);
+		}
+		memset(&fstr, 0, sizeof(fstr));
+		fstr.str = fw->visible_icon_name;
+		fstr.win =  FW_W_ICON_TITLE(fw);
+		fstr.gc = Scr.TitleGC;
+		if (cs >= 0)
+		{
+			fstr.colorset = &Colorset[cs];
+			fstr.flags.has_colorset = 1;
+		}
+		fstr.x = x_title;
+		fstr.y = fw->icon_g.title_w_g.height -
+			fw->icon_font->height +
+			fw->icon_font->ascent + ICON_TITLE_VERT_TEXT_OFFSET;
+		FlocaleDrawString(dpy, fw->icon_font, &fstr, 0);
+		RelieveRectangle(
+			dpy, FW_W_ICON_TITLE(fw), 0, 0, w_title_w - 1,
+			ICON_HEIGHT(fw) - 1, Relief, Shadow, ICON_RELIEF_WIDTH);
+		if (is_sticky)
+		{
+			/* an odd number of lines every 4 pixels */
+			int num = (ICON_HEIGHT(fw) /
+				   ICON_TITLE_STICK_VERT_DIST / 2) * 2 - 1;
+			int min = ICON_HEIGHT(fw) / 2 - num * 2 + 1;
+			int max = ICON_HEIGHT(fw) / 2 + num * 2 -
+				ICON_TITLE_STICK_VERT_DIST + 1;
+			int i;
+
+			for(i = min; w_stipple > 0 && i <= max;
+			    i += ICON_TITLE_STICK_VERT_DIST)
+			{
+				RelieveRectangle(
+					dpy, FW_W_ICON_TITLE(fw), x_stipple,
+					i, w_stipple - 1, 1, Shadow,
+					Relief, ICON_TITLE_STICK_HEIGHT);
+				RelieveRectangle(
+					dpy, FW_W_ICON_TITLE(fw),
+					w_title_w - x_stipple - w_stipple, i,
+					w_stipple - 1, 1, Shadow, Relief,
+					ICON_TITLE_STICK_HEIGHT);
+			}
+			XSetClipMask(dpy, Scr.TitleGC, None);
+		}
+	}
+
+	if (FW_W_ICON_PIXMAP(fw) != None)
+	{
+		XMoveWindow(
+			dpy, FW_W_ICON_PIXMAP(fw), fw->icon_g.picture_w_g.x,
+			fw->icon_g.picture_w_g.y);
+	}
+
+	/* only relieve unshaped icons that share fvwm's visual */
+	if ((fw->iconPixmap != None) && !IS_ICON_SHAPED(fw)
+	    && (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw)))
+	{
+		RelieveRectangle(dpy, FW_W_ICON_PIXMAP(fw), 0, 0,
+				 fw->icon_g.picture_w_g.width - 1,
+				 fw->icon_g.picture_w_g.height - 1,
+				 Relief, Shadow,
+				 ICON_RELIEF_WIDTH);
+	}
+
+	/* need to locate the icon pixmap */
+	if (fw->iconPixmap != None)
+	{
+		if (fw->iconDepth == 1)
+		{
+			/* it's a bitmap */
+			XCopyPlane(
+			      dpy, fw->iconPixmap, FW_W_ICON_PIXMAP(fw),
+			      Scr.TitleGC, 0, 0,
+			      fw->icon_g.picture_w_g.width - 2 *
+			      ICON_RELIEF_WIDTH,
+			      fw->icon_g.picture_w_g.height - 2 *
+			      ICON_RELIEF_WIDTH,
+			      ICON_RELIEF_WIDTH, ICON_RELIEF_WIDTH, 1);
+		}
+		else
+		{
+			if (Pdefault || IS_PIXMAP_OURS(fw))
+			{
+				if (fw->icon_alphaPixmap)
+				{
+					XClearWindow(dpy, FW_W_ICON_PIXMAP(fw));
+					XSetWindowBackgroundPixmap(
+							    dpy,
+							    FW_W_ICON_PIXMAP(fw),
+							    ParentRelative);
+				}
+				PGraphicsCopyPixmaps(
+						dpy, fw->iconPixmap, None,
+						fw->icon_alphaPixmap,
+						Pdepth,
+						FW_W_ICON_PIXMAP(fw),
+						Scr.TitleGC, 0, 0,
+						fw->icon_g.picture_w_g.width -
+						2 *
+						ICON_RELIEF_WIDTH,
+						fw->icon_g.picture_w_g.height -
+						2 *
+						ICON_RELIEF_WIDTH,
+						ICON_RELIEF_WIDTH,
+						ICON_RELIEF_WIDTH);
+			}
+			else
+			{
+				/* it's a client pixmap and fvwm is not using
+				 * the root visual The icon window has no 3d
+				 * border so copy to (0,0) install the root
+				 * colormap temporarily to help the Exceed
+				 * server */
+				if (Scr.bo.InstallRootCmap)
+					InstallRootColormap();
+				XCopyArea(
+				     dpy, fw->iconPixmap, FW_W_ICON_PIXMAP(fw),
+				     DefaultGC(dpy, Scr.screen), 0, 0,
+				     fw->icon_g.picture_w_g.width,
+				     fw->icon_g.picture_w_g.height, 0, 0);
+				if (Scr.bo.InstallRootCmap)
+					UninstallRootColormap();
+			}
+		}
+	}
+
+	if (is_expanded)
+	{
+		if (FW_W_ICON_TITLE(fw) != None)
+		{
+			XRaiseWindow(dpy, FW_W_ICON_TITLE(fw));
+			raisePanFrames();
+		}
+	}
+	else
+	{
+		XWindowChanges xwc;
+		int mask;
+		xwc.sibling = FW_W_FRAME(fw);
+		xwc.stack_mode = Below;
+		mask = CWSibling|CWStackMode;
+		if (FW_W_ICON_TITLE(fw) != None)
+		{
+			XConfigureWindow(dpy, FW_W_ICON_TITLE(fw), mask, &xwc);
+		}
+		if (FW_W_ICON_PIXMAP(fw) != None)
+		{
+			XConfigureWindow(dpy, FW_W_ICON_PIXMAP(fw), mask, &xwc);
+		}
+	}
+	/* wait for pending EnterNotify/LeaveNotify events to suppress race
+	 * condition w/ expanding/collapsing icon titles */
+	XFlush(dpy);
 }
 
 /***********************************************************************
  *
  *  Procedure:
  *    ChangeIconPixmap - procedure change the icon pixmap or "pixmap"
- *      window. Called in events.c and ewmh_events.c
+ *	window. Called in events.c and ewmh_events.c
  *
  ************************************************************************/
 void ChangeIconPixmap(FvwmWindow *fw)
@@ -978,19 +1026,19 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
     /* A place to hold inner and outer loop variables. */
     typedef struct dimension_struct
     {
-      int step;                         /* grid size (may be negative) */
-      int start_at;                     /* starting edge */
-      int real_start;                   /* on screen starting edge */
-      int end_at;                       /* ending edge */
-      int base;                         /* base for screen */
-      int icon_dimension;               /* height or width */
-      int nom_dimension;                /* nonminal height or width */
-      int screen_dimension;             /* screen height or width */
-      int screen_offset;                /* screen offset */
+      int step;				/* grid size (may be negative) */
+      int start_at;			/* starting edge */
+      int real_start;			/* on screen starting edge */
+      int end_at;			/* ending edge */
+      int base;				/* base for screen */
+      int icon_dimension;		/* height or width */
+      int nom_dimension;		/* nonminal height or width */
+      int screen_dimension;		/* screen height or width */
+      int screen_offset;		/* screen offset */
     } dimension;
-    dimension dim[3];                   /* space for work, 1st, 2nd dimen */
-    icon_boxes *icon_boxes_ptr;         /* current icon box */
-    int i;                              /* index for inner/outer loop data */
+    dimension dim[3];			/* space for work, 1st, 2nd dimen */
+    icon_boxes *icon_boxes_ptr;		/* current icon box */
+    int i;				/* index for inner/outer loop data */
     fscreen_scr_arg fscr;
     rectangle ref;
     rectangle g;
@@ -1017,20 +1065,20 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
     loc_ok_wrong_screen = False;
 
     /* check all boxes in order */
-    icon_boxes_ptr = NULL;              /* init */
+    icon_boxes_ptr = NULL;		/* init */
     while(do_all_iconboxes(t, &icon_boxes_ptr))
     {
       if (loc_ok == True)
       {
 	/* leave for loop */
-        break;
+	break;
       }
       /* get the screen dimensions for the icon box */
       if (icon_boxes_ptr->IconScreen == FSCREEN_CURRENT)
 	fscr.mouse_ev = NULL;
       FScreenGetScrRect(
 	&fscr,
-        icon_boxes_ptr->IconScreen,
+	icon_boxes_ptr->IconScreen,
 	&ref.x, &ref.y, &ref.width, &ref.height);
       dim[1].screen_offset = ref.y;
       dim[1].screen_dimension = ref.height;
@@ -1041,12 +1089,12 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
       /* init start from */
       dim[1].start_at = ICONBOX_TOP + dim[1].screen_offset;
       if (icon_boxes_ptr->IconSign[1] == '-') {
-        dim[1].start_at += dim[1].screen_dimension;
+	dim[1].start_at += dim[1].screen_dimension;
       }
       /* init end at */
       dim[1].end_at = ICONBOX_BOT + dim[1].screen_offset;
       if (icon_boxes_ptr->IconSign[3] == '-') {
-        dim[1].end_at += dim[1].screen_dimension;
+	dim[1].end_at += dim[1].screen_dimension;
       }
       /* save base */
       dim[1].base = base_y;
@@ -1056,7 +1104,7 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
       {
 	/* fill from bottom */
 	/* reverse step */
-        dim[1].step = 0 - dim[1].step;
+	dim[1].step = 0 - dim[1].step;
       } /* end fill from bottom */
 
       /* x amount */
@@ -1064,12 +1112,12 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
       /* init start from */
       dim[2].start_at = ICONBOX_LFT + dim[2].screen_offset;
       if (icon_boxes_ptr->IconSign[0] == '-') {
-        dim[2].start_at += dim[2].screen_dimension;
+	dim[2].start_at += dim[2].screen_dimension;
       }
       /* init end at */
       dim[2].end_at = ICONBOX_RGT + dim[2].screen_offset;
       if (icon_boxes_ptr->IconSign[2] == '-') {
-        dim[2].end_at += dim[2].screen_dimension;
+	dim[2].end_at += dim[2].screen_dimension;
       }
       /* save base */
       dim[2].base   = base_x;
@@ -1079,103 +1127,103 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
       {
 	/* fill from right */
 	/* reverse step */
-        dim[2].step = 0 - dim[2].step;
+	dim[2].step = 0 - dim[2].step;
       } /* end fill from right */
       for (i=1;i<=2;i++)
       {
 	/* for dimensions 1 and 2 */
-        /* If the window is taller than the icon box, ignore the icon height
-         * when figuring where to put it. Same goes for the width
-         * This should permit reasonably graceful handling of big icons. */
-        dim[i].nom_dimension = dim[i].icon_dimension;
-        if (dim[i].icon_dimension >= dim[i].end_at - dim[i].start_at)
+	/* If the window is taller than the icon box, ignore the icon height
+	 * when figuring where to put it. Same goes for the width
+	 * This should permit reasonably graceful handling of big icons. */
+	dim[i].nom_dimension = dim[i].icon_dimension;
+	if (dim[i].icon_dimension >= dim[i].end_at - dim[i].start_at)
 	{
-          dim[i].nom_dimension = dim[i].end_at - dim[i].start_at - 1;
-        }
-        if (dim[i].step < 0)
+	  dim[i].nom_dimension = dim[i].end_at - dim[i].start_at - 1;
+	}
+	if (dim[i].step < 0)
 	{
 	  /* if moving backwards */
 	  /* save */
-          dim[0].start_at = dim[i].start_at;
+	  dim[0].start_at = dim[i].start_at;
 	  /* swap one */
-          dim[i].start_at = dim[i].end_at;
+	  dim[i].start_at = dim[i].end_at;
 	  /* swap the other */
-          dim[i].end_at = dim[0].start_at;
-          dim[i].start_at -= dim[i].icon_dimension;
-        } /* end moving backwards */
+	  dim[i].end_at = dim[0].start_at;
+	  dim[i].start_at -= dim[i].icon_dimension;
+	} /* end moving backwards */
 	/* adjust both to base */
-        dim[i].start_at += dim[i].base;
-        dim[i].end_at += dim[i].base;
+	dim[i].start_at += dim[i].base;
+	dim[i].end_at += dim[i].base;
       } /* end 2 dimensions */
       if (HRZ_FILL)
       {
 	/* if hrz first */
 	/* save */
-        memcpy(&dim[0],&dim[1],sizeof(dimension));
+	memcpy(&dim[0],&dim[1],sizeof(dimension));
 	/* switch one */
-        memcpy(&dim[1],&dim[2],sizeof(dimension));
+	memcpy(&dim[1],&dim[2],sizeof(dimension));
 	/* switch the other */
-        memcpy(&dim[2],&dim[0],sizeof(dimension));
+	memcpy(&dim[2],&dim[0],sizeof(dimension));
       } /* end horizontal dimension first */
       /* save for reseting inner loop */
       dim[0].start_at = dim[2].start_at;
       loc_ok_wrong_screen2 = False;
-      while((dim[1].step < 0            /* filling reversed */
-             ? (dim[1].start_at + dim[1].icon_dimension - dim[1].nom_dimension
-                > dim[1].end_at)        /* check back edge */
-             : (dim[1].start_at + dim[1].nom_dimension
-                < dim[1].end_at))       /* check front edge */
-            && (!loc_ok)
+      while((dim[1].step < 0		/* filling reversed */
+	     ? (dim[1].start_at + dim[1].icon_dimension - dim[1].nom_dimension
+		> dim[1].end_at)	/* check back edge */
+	     : (dim[1].start_at + dim[1].nom_dimension
+		< dim[1].end_at))	/* check front edge */
+	    && (!loc_ok)
 	    && (!loc_ok_wrong_screen2)) {  /* nothing found yet */
-        dim[1].real_start = dim[1].start_at; /* init */
-        if (dim[1].start_at + dim[1].icon_dimension >
+	dim[1].real_start = dim[1].start_at; /* init */
+	if (dim[1].start_at + dim[1].icon_dimension >
 	    dim[1].screen_offset + dim[1].screen_dimension - 2 + dim[1].base)
 	{
 	  /* off screen, move on screen */
-          dim[1].real_start = dim[1].screen_offset + dim[1].screen_dimension
-            - dim[1].icon_dimension + dim[1].base;
-        } /* end off screen */
-        if (dim[1].start_at < dim[1].screen_offset + dim[1].base)
+	  dim[1].real_start = dim[1].screen_offset + dim[1].screen_dimension
+	    - dim[1].icon_dimension + dim[1].base;
+	} /* end off screen */
+	if (dim[1].start_at < dim[1].screen_offset + dim[1].base)
 	{
 	  /* if off other edge, move on screen */
-          dim[1].real_start = dim[1].screen_offset + dim[1].base;
-        } /* end off other edge */
+	  dim[1].real_start = dim[1].screen_offset + dim[1].base;
+	} /* end off other edge */
 	/* reset inner loop */
-        dim[2].start_at = dim[0].start_at;
-        while((dim[2].step < 0            /* filling reversed */
-               ? (dim[2].start_at + dim[2].icon_dimension-dim[2].nom_dimension
-                  > dim[2].end_at)        /* check back edge */
-               : (dim[2].start_at + dim[2].nom_dimension
-                  < dim[2].end_at))       /* check front edge */
+	dim[2].start_at = dim[0].start_at;
+	while((dim[2].step < 0		  /* filling reversed */
+	       ? (dim[2].start_at + dim[2].icon_dimension-dim[2].nom_dimension
+		  > dim[2].end_at)	  /* check back edge */
+	       : (dim[2].start_at + dim[2].nom_dimension
+		  < dim[2].end_at))	  /* check front edge */
 	      && (!loc_ok)
 	      && (!loc_ok_wrong_screen2)) { /* nothing found yet */
-          dim[2].real_start = dim[2].start_at; /* init */
-          if (dim[2].start_at + dim[2].icon_dimension >
-              dim[2].screen_offset + dim[2].screen_dimension - 2 + dim[2].base)
+	  dim[2].real_start = dim[2].start_at; /* init */
+	  if (dim[2].start_at + dim[2].icon_dimension >
+	      dim[2].screen_offset + dim[2].screen_dimension - 2 + dim[2].base)
 	  {
 	    /* if off screen, move on screen */
-            dim[2].real_start = dim[2].screen_offset + dim[2].screen_dimension
-              - dim[2].icon_dimension + dim[2].base;
-          } /* end off screen */
-          if (dim[2].start_at < dim[2].screen_offset + dim[2].base)
+	    dim[2].real_start = dim[2].screen_offset + dim[2].screen_dimension
+	      - dim[2].icon_dimension + dim[2].base;
+	  } /* end off screen */
+	  if (dim[2].start_at < dim[2].screen_offset + dim[2].base)
 	  {
 	    /* if off other edge, move on screen */
 	    dim[2].real_start = dim[2].screen_offset + dim[2].base;
-          } /* end off other edge */
+	  } /* end off other edge */
 
-          if (HRZ_FILL)
+	  if (HRZ_FILL)
 	  {
 	    /* hrz first */
 	    /* unreverse them */
-            real_x = dim[1].real_start;
-            real_y = dim[2].real_start;
-          }
+	    real_x = dim[1].real_start;
+	    real_y = dim[2].real_start;
+	  }
 	  else
 	  {
 	    /* reverse them */
-            real_x = dim[2].real_start;
-            real_y = dim[1].real_start;
-          }
+	    real_x = dim[2].real_start;
+	    real_y = dim[1].real_start;
+	  }
 
 	  /* this may be a good location */
 	  if (FScreenIsRectangleOnScreen(&fscr, FSCREEN_XYPOS, &ref))
@@ -1186,43 +1234,43 @@ void AutoPlaceIcon(FvwmWindow *t, initial_window_options_type *win_opts)
 	  {
 	    loc_ok_wrong_screen2 = True;
 	  }
-          test_fw = Scr.FvwmRoot.next;
-          while((test_fw != (FvwmWindow *)0)
-                &&(loc_ok == True || loc_ok_wrong_screen2))
+	  test_fw = Scr.FvwmRoot.next;
+	  while((test_fw != (FvwmWindow *)0)
+		&&(loc_ok == True || loc_ok_wrong_screen2))
 	  {
 	    /* test overlap */
-            if(test_fw->Desk == t->Desk)
+	    if(test_fw->Desk == t->Desk)
 	    {
 	      rectangle g;
 
-              if((IS_ICONIFIED(test_fw)) &&
-                 (!IS_TRANSIENT(test_fw) ||
+	      if((IS_ICONIFIED(test_fw)) &&
+		 (!IS_TRANSIENT(test_fw) ||
 		  !IS_ICONIFIED_BY_PARENT(test_fw)) &&
-                 (FW_W_ICON_TITLE(test_fw)||FW_W_ICON_PIXMAP(test_fw)) &&
-                 (test_fw != t)) {
+		 (FW_W_ICON_TITLE(test_fw)||FW_W_ICON_PIXMAP(test_fw)) &&
+		 (test_fw != t)) {
 		get_icon_geometry(test_fw, &g);
-                if((g.x<(real_x+width+MIN_ICON_BOX_DIST))&&
+		if((g.x<(real_x+width+MIN_ICON_BOX_DIST))&&
 		   ((g.x+g.width+MIN_ICON_BOX_DIST) > real_x)&&
-                   (g.y<(real_y+height+MIN_ICON_BOX_DIST))&&
+		   (g.y<(real_y+height+MIN_ICON_BOX_DIST))&&
 		   ((g.y+g.height + MIN_ICON_BOX_DIST)>real_y))
 		{
 		  /* don't accept this location */
-                  loc_ok = False;
-                  loc_ok_wrong_screen2 = False;
-                } /* end if icons overlap */
-              } /* end if its an icon */
-            } /* end if same desk */
-            test_fw = test_fw->next;
-          } /* end while icons that may overlap */
+		  loc_ok = False;
+		  loc_ok_wrong_screen2 = False;
+		} /* end if icons overlap */
+	      } /* end if its an icon */
+	    } /* end if same desk */
+	    test_fw = test_fw->next;
+	  } /* end while icons that may overlap */
 	  if (loc_ok_wrong_screen2)
 	  {
 	    loc_ok_wrong_screen = True;
 	  }
 	  /* Grid inner value & direction */
-          dim[2].start_at += dim[2].step;
-        } /* end while room inner dimension */
+	  dim[2].start_at += dim[2].step;
+	} /* end while room inner dimension */
 	/* Grid outer value & direction */
-        dim[1].start_at += dim[1].step;
+	dim[1].start_at += dim[1].step;
       } /* end while room outer dimension */
     } /* end for all icon boxes, or found space */
     if (!loc_ok && !loc_ok_wrong_screen)
@@ -1252,7 +1300,7 @@ static icon_boxes *global_icon_box_ptr;
 static int
 do_all_iconboxes(FvwmWindow *t, icon_boxes **icon_boxes_ptr)
 {
-  if (global_icon_box_ptr == 0) {       /* if first time */
+  if (global_icon_box_ptr == 0) {	/* if first time */
     int sx;
     int sy;
     int sw;
@@ -1269,25 +1317,25 @@ do_all_iconboxes(FvwmWindow *t, icon_boxes **icon_boxes_ptr)
     global_icon_box_ptr->IconGrid[1] = 80;
     global_icon_box_ptr->IconFlags = ICONFILLHRZ;
   }
-  if (*icon_boxes_ptr == NULL) {        /* first time? */
-    *icon_boxes_ptr = t->IconBoxes;     /* start at windows box */
-    if (!*icon_boxes_ptr) {             /* if window has no box */
+  if (*icon_boxes_ptr == NULL) {	/* first time? */
+    *icon_boxes_ptr = t->IconBoxes;	/* start at windows box */
+    if (!*icon_boxes_ptr) {		/* if window has no box */
       *icon_boxes_ptr = global_icon_box_ptr; /* use global box */
     }
-    return (1);                         /* use box */
+    return (1);				/* use box */
   }
 
   /* Here its not the first call, we are either on the chain or at
      the global box */
   if (*icon_boxes_ptr == global_icon_box_ptr) { /* if the global box */
-    return (0);                         /* completely out of boxes (unlikely) */
+    return (0);				/* completely out of boxes (unlikely) */
   }
   *icon_boxes_ptr = (*icon_boxes_ptr)->next; /* move to next one on chain */
-  if (*icon_boxes_ptr) {                /* if there is a next one */
-    return (1);                         /* return it */
+  if (*icon_boxes_ptr) {		/* if there is a next one */
+    return (1);				/* return it */
   }
   *icon_boxes_ptr = global_icon_box_ptr; /* global box */
-  return (1);                           /* use it */
+  return (1);				/* use it */
 }
 
 /****************************************************************************
@@ -1524,8 +1572,8 @@ void DeIconify(FvwmWindow *fw)
 	  t->frame_g.y -=
 	    truncate_to_multiple(t->frame_g.y,Scr.MyDisplayHeight);
 	  XMoveWindow(dpy, FW_W_FRAME(t), t->frame_g.x, t->frame_g.y);
-          update_absolute_geometry(t);
-          maximize_adjust_offset(t);
+	  update_absolute_geometry(t);
+	  maximize_adjust_offset(t);
 	}
       }
       /* domivogt (1-Mar-2000): The next block is a hack to prevent animation
@@ -1749,16 +1797,16 @@ void Iconify(FvwmWindow *fw, initial_window_options_type *win_opts)
   /* if this fails it does not overwrite icon_rect */
   EWMH_GetIconGeometry(fw, &icon_rect);
   BroadcastPacket(M_ICONIFY, 11,
-                  FW_W(fw), FW_W_FRAME(fw),
-                  (unsigned long)fw,
-                  icon_rect.x,
-                  icon_rect.y,
-                  icon_rect.width,
-                  icon_rect.height,
-                  fw->frame_g.x, /* next 4 added for Animate module */
-                  fw->frame_g.y,
-                  fw->frame_g.width,
-                  fw->frame_g.height);
+		  FW_W(fw), FW_W_FRAME(fw),
+		  (unsigned long)fw,
+		  icon_rect.x,
+		  icon_rect.y,
+		  icon_rect.width,
+		  icon_rect.height,
+		  fw->frame_g.x, /* next 4 added for Animate module */
+		  fw->frame_g.y,
+		  fw->frame_g.width,
+		  fw->frame_g.height);
   BroadcastConfig(M_CONFIGURE_WINDOW,fw);
 
   if (win_opts->initial_state != IconicState ||
