@@ -16,10 +16,6 @@
 
 /* ---------------------------- included header files ----------------------- */
 
-#include <config.h>
-#include <stdio.h>
-
-
 #include "config.h"
 
 #include <stdio.h>
@@ -285,29 +281,29 @@ static void menustyle_parse_old_style(F_CMD_ARGS)
 	}
 
 	if (fore)
-        {
+	{
 		free(fore);
-        }
+	}
 	if (back)
-        {
+	{
 		free(back);
-        }
+	}
 	if (stipple)
-        {
+	{
 		free(stipple);
-        }
+	}
 	if (font)
-        {
+	{
 		free(font);
-        }
+	}
 	if (style)
-        {
+	{
 		free(style);
-        }
+	}
 	if (animated)
-        {
+	{
 		free(animated);
-        }
+	}
 
 	return;
 }
@@ -1560,6 +1556,7 @@ void CMD_CopyMenuStyle(F_CMD_ARGS)
 	ST_POPUP_DELAY(destms) = ST_POPUP_DELAY(origms);
 	/* PopupOffset */
 	ST_POPUP_OFFSET_PERCENT(destms) = ST_POPUP_OFFSET_PERCENT(origms);
+	ST_POPUP_OFFSET_ADD(destms) = ST_POPUP_OFFSET_ADD(origms);
 	/* TitleWarp */
 	ST_DO_WARP_TO_TITLE(destms) = ST_DO_WARP_TO_TITLE(origms);
 	/* TitleUnderlines */
