@@ -5,20 +5,18 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef MODCONF_H
 #define MODCONF_H
 
-void DestroyModConfig(F_CMD_ARGS);
-void AddModConfig(F_CMD_ARGS);
-void ModuleConfig(F_CMD_ARGS);
-void SendDataToModule(F_CMD_ARGS);
+
+void ModuleConfig(char *action);
 
 #endif /* MODCONF_H */
