@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /****************************************************************************
@@ -72,9 +72,9 @@ static int SmartPlacement(
   FvwmWindow *t, rectangle *screen_g,
   int width, int height, int *x, int *y, int pdeltax, int pdeltay)
 {
-  int PageLeft   = screen_g->x - pdeltax;
-  int PageTop    = screen_g->y - pdeltay;
-  int PageRight  = PageLeft + screen_g->width;
+  int PageLeft	 = screen_g->x - pdeltax;
+  int PageTop	 = screen_g->y - pdeltay;
+  int PageRight	 = PageLeft + screen_g->width;
   int PageBottom = PageTop + screen_g->height;
   int temp_h;
   int temp_w;
@@ -108,15 +108,15 @@ static int SmartPlacement(
 	if (t == test_fw || IS_EWMH_DESKTOP(FW_W(test_fw)))
 	  continue;
 
-        /*  RBW - account for sticky windows...  */
-        if (test_fw->Desk == t->Desk || IS_STICKY(test_fw))
-        {
-          if (IS_STICKY(test_fw))
+	/*  RBW - account for sticky windows...	 */
+	if (test_fw->Desk == t->Desk || IS_STICKY(test_fw))
+	{
+	  if (IS_STICKY(test_fw))
 	  {
 	    stickyx = pdeltax;
 	    stickyy = pdeltay;
 	  }
-          else
+	  else
 	  {
 	    stickyx = 0;
 	    stickyy = 0;
@@ -129,15 +129,15 @@ static int SmartPlacement(
 	    ty = g.y - stickyy;
 	    tw = g.width;
 	    th = g.height;
-            if (tx < test_x + width  && test_x < tx + tw &&
+	    if (tx < test_x + width  && test_x < tx + tw &&
 		ty < test_y + height && test_y < ty + th)
-            {
+	    {
 	      /* window overlaps, look for a different place */
-              loc_ok = False;
-              test_x = tx + tw - 1;
-            }
+	      loc_ok = False;
+	      test_x = tx + tw - 1;
+	    }
 	  }
-        } /* if (test_fw->Desk == t->Desk || IS_STICKY(test_fw)) */
+	} /* if (test_fw->Desk == t->Desk || IS_STICKY(test_fw)) */
       } /* for */
       if (!loc_ok)
 	test_x +=1;
@@ -158,8 +158,8 @@ static int SmartPlacement(
 
 /* CleverPlacement by Anthony Martin <amartin@engr.csulb.edu>
  * This function will place a new window such that there is a minimum amount
- * of interference with other windows.  If it can place a window without any
- * interference, fine.  Otherwise, it places it so that the area of of
+ * of interference with other windows.	If it can place a window without any
+ * interference, fine.	Otherwise, it places it so that the area of of
  * interference between the new window and the other windows is minimized */
 static void CleverPlacement(
   FvwmWindow *t, style_flags *sflags, rectangle *screen_g,
@@ -424,7 +424,7 @@ static float test_fit(
   float anew;
   float cover_factor = 0;
   float avoidance_factor;
-  int PageRight  = screen_g->x + screen_g->width - pdeltax;
+  int PageRight	 = screen_g->x + screen_g->width - pdeltax;
   int PageBottom = screen_g->y + screen_g->height - pdeltay;
   int stickyx, stickyy;
   rectangle g;
@@ -469,15 +469,15 @@ static float test_fit(
       yb = MIN(y12, y22);
       anew = (xr - xl) * (yb - yt);
       if (IS_ICONIFIED(testw))
-        avoidance_factor = ICON_PLACEMENT_PENALTY(testw);
+	avoidance_factor = ICON_PLACEMENT_PENALTY(testw);
       else if(compare_window_layers(testw, t) > 0)
-        avoidance_factor = ONTOP_PLACEMENT_PENALTY(testw);
+	avoidance_factor = ONTOP_PLACEMENT_PENALTY(testw);
       else if(compare_window_layers(testw, t) < 0)
-        avoidance_factor = BELOW_PLACEMENT_PENALTY(testw);
+	avoidance_factor = BELOW_PLACEMENT_PENALTY(testw);
       else if(IS_STICKY(testw))
-        avoidance_factor = STICKY_PLACEMENT_PENALTY(testw);
+	avoidance_factor = STICKY_PLACEMENT_PENALTY(testw);
       else
-        avoidance_factor = NORMAL_PLACEMENT_PENALTY(testw);
+	avoidance_factor = NORMAL_PLACEMENT_PENALTY(testw);
 
       if (use_percent)
       {
@@ -512,7 +512,7 @@ static float test_fit(
       aoi += anew;
       if (aoi > aoimin && aoimin != -1)
       {
-        return aoi;
+	return aoi;
       }
     }
   }
@@ -576,7 +576,7 @@ Bool PlaceWindow(
    * 3. Put it on the desk it was on before the restart.
    * 4. Transients go on the same desk as their parents.
    * 5. Window groups stay together (if the KeepWindowGroupsOnDesk style is
-   *    used).
+   *	used).
    */
 
   /*
@@ -615,7 +615,7 @@ Bool PlaceWindow(
 	 (SPLACEMENT_MODE(sflags) == PLACE_MANUAL ||
 	  SPLACEMENT_MODE(sflags) == PLACE_MANUAL_B ||
 	  SPLACEMENT_MODE(sflags) == PLACE_TILEMANUAL) &&
-         !SMANUAL_PLACEMENT_HONORS_STARTS_ON_PAGE(sflags)))
+	 !SMANUAL_PLACEMENT_HONORS_STARTS_ON_PAGE(sflags)))
     {
       flags.do_honor_starts_on_page = False;
       fvwm_msg(WARN, "PlaceWindow",
@@ -707,10 +707,10 @@ Bool PlaceWindow(
       for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
       {
 	if (FW_W(t) == FW_W_TRANSIENTFOR(fw))
-        {
+	{
 	  fw->Desk = t->Desk;
-          break;
-        }
+	  break;
+	}
       }
     }
 
@@ -738,7 +738,7 @@ Bool PlaceWindow(
 
   /* I think it would be good to switch to the selected desk
    * whenever a new window pops up, except during initialization */
-  /*  RBW - 11/02/1998  --  I dont. */
+  /*  RBW - 11/02/1998	--  I dont. */
   if ((!win_opts->flags.do_override_ppos)&&(!DO_NOT_SHOW_ON_MAP(fw)))
   {
     goto_desk(fw->Desk);
@@ -763,11 +763,11 @@ Bool PlaceWindow(
       else if (flags.do_honor_starts_on_page)
       {
 	/*  Save the delta from current page */
-	pdeltax     = Scr.Vx - px;
-	pdeltay     = Scr.Vy - py;
+	pdeltax	    = Scr.Vx - px;
+	pdeltay	    = Scr.Vy - py;
 	PageLeft   -= pdeltax;
 	PageRight  -= pdeltax;
-	PageTop    -= pdeltay;
+	PageTop	   -= pdeltay;
 	PageBottom -= pdeltay;
       }
     }
@@ -889,9 +889,9 @@ Bool PlaceWindow(
 			 (unsigned int *)&DragWidth,
 			 (unsigned int *)&DragHeight,
 			 &JunkBW,  &JunkDepth) == 0)
-        {
+	{
 	  MyXUngrabServer(dpy);
-          UngrabEm(GRAB_NORMAL);
+	  UngrabEm(GRAB_NORMAL);
 	  return False;
 	}
 	SET_PLACED_BY_FVWM(fw,False);
@@ -932,8 +932,8 @@ Bool PlaceWindow(
       }
       if (flags.do_honor_starts_on_page)
       {
-        xl -= pdeltax;
-        yt -= pdeltay;
+	xl -= pdeltax;
+	yt -= pdeltay;
       }
       attr_g->y = yt;
       attr_g->x = xl;
@@ -953,38 +953,56 @@ Bool PlaceWindow(
       /* fall through to cascade placement */
     case PLACE_CASCADE:
     case PLACE_CASCADE_B:
-      /*  either "smart" placement fail and the second choice is "random"
-	  placement (TileCascade) or we have a "random" placement in any case
+      /*  either "smart" placement fail and the second choice is "cascade"
+	  placement (TileCascade) or we have a "cascade" placement in any case
 	  (Cascade) or we have a crazy SPLACEMENT_MODE(sflags) value set with
 	  the old Style Dumb/Smart, Random/Active, Smart/SmartOff (i.e.:
 	  Dumb+Random+Smart or Dumb+Active+Smart)
       */
-      if ((Scr.randomx += fw->title_thickness) > screen_g.width / 2)
+      if (Scr.cascade_window != NULL)
       {
-	Scr.randomx = fw->title_thickness;
+	Scr.cascade_x += fw->title_thickness;
+	Scr.cascade_y += 2 * fw->title_thickness;
       }
-      if ((Scr.randomy += 2 * fw->title_thickness) > screen_g.height / 2)
+      Scr.cascade_window = fw;
+      if (Scr.cascade_x > screen_g.width / 2)
       {
-	Scr.randomy = 2 * fw->title_thickness;
+	Scr.cascade_x = fw->title_thickness;
       }
-      attr_g->x = Scr.randomx + PageLeft - pdeltax;
-      attr_g->y = Scr.randomy + PageTop - pdeltay;
-      /* try to keep the window on the screen */
+      if (Scr.cascade_y > screen_g.height / 2)
+      {
+	Scr.cascade_y = 2 * fw->title_thickness;
+      }
+      attr_g->x = Scr.cascade_x + PageLeft - pdeltax;
+      attr_g->y = Scr.cascade_y + PageTop - pdeltay;
+
+      /* migo: what should these crazy calculations mean? */
+#if 0
       fw->frame_g.x = PageLeft + attr_g->x + fw->attr_backup.border_width + 10;
       fw->frame_g.y = PageTop + attr_g->y + fw->attr_backup.border_width + 10;
+#endif
 
+      /* try to keep the window on the screen */
       get_window_borders(fw, &b);
       if (attr_g->x + fw->frame_g.width >= PageRight)
       {
-	attr_g->x = PageRight - attr_g->width - fw->attr_backup.border_width -
-		b.total_size.width;
-	Scr.randomx = 0;
+	attr_g->x = PageRight - attr_g->width - b.total_size.width;
+	Scr.cascade_x = fw->title_thickness;
       }
       if (attr_g->y + fw->frame_g.height >= PageBottom)
       {
-	attr_g->y = PageBottom - attr_g->height - fw->attr_backup.border_width -
-		b.total_size.height;
-	Scr.randomy = 0;
+	attr_g->y = PageBottom - attr_g->height - b.total_size.height;
+	Scr.cascade_y = 2 * fw->title_thickness;
+      }
+
+      /* the left and top sides are more important in huge windows */
+      if (attr_g->x < 0)
+      {
+	attr_g->x = 0;
+      }
+      if (attr_g->y < 0)
+      {
+	attr_g->y = 0;
       }
       break;
     case PLACE_MINOVERLAP:
@@ -1032,7 +1050,7 @@ Bool PlaceWindow(
     }
 
     /*
-     *  If SkipMapping, and other legalities are observed, adjust for
+     *	If SkipMapping, and other legalities are observed, adjust for
      * StartsOnPage.
      */
     if ( ( DO_NOT_SHOW_ON_MAP(fw) && flags.do_honor_starts_on_page )  &&
@@ -1043,11 +1061,11 @@ Bool PlaceWindow(
 	   ((SUSE_NO_PPOSITION(sflags)) ||
 	    !(fw->hints.flags & PPosition)) &&
 
-           /*  RBW - allow StartsOnPage to go through, even if iconic.  */
-           ( ((!((fw->wmhints)&&
+	   /*  RBW - allow StartsOnPage to go through, even if iconic.	*/
+	   ( ((!((fw->wmhints)&&
 		 (fw->wmhints->flags & StateHint)&&
 		 (fw->wmhints->initial_state == IconicState)))
-              || (flags.do_honor_starts_on_page)) )
+	      || (flags.do_honor_starts_on_page)) )
 
 	   ) )
     {
@@ -1111,9 +1129,9 @@ Bool PlaceWindow(
       if (mode == PLACE_INITIAL)
       {
 	get_window_borders(fw, &b);
-        gravity_resize(
-          fw->hints.win_gravity, &final_g,
-          b.total_size.width, b.total_size.height);
+	gravity_resize(
+	  fw->hints.win_gravity, &final_g,
+	  b.total_size.width, b.total_size.height);
       }
       attr_g->x = final_g.x;
       attr_g->y = final_g.y;
