@@ -7,20 +7,17 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef _REPEAT_
 #define _REPEAT_
 
-#include "fvwm.h"
-#include "functions.h"
-
 typedef enum
 {
   REPEAT_NONE = 0,
@@ -49,8 +46,6 @@ extern char *repeat_last_menu;
 extern FvwmWindow *repeat_last_fvwm_window;
 */
 
-void repeat_function(F_CMD_ARGS);
-Bool set_repeat_data(void *data, repeat_type type,
-		     const struct functions *builtin);
+Bool set_repeat_data(void *data, repeat_type type, const func_type *builtin);
 
 #endif /* _REPEAT_ */
