@@ -5,21 +5,21 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /* File: session.h
  *
  * Description:
- *       exports from session.c shall go into this file
+ *	 exports from session.c shall go into this file
  *
  * Created:
- *       4 April 1999 - Steve Robbins <steve@nyongwa.montreal.qc.ca>
+ *	 4 April 1999 - Steve Robbins <steve@nyongwa.montreal.qc.ca>
  */
 
 #ifndef SESSION_H
@@ -60,8 +60,16 @@ void RestartInSession (char *filename, Bool isNative, Bool doPreserveState);
 **  The dimensions returned in x, y, w, h should be used when the
 **  window is to be maximized.
  */
+typedef struct
+{
+	int shade_dir;
+	int do_shade : 1;
+	int used_title_dir_for_shading : 1;
+	unsigned do_max : 1;
+} mwtsm_state_args;
+
 Bool MatchWinToSM(
-	FvwmWindow *ewin, int *do_shade, int *shade_dir, int *do_max,
+	FvwmWindow *ewin, mwtsm_state_args *ret_state_args,
 	initial_window_options_type *win_opts);
 
 #ifdef SESSION
