@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef _STACK_H
@@ -43,11 +43,6 @@ void new_layer(FvwmWindow *t, int layer);
 void init_stack_and_layers(void);
 Bool is_on_top_of_layer(FvwmWindow *t);
 
-void raiselower_func(F_CMD_ARGS);
-void raise_function(F_CMD_ARGS);
-void lower_function(F_CMD_ARGS);
-void change_layer(F_CMD_ARGS);
-void SetDefaultLayers(F_CMD_ARGS);
 /* This function recursively finds the transients of the window t and sets their
  * is_in_transient_subtree flag.  If a layer is given, only windows in this
  * layer are checked.  If the layer is < 0, all windows are considered.
