@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef _STYLE_
@@ -19,37 +19,37 @@
 /* access to the special flags of a style */
 /* call these with a pointer to a style_flags struct */
 #define SDO_DECORATE_TRANSIENT(sf)    ((sf)->do_decorate_transient)
-#define SDO_SAVE_UNDER(sf)            ((sf)->do_save_under)
-#define SDO_START_LOWERED(sf)         ((sf)->do_start_lowered)
-#define SHAS_BORDER_WIDTH(sf)         ((sf)->has_border_width)
-#define SHAS_COLOR_BACK(sf)           ((sf)->has_color_back)
-#define SHAS_COLOR_FORE(sf)           ((sf)->has_color_fore)
-#define SHAS_HANDLE_WIDTH(sf)         ((sf)->has_handle_width)
-#define SHAS_ICON(sf)                 ((sf)->has_icon)
-#define SHAS_ICON_BOXES(sf)           ((sf)->has_icon_boxes)
+#define SDO_SAVE_UNDER(sf)	      ((sf)->do_save_under)
+#define SDO_START_LOWERED(sf)	      ((sf)->do_start_lowered)
+#define SHAS_BORDER_WIDTH(sf)	      ((sf)->has_border_width)
+#define SHAS_COLOR_BACK(sf)	      ((sf)->has_color_back)
+#define SHAS_COLOR_FORE(sf)	      ((sf)->has_color_fore)
+#define SHAS_HANDLE_WIDTH(sf)	      ((sf)->has_handle_width)
+#define SHAS_ICON(sf)		      ((sf)->has_icon)
+#define SHAS_ICON_BOXES(sf)	      ((sf)->has_icon_boxes)
 #define SHAS_MAX_WINDOW_SIZE(sf)      ((sf)->has_max_window_size)
 #define SHAS_WINDOW_SHADE_STEPS(sf)   ((sf)->has_window_shade_steps)
-#define SHAS_MINI_ICON(sf)            ((sf)->has_mini_icon)
-#define SHAS_MWM_DECOR(sf)            ((sf)->has_mwm_decor)
-#define SHAS_MWM_FUNCTIONS(sf)        ((sf)->has_mwm_functions)
-#define SHAS_NO_HANDLES(sf)           ((sf)->has_no_handles)
-#define SHAS_NO_TITLE(sf)             ((sf)->has_no_title)
-#define SHAS_OL_DECOR(sf)             ((sf)->has_ol_decor)
-#define SIS_BUTTON_DISABLED(sf)       ((sf)->is_button_disabled)
-#define SPLACEMENT_MODE(sf)           ((sf)->placement_mode)
+#define SHAS_MINI_ICON(sf)	      ((sf)->has_mini_icon)
+#define SHAS_MWM_DECOR(sf)	      ((sf)->has_mwm_decor)
+#define SHAS_MWM_FUNCTIONS(sf)	      ((sf)->has_mwm_functions)
+#define SHAS_NO_HANDLES(sf)	      ((sf)->has_no_handles)
+#define SHAS_NO_TITLE(sf)	      ((sf)->has_no_title)
+#define SHAS_OL_DECOR(sf)	      ((sf)->has_ol_decor)
+#define SIS_BUTTON_DISABLED(sf)	      ((sf)->is_button_disabled)
+#define SPLACEMENT_MODE(sf)	      ((sf)->placement_mode)
 #define SEWMH_PLACEMENT_MODE(sf)      ((sf)->ewmh_placement_mode)
-#define SUSE_BACKING_STORE(sf)        ((sf)->use_backing_store)
+#define SUSE_BACKING_STORE(sf)	      ((sf)->use_backing_store)
 #define SUSE_PARENT_RELATIVE(sf)      ((sf)->use_parent_relative)
-#define SUSE_COLORSET(sf)             ((sf)->use_colorset)
-#define SUSE_COLORSET_HI(sf)          ((sf)->use_colorset_hi)
+#define SUSE_COLORSET(sf)	      ((sf)->use_colorset)
+#define SUSE_COLORSET_HI(sf)	      ((sf)->use_colorset_hi)
 #define SUSE_BORDER_COLORSET(sf)      ((sf)->use_border_colorset)
 #define SUSE_BORDER_COLORSET_HI(sf)   ((sf)->use_border_colorset_hi)
-#define SUSE_LAYER(sf)                ((sf)->use_layer)
-#define SUSE_NO_PPOSITION(sf)         ((sf)->use_no_pposition)
-#define SUSE_NO_USPOSITION(sf)         ((sf)->use_no_usposition)
-#define SUSE_NO_TRANSIENT_PPOSITION(sf)  ((sf)->use_no_transient_pposition)
+#define SUSE_LAYER(sf)		      ((sf)->use_layer)
+#define SUSE_NO_PPOSITION(sf)	      ((sf)->use_no_pposition)
+#define SUSE_NO_USPOSITION(sf)	       ((sf)->use_no_usposition)
+#define SUSE_NO_TRANSIENT_PPOSITION(sf)	 ((sf)->use_no_transient_pposition)
 #define SUSE_NO_TRANSIENT_USPOSITION(sf) ((sf)->use_no_transient_usposition)
-#define SUSE_START_ON_DESK(sf)        ((sf)->use_start_on_desk)
+#define SUSE_START_ON_DESK(sf)	      ((sf)->use_start_on_desk)
 #define SUSE_START_ON_PAGE_FOR_TRANSIENT(sf) \
   ((sf)->use_start_on_page_for_transient)
 #define SUSE_START_ON_SCREEN(sf)      ((sf)->use_start_on_screen)
@@ -71,16 +71,16 @@
 #define SMGET_COMMON_STATIC_FLAGS(st) ((st).flag_mask.common.s)
 #define SCGET_COMMON_FLAGS(st) ((st).change_mask.common)
 #define SCGET_COMMON_STATIC_FLAGS(st) ((st).change_mask.common.s)
-#define STITLE_DIR(sf)  ((sf).common.title_dir)
+#define STITLE_DIR(sf)	((sf).common.title_dir)
 #define SFTITLE_DIR(st) ((st).flags.common.title_dir)
 #define SMTITLE_DIR(st) ((st).flag_mask.common.title_dir)
 #define SCTITLE_DIR(st) ((st).change_mask.common.title_dir)
 #define SFSET_TITLE_DIR(st,x) \
-          ((st).flags.common.title_dir = x)
+	  ((st).flags.common.title_dir = x)
 #define SMSET_TITLE_DIR(st,x) \
-          ((st).flag_mask.common.title_dir = DIR_MAJOR_MASK * !!(x))
+	  ((st).flag_mask.common.title_dir = DIR_MAJOR_MASK * !!(x))
 #define SCSET_TITLE_DIR(st,x) \
-          ((st).change_mask.common.title_dir = DIR_MAJOR_MASK * !!(x))
+	  ((st).change_mask.common.title_dir = DIR_MAJOR_MASK * !!(x))
 #define SIS_STICKY(sf) ((sf).common.is_sticky)
 #define SFIS_STICKY(st) ((st).flags.common.is_sticky)
 #define SMIS_STICKY(st) ((st).flag_mask.common.is_sticky)
@@ -186,14 +186,14 @@
 #define SFSET_DO_NOT_RAISE_CLICK_FOCUS_CLICK(st,x) ((st).flags.common.s.do_not_raise_click_focus_click = !!(x))
 #define SMSET_DO_NOT_RAISE_CLICK_FOCUS_CLICK(st,x) ((st).flag_mask.common.s.do_not_raise_click_focus_click = !!(x))
 #define SCSET_DO_NOT_RAISE_CLICK_FOCUS_CLICK(st,x) ((st).change_mask.common.s.do_not_raise_click_focus_click = !!(x))
-#define SDO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(sf)  ((sf).common.s.do_ignore_mouse_focus_click_motion)
+#define SDO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(sf)	 ((sf).common.s.do_ignore_mouse_focus_click_motion)
 #define SFDO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(st) ((st).flags.common.s.do_ignore_mouse_focus_click_motion)
 #define SMDO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(st) ((st).flag_mask.common.s.do_ignore_mouse_focus_click_motion)
 #define SCDO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(st) ((st).change_mask.common.s.do_ignore_mouse_focus_click_motion)
 #define SFSET_DO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(st,x) ((st).flags.common.s.do_ignore_mouse_focus_click_motion = !!(x))
 #define SMSET_DO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(st,x) ((st).flag_mask.common.s.do_ignore_mouse_focus_click_motion = !!(x))
 #define SCSET_DO_IGNORE_MOUSE_FOCUS_CLICK_MOTION(st,x) ((st).change_mask.common.s.do_ignore_mouse_focus_click_motion = !!(x))
-#define SDO_RAISE_MOUSE_FOCUS_CLICK(sf)  ((sf).common.s.do_raise_mouse_focus_click)
+#define SDO_RAISE_MOUSE_FOCUS_CLICK(sf)	 ((sf).common.s.do_raise_mouse_focus_click)
 #define SFDO_RAISE_MOUSE_FOCUS_CLICK(st) ((st).flags.common.s.do_raise_mouse_focus_click)
 #define SMDO_RAISE_MOUSE_FOCUS_CLICK(st) ((st).flag_mask.common.s.do_raise_mouse_focus_click)
 #define SCDO_RAISE_MOUSE_FOCUS_CLICK(st) ((st).change_mask.common.s.do_raise_mouse_focus_click)
@@ -242,6 +242,13 @@
 #define SFSET_FOCUS_MODE(st,x) ((st).flags.common.s.focus_mode = (x))
 #define SMSET_FOCUS_MODE(st,x) ((st).flag_mask.common.s.focus_mode = (x))
 #define SCSET_FOCUS_MODE(st,x) ((st).change_mask.common.s.focus_mode = (x))
+#define SHAS_NO_BORDER(sf) ((sf).common.s.has_no_border)
+#define SFHAS_NO_BORDER(st) ((st).flags.common.s.has_no_border)
+#define SMHAS_NO_BORDER(st) ((st).flag_mask.common.s.has_no_border)
+#define SCHAS_NO_BORDER(st) ((st).change_mask.common.s.has_no_border)
+#define SFSET_HAS_NO_BORDER(st,x) ((st).flags.common.s.has_no_border = !!(x))
+#define SMSET_HAS_NO_BORDER(st,x) ((st).flag_mask.common.s.has_no_border = !!(x))
+#define SCSET_HAS_NO_BORDER(st,x) ((st).change_mask.common.s.has_no_border = !!(x))
 #define SHAS_DEPRESSABLE_BORDER(sf) ((sf).common.s.has_depressable_border)
 #define SFHAS_DEPRESSABLE_BORDER(st) ((st).flags.common.s.has_depressable_border)
 #define SMHAS_DEPRESSABLE_BORDER(st) ((st).flag_mask.common.s.has_depressable_border)
@@ -472,68 +479,68 @@
 
 
 /* access to other parts of a style (call with the style itself) */
-#define SGET_NEXT_STYLE(s)            ((s).next)
-#define SSET_NEXT_STYLE(s,x)          ((s).next = (x))
-#define SGET_PREV_STYLE(s)            ((s).prev)
-#define SSET_PREV_STYLE(s,x)          ((s).prev = (x))
-#define SGET_NAME(s)                  ((s).name)
-#define SSET_NAME(s,x)                ((s).name = (x))
-#define SGET_ICON_NAME(s)             ((s).icon_name)
-#define SSET_ICON_NAME(s,x)           ((s).icon_name = (x))
-#define SGET_MINI_ICON_NAME(s)        ((s).mini_icon_name)
+#define SGET_NEXT_STYLE(s)	      ((s).next)
+#define SSET_NEXT_STYLE(s,x)	      ((s).next = (x))
+#define SGET_PREV_STYLE(s)	      ((s).prev)
+#define SSET_PREV_STYLE(s,x)	      ((s).prev = (x))
+#define SGET_NAME(s)		      ((s).name)
+#define SSET_NAME(s,x)		      ((s).name = (x))
+#define SGET_ICON_NAME(s)	      ((s).icon_name)
+#define SSET_ICON_NAME(s,x)	      ((s).icon_name = (x))
+#define SGET_MINI_ICON_NAME(s)	      ((s).mini_icon_name)
 #define SSET_MINI_ICON_NAME(s,x)      ((s).mini_icon_name = (x))
 #ifdef USEDECOR
-#define SGET_DECOR_NAME(s)            ((s).decor_name)
-#define SSET_DECOR_NAME(s,x)          ((s).decor_name = (x))
+#define SGET_DECOR_NAME(s)	      ((s).decor_name)
+#define SSET_DECOR_NAME(s,x)	      ((s).decor_name = (x))
 #endif
-#define SGET_FORE_COLOR_NAME(s)       ((s).fore_color_name)
+#define SGET_FORE_COLOR_NAME(s)	      ((s).fore_color_name)
 #define SSET_FORE_COLOR_NAME(s,x)     ((s).fore_color_name = (x))
-#define SGET_BACK_COLOR_NAME(s)       ((s).back_color_name)
+#define SGET_BACK_COLOR_NAME(s)	      ((s).back_color_name)
 #define SSET_BACK_COLOR_NAME(s,x)     ((s).back_color_name = (x))
 #define SGET_FORE_COLOR_NAME_HI(s)    ((s).fore_color_name_hi)
 #define SSET_FORE_COLOR_NAME_HI(s,x)  ((s).fore_color_name_hi = (x))
 #define SGET_BACK_COLOR_NAME_HI(s)    ((s).back_color_name_hi)
 #define SSET_BACK_COLOR_NAME_HI(s,x)  ((s).back_color_name_hi = (x))
-#define SGET_ICON_FONT(s)             ((s).icon_font)
-#define SSET_ICON_FONT(s,x)           ((s).icon_font = (x))
-#define SGET_WINDOW_FONT(s)           ((s).window_font)
-#define SSET_WINDOW_FONT(s,x)         ((s).window_font = (x))
-#define SGET_COLORSET(s)              ((s).colorset)
-#define SSET_COLORSET(s,x)            ((s).colorset = (x))
+#define SGET_ICON_FONT(s)	      ((s).icon_font)
+#define SSET_ICON_FONT(s,x)	      ((s).icon_font = (x))
+#define SGET_WINDOW_FONT(s)	      ((s).window_font)
+#define SSET_WINDOW_FONT(s,x)	      ((s).window_font = (x))
+#define SGET_COLORSET(s)	      ((s).colorset)
+#define SSET_COLORSET(s,x)	      ((s).colorset = (x))
 #define SSET_BORDER_COLORSET(s,x)     ((s).border_colorset = (x))
-#define SGET_BORDER_COLORSET(s)       ((s).border_colorset)
-#define SGET_COLORSET_HI(s)           ((s).colorset_hi)
-#define SSET_COLORSET_HI(s,x)         ((s).colorset_hi = (x))
+#define SGET_BORDER_COLORSET(s)	      ((s).border_colorset)
+#define SGET_COLORSET_HI(s)	      ((s).colorset_hi)
+#define SSET_COLORSET_HI(s,x)	      ((s).colorset_hi = (x))
 #define SGET_BORDER_COLORSET_HI(s)    ((s).border_colorset_hi)
 #define SSET_BORDER_COLORSET_HI(s,x)  ((s).border_colorset_hi = (x))
-#define SGET_FLAGS_POINTER(s)         (&((s).flags))
-#define SGET_BORDER_WIDTH(s)          ((s).border_width)
-#define SSET_BORDER_WIDTH(s,x)        ((s).border_width = (x))
-#define SGET_HANDLE_WIDTH(s)          ((s).handle_width)
-#define SSET_HANDLE_WIDTH(s,x)        ((s).handle_width = (x))
-#define SGET_LAYER(s)                 ((s).layer)
-#define SSET_LAYER(s,x)               ((s).layer = (x))
-#define SGET_START_DESK(s)            ((s).start_desk)
-#define SSET_START_DESK(s,x)          ((s).start_desk = (x))
-#define SGET_START_PAGE_X(s)          ((s).start_page_x)
-#define SSET_START_PAGE_X(s,x)        ((s).start_page_x = (x))
-#define SGET_START_PAGE_Y(s)          ((s).start_page_y)
-#define SSET_START_PAGE_Y(s,x)        ((s).start_page_y = (x))
-#define SGET_START_SCREEN(s)          ((s).start_screen)
-#define SSET_START_SCREEN(s,x)        ((s).start_screen = (x))
+#define SGET_FLAGS_POINTER(s)	      (&((s).flags))
+#define SGET_BORDER_WIDTH(s)	      ((s).border_width)
+#define SSET_BORDER_WIDTH(s,x)	      ((s).border_width = (x))
+#define SGET_HANDLE_WIDTH(s)	      ((s).handle_width)
+#define SSET_HANDLE_WIDTH(s,x)	      ((s).handle_width = (x))
+#define SGET_LAYER(s)		      ((s).layer)
+#define SSET_LAYER(s,x)		      ((s).layer = (x))
+#define SGET_START_DESK(s)	      ((s).start_desk)
+#define SSET_START_DESK(s,x)	      ((s).start_desk = (x))
+#define SGET_START_PAGE_X(s)	      ((s).start_page_x)
+#define SSET_START_PAGE_X(s,x)	      ((s).start_page_x = (x))
+#define SGET_START_PAGE_Y(s)	      ((s).start_page_y)
+#define SSET_START_PAGE_Y(s,x)	      ((s).start_page_y = (x))
+#define SGET_START_SCREEN(s)	      ((s).start_screen)
+#define SSET_START_SCREEN(s,x)	      ((s).start_screen = (x))
 #define SGET_MAX_WINDOW_WIDTH(s)      ((s).max_window_width)
 #define SSET_MAX_WINDOW_WIDTH(s,x)    ((s).max_window_width = (x))
 #define SGET_MAX_WINDOW_HEIGHT(s)     ((s).max_window_height)
 #define SSET_MAX_WINDOW_HEIGHT(s,x)   ((s).max_window_height = (x))
 #define SGET_WINDOW_SHADE_STEPS(s)    ((s).shade_anim_steps)
 #define SSET_WINDOW_SHADE_STEPS(s,x)  ((s).shade_anim_steps = (x))
-#define SGET_ICON_BOXES(s)            ((s).icon_boxes)
-#define SSET_ICON_BOXES(s,x)          ((s).icon_boxes = (x))
+#define SGET_ICON_BOXES(s)	      ((s).icon_boxes)
+#define SSET_ICON_BOXES(s,x)	      ((s).icon_boxes = (x))
 #define SGET_NORMAL_PLACEMENT_PENALTY(s)       ((s).placement_penalty[0])
-#define SGET_ONTOP_PLACEMENT_PENALTY(s)        ((s).placement_penalty[1])
-#define SGET_ICON_PLACEMENT_PENALTY(s)         ((s).placement_penalty[2])
+#define SGET_ONTOP_PLACEMENT_PENALTY(s)	       ((s).placement_penalty[1])
+#define SGET_ICON_PLACEMENT_PENALTY(s)	       ((s).placement_penalty[2])
 #define SGET_STICKY_PLACEMENT_PENALTY(s)       ((s).placement_penalty[3])
-#define SGET_BELOW_PLACEMENT_PENALTY(s)        ((s).placement_penalty[4])
+#define SGET_BELOW_PLACEMENT_PENALTY(s)	       ((s).placement_penalty[4])
 #define SGET_EWMH_STRUT_PLACEMENT_PENALTY(s)   ((s).placement_penalty[5])
 #define SSET_NORMAL_PLACEMENT_PENALTY(s,x)     ((s).placement_penalty[0] = (x))
 #define SSET_ONTOP_PLACEMENT_PENALTY(s,x)      ((s).placement_penalty[1] = (x))
@@ -542,21 +549,21 @@
 #define SSET_BELOW_PLACEMENT_PENALTY(s,x)      ((s).placement_penalty[4] = (x))
 #define SSET_EWMH_STRUT_PLACEMENT_PENALTY(s,x) ((s).placement_penalty[5] = (x))
 #define SGET_99_PLACEMENT_PERCENTAGE_PENALTY(s) \
-                                    ((s).placement_percentage_penalty[0])
+				    ((s).placement_percentage_penalty[0])
 #define SGET_95_PLACEMENT_PERCENTAGE_PENALTY(s) \
-                                    ((s).placement_percentage_penalty[1])
+				    ((s).placement_percentage_penalty[1])
 #define SGET_85_PLACEMENT_PERCENTAGE_PENALTY(s) \
-                                    ((s).placement_percentage_penalty[2])
+				    ((s).placement_percentage_penalty[2])
 #define SGET_75_PLACEMENT_PERCENTAGE_PENALTY(s) \
-                                    ((s).placement_percentage_penalty[3])
+				    ((s).placement_percentage_penalty[3])
 #define SSET_99_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-                                    ((s).placement_percentage_penalty[0] = (x))
+				    ((s).placement_percentage_penalty[0] = (x))
 #define SSET_95_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-                                    ((s).placement_percentage_penalty[1] = (x))
+				    ((s).placement_percentage_penalty[1] = (x))
 #define SSET_85_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-                                    ((s).placement_percentage_penalty[2] = (x))
+				    ((s).placement_percentage_penalty[2] = (x))
 #define SSET_75_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-                                    ((s).placement_percentage_penalty[3] = (x))
+				    ((s).placement_percentage_penalty[3] = (x))
 
 /* function prototypes */
 void lookup_style(FvwmWindow *fw, window_style *styles);
