@@ -10,18 +10,18 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.GPL.  If not, write to
+ * along with this software; see the file COPYING.GPL.	If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307 USA
  *
  */
 
 
-#include "config.h"                     /* must be first */
+#include "config.h"			/* must be first */
 
 #include <stdio.h>
 #include <X11/Intrinsic.h>
@@ -68,13 +68,13 @@ void AllocColorset(int n)
 /*****************************************************************************
  * DumpColorset() returns a char * to the colorset contents in printable form
  *****************************************************************************/
-static char csetbuf[160];
+static char csetbuf[184];
 char *DumpColorset(int n, colorset_struct *cs)
 {
   sprintf(csetbuf,
-	  "Colorset %x %lx %lx %lx %lx %lx %lx %x %x %x %x %x %x",
-	  n, cs->fg, cs->bg, cs->hilite, cs->shadow, cs->pixmap,
-	  cs->shape_mask, cs->width, cs->height, cs->pixmap_type,
+	  "Colorset %x %lx %lx %lx %lx %lx %lx %lx %x %x %x %x %x %x %x",
+	  n, cs->fg, cs->bg, cs->hilite, cs->shadow, cs->fgsh, cs->pixmap,
+	  cs->shape_mask, cs->fg_alpha, cs->width, cs->height, cs->pixmap_type,
 	  cs->shape_width, cs->shape_height, cs->shape_type);
   return csetbuf;
 }
@@ -86,10 +86,10 @@ int LoadColorset(char *line)
 {
   colorset_struct *cs;
   unsigned int n, chars;
-  Pixel fg, bg, hilite, shadow;
+  Pixel fg, bg, hilite, shadow, fgsh;
   Pixmap pixmap;
   Pixmap shape_mask;
-  unsigned int width, height, pixmap_type;
+  unsigned int fg_alpha, width, height, pixmap_type;
   unsigned int shape_width, shape_height, shape_type;
 
   if (line == NULL)
@@ -97,18 +97,22 @@ int LoadColorset(char *line)
   if (sscanf(line, "%x%n", &n, &chars) < 1)
     return -1;
   line += chars;
-  if (sscanf(line, "%lx %lx %lx %lx %lx %lx %x %x %x %x %x %x",
-	     &fg, &bg, &hilite, &shadow, &pixmap, &shape_mask, &width, &height,
-	     &pixmap_type, &shape_width, &shape_height, &shape_type) != 12)
+  if (sscanf(line, "%lx %lx %lx %lx %lx %lx %lx %x %x %x %x %x %x %x",
+	     &fg, &bg, &hilite, &shadow, &fgsh, &pixmap, &shape_mask, &fg_alpha,
+	     &width, &height, &pixmap_type, &shape_width, &shape_height,
+	     &shape_type) != 14)
     return -1;
+
   AllocColorset(n);
   cs = &Colorset[n];
   cs->fg = fg;
   cs->bg = bg;
   cs->hilite = hilite;
   cs->shadow = shadow;
+  cs->fgsh = fgsh;
   cs->pixmap = pixmap;
   cs->shape_mask = shape_mask;
+  cs->fg_alpha = fg_alpha;
   cs->width = width;
   cs->height = height;
   cs->pixmap_type = pixmap_type;
