@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef LIBS_COLORSETS_H
@@ -27,8 +27,10 @@ typedef struct {
   Pixel bg;
   Pixel hilite;
   Pixel shadow;
+  Pixel fgsh;
   Pixmap pixmap;
   Pixmap shape_mask;
+  unsigned int fg_alpha : 7;
   unsigned int width : 12;
   unsigned int height : 12;
   unsigned int pixmap_type: 3;
@@ -37,13 +39,13 @@ typedef struct {
   unsigned int shape_type : 2;
 #ifdef FVWM_COLORSET_PRIVATE
   /* fvwm/colorset.c use only */
+  Pixel tint;
   Pixmap mask;
   Pixmap alpha_pixmap;
   unsigned int color_flags : 7;
   FvwmPicture *picture;
   Pixel *pixels;
   int nalloc_pixels;
-  Pixel tint;
   int tint_percent;
   Bool do_tint_use_mask;
 #endif
@@ -58,14 +60,16 @@ typedef struct {
 #define SHAPE_TILED 0
 #define SHAPE_STRETCH 1
 #define SHAPE_STRETCH_ASPECT 2
+
 #ifdef FVWM_COLORSET_PRIVATE
 #define FG_SUPPLIED 0x1
 #define BG_SUPPLIED 0x2
 #define HI_SUPPLIED 0x4
 #define SH_SUPPLIED 0x8
-#define FG_CONTRAST 0x10
-#define BG_AVERAGE  0x20
-#define TINT_SUPPLIED  0x40
+#define FGSH_SUPPLIED 0x10
+#define FG_CONTRAST 0x20
+#define BG_AVERAGE  0x40
+#define TINT_SUPPLIED  0x80
 #endif
 
 /* colorsets are stored as an array of structs to permit fast dereferencing */
