@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /*
@@ -83,10 +83,9 @@ FvwmPacket* ReadFvwmPacket( int fd )
  * finished its startup procedures and is fully operational now.
  *
  ***********************************************************************/
-char *ModuleFinished = "NOP FINISHED STARTUP";
 void SendFinishedStartupNotification(int *fd)
 {
-  SendText(fd, ModuleFinished, 0);
+  SendText(fd, ModuleFinishedStartupResponse, 0);
 }
 
 /************************************************************************
@@ -95,10 +94,9 @@ void SendFinishedStartupNotification(int *fd)
  * finished it's procedures and fvwm may proceed.
  *
  ***********************************************************************/
-char *ModuleUnlock = "NOP UNLOCK";
 void SendUnlockNotification(int *fd)
 {
-  SendText(fd, ModuleUnlock, 0);
+  SendText(fd, ModuleUnlockResponse, 0);
 }
 
 /************************************************************************
@@ -111,7 +109,7 @@ static unsigned long ModuleContinue = 1;
 void SendQuitNotification(int *fd)
 {
   ModuleContinue = 0;
-  SendText(fd, ModuleUnlock, 0); /* unlock just in case */
+  SendText(fd, ModuleUnlockResponse, 0); /* unlock just in case */
 }
 
 /************************************************************************
@@ -179,9 +177,9 @@ void SendFvwmPipe(int *fd, const char *message, unsigned long window)
    * storage because we don't need to modify it ...
    *
    * NOTE: this makes this second call to SendText()
-   *       distinct from the first call. Two calls is
-   *       cleaner than hacking the loop to make only
-   *       one call.
+   *	   distinct from the first call. Two calls is
+   *	   cleaner than hacking the loop to make only
+   *	   one call.
    */
   SendText(fd, hold, window);
 }
@@ -221,7 +219,7 @@ static int first_pass = 1;
 void InitGetConfigLine(int *fd,char *match)
 {
   char *buffer = (char *)alloca(strlen(match) + 32);
-  first_pass = 0;                       /* make sure get wont do this */
+  first_pass = 0;			/* make sure get wont do this */
   sprintf(buffer,"Send_ConfigInfo %s",match);
   SendText(fd,buffer,0);
 }
@@ -234,7 +232,7 @@ void InitGetConfigLine(int *fd,char *match)
  * Changed 10/19/98 by Dan Espen:
  *
  * - The "isspace"  call was referring to  memory  beyond the end of  the
- * input area.  This could have led to the creation of a core file. Added
+ * input area.	This could have led to the creation of a core file. Added
  * "body_size" to keep it in bounds.
  **************************************************************************/
 void GetConfigLine(int *fd, char **tline)
@@ -262,8 +260,8 @@ void GetConfigLine(int *fd, char **tline)
     body_count = FvwmPacketBodySize(*packet) * sizeof(unsigned long);
 
     while ( body_count > 0 && isspace((unsigned char)**tline) ) {
-        (*tline)++;
-        --body_count;
+	(*tline)++;
+	--body_count;
     }
 }
 
