@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /*
@@ -96,6 +96,32 @@ void CopyString(char **dest, const char *source)
   (*dest)[len]=0;
 }
 
+
+void CopyStringWithQuotes(char **dest, const char *src)
+{
+	while (src && src[0] == ' ')
+	{
+		src++;
+	}
+	if (src && src[0] == '"')
+	{
+		int len;
+
+		src++;
+		CopyString(dest, src);
+		len = strlen(*dest);
+		if (len > 0 && (*dest)[len - 1] == '"')
+		{
+			(*dest)[len - 1] = '\0';
+		}
+	}
+	else
+	{
+		CopyString(dest, src);
+	}
+}
+
+
 /****************************************************************************
  *
  * Copies a string into a new, malloc'ed string
@@ -145,3 +171,27 @@ int StrHasPrefix( const char* string, const char* prefix )
     if ( string == NULL ) return 0;
     return strncasecmp( string, prefix, strlen(prefix) ) == 0;
 }
+
+
+/****************************************************************************
+ *
+ * Adds single quotes arround the string and escapes single quotes with
+ * backslashes.	 The result is placed in the given dest, not allocated.
+ * The end of destination, i.e. pointer to '\0' is returned.
+ * You should allocate dest yourself, at least strlen(source) * 2 + 3.
+ *
+ ****************************************************************************/
+char *QuoteString(char *dest, const char *source)
+{
+  int i = 0;
+  *dest++ = '\'';
+  for(i = 0; source[i]; i++)
+  {
+    if (source[i] == '\'')
+      *dest++ = '\\';
+    *dest++ = source[i];
+  }
+  *dest++ = '\'';
+  *dest = '\0';
+  return dest;
+}
