@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /*
@@ -26,6 +26,11 @@
 #endif
 #include <sys/stat.h>
 
+/* needed for QNX to define FD_SETSIZE */
+#if HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
+
 
 /*
 ** just in case...
@@ -52,7 +57,7 @@ int getostype(char *buf, int max)
     struct utsname sysname;
 
     if ( uname( &sysname ) >= 0 ) {
-        buf[0] = '\0';
+	buf[0] = '\0';
 	strncat( buf, sysname.sysname, max );
 	return 0;
     }
