@@ -7,20 +7,22 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /*
 ** WinMagic.c:
-** This file supplied routines for moving and resizing windows in an animated
+** This file supplies routines for moving and resizing windows in an animated
 ** fashion.
 */
 
+#include "config.h"
+
 #include <X11/Xlib.h>
 #include <fvwmlib.h>
 #include <stdio.h>
@@ -49,7 +51,7 @@ void SlideWindow(
   int w = 0;
   int h = 0;
   int g_w = 0;
-  int g_h = 0;  /* -Wall fixes :o( */
+  int g_h = 0;	/* -Wall fixes :o( */
   int min_w = 1;
   int min_h = 1;
   int inc_w = 1;
