@@ -34,7 +34,7 @@ static int term_sigs;
  * trying to access the same static data at the same time.
  *
  * NOTE: We don't need this if we have POSIX.1 since we can install
- *       a signal mask automatically using sigaction()
+ *	 a signal mask automatically using sigaction()
  */
 void
 fvwmSetSignalMask(int sigmask)
@@ -47,7 +47,7 @@ fvwmSetSignalMask(int sigmask)
  * fvwmGetSignalMask - get the set of signals that will terminate FVWM
  *
  * NOTE: We don't need this if we have POSIX.1 since we can install
- *       a signal mask automatically using sigaction()
+ *	 a signal mask automatically using sigaction()
  */
 int
 fvwmGetSignalMask(void)
@@ -80,14 +80,14 @@ fvwmSetTerminate(int sig)
   if (canJump)
   {
     canJump = false;
-    errno = EINTR;
+
     /*
      * This non-local jump is safe ONLY because we haven't called
      * any non-reentrant functions in the short period where the
      * "canJump" variable is true.
      *
      * NOTE: No need to restore the signal mask, since siglongjmp
-     *       is designed to do that for us.
+     *	     is designed to do that for us.
      */
     siglongjmp(deadJump, SIG_DONE);
   }
@@ -105,10 +105,23 @@ fvwmSetTerminate(int sig)
  */
 int
 fvwmSelect(fd_set_size_t nfds,
-           fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
-           struct timeval *timeout)
+	   fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
+	   struct timeval *timeout)
 {
-  volatile int iRet = 0;  /* This variable MUST NOT be in a register */
+  volatile int iRet = -1;  /* This variable MUST NOT be in a register */
+
+  /*
+   * Yes, we trash errno here, but you're only supposed to check
+   * errno immediately after a function fails anyway. If we fail,
+   * then it's because we received a signal. If we succeed, we
+   * shouldn't be checking errno. And if somebody calls us expecting
+   * us to preserve errno then that's their bug.
+   *
+   * NOTE: We mustn't call any function that might trash errno
+   *	   ourselves, except select() itself of course. I believe
+   *	   that sigsetjmp() does NOT trash errno.
+   */
+  errno = EINTR;
 
   /*
    * Now initialise the non-local jump. Between here and the end of
@@ -139,10 +152,10 @@ fvwmSelect(fd_set_size_t nfds,
        * that IS the whole point, after all :-)
        */
       iRet = select(nfds,
-                    SELECT_FD_SET_CAST readfds,
-                    SELECT_FD_SET_CAST writefds,
-                    SELECT_FD_SET_CAST exceptfds,
-                    timeout);
+		    SELECT_FD_SET_CAST readfds,
+		    SELECT_FD_SET_CAST writefds,
+		    SELECT_FD_SET_CAST exceptfds,
+		    timeout);
     }
 
     /*
@@ -157,5 +170,5 @@ fvwmSelect(fd_set_size_t nfds,
   return iRet;
 }
 
-#endif  /* HAVE_SELECT */
+#endif	/* HAVE_SELECT */
 
