@@ -21,6 +21,7 @@
 
 #include <X11/Xlib.h>
 #include "Parse.h"
+#include "Strings.h"
 #include "fvwmrect.h"
 #include "gravity.h"
 
@@ -419,14 +420,14 @@ direction_type ParseDirectionArgument(
 	int rc;
 	char *next;
 	char *optlist[] = {
-		"N",  "North",     "Top",         "Up",
-		"E",  "East",      "Right",       "Right",
-		"S",  "South",     "Bottom",      "Down",
-		"W",  "West",      "Left",        "Left",
-		"NE", "NorthEast", "TopRight",    "UpRight",
-		"SE", "SouthEast", "BottomRight", "DownRight",
-		"SW", "SouthWest", "BottomLeft",  "DownLeft",
-		"NW", "NorthWest", "TopLeft",     "UpLeft",
+		"N",  "North",	   "Top",	  "t", "Up",	     "u",
+		"E",  "East",	   "Right",	  "r", "Right",	     "r",
+		"S",  "South",	   "Bottom",	  "b", "Down",	     "d",
+		"W",  "West",	   "Left",	  "l", "Left",	     "l",
+		"NE", "NorthEast", "TopRight",	  "tr", "UpRight",   "ur",
+		"SE", "SouthEast", "BottomRight", "br", "DownRight", "dr",
+		"SW", "SouthWest", "BottomLeft",  "bl", "DownLeft",  "dl",
+		"NW", "NorthWest", "TopLeft",	  "tl", "UpLeft",    "ul",
 		NULL
 	};
 
@@ -439,7 +440,7 @@ direction_type ParseDirectionArgument(
 	}
 	else
 	{
-		rc = index / 4;
+		rc = index / 6;
 	}
 	if (ret_action)
 	{
@@ -448,3 +449,47 @@ direction_type ParseDirectionArgument(
 
 	return (direction_type)rc;
 }
+
+multi_direction_type ParseMultiDirectionArgument(
+	char *action, char **ret_action)
+{
+	int rc = MULTI_DIR_NONE;
+	char *token, *str;
+	direction_type dir = ParseDirectionArgument(action, ret_action, -1);
+
+	if (dir != -1)
+	{
+		rc = (1 << dir);
+	}
+	else
+	{
+		token = PeekToken(action, &str);
+		if (StrEquals(token, "all"))
+		{
+			rc = MULTI_DIR_ALL;
+			*ret_action = str;
+		}
+		else
+		{
+			rc = MULTI_DIR_NONE;
+		}
+	}
+	return (multi_direction_type)rc;
+}
+
+void GetNextMultiDirection(int dir_set, multi_direction_type *dir)
+{
+	if (*dir == MULTI_DIR_NONE)
+	{
+		*dir = FIRST_MULTI_DIR;
+		if (dir_set & *dir)
+			return;
+	}
+	while(*dir != LAST_MULTI_DIR)
+	{
+		*dir = (*dir << 1);
+		if (dir_set & *dir)
+			return;
+	}
+	*dir = MULTI_DIR_NONE;
+}
