@@ -5,22 +5,24 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 #include <stdio.h>
-
+#include <string.h>
 #include "safemalloc.h"
 
 static void alloc_failed(char *c, int length)
 {
-  fprintf(stderr, "%salloc of %d bytes failed. Exiting\n", c, length);
+  fprintf(stderr, "%s of %d bytes failed. Exiting\n", c, length);
   exit(1);
 }
 
@@ -43,7 +45,7 @@ char *safemalloc(int length)
   if(ptr == (char *)0)
   {
     /* doesn't return */
-    alloc_failed("m", length);
+    alloc_failed("malloc", length);
   }
   return ptr;
 }
@@ -64,7 +66,7 @@ char *safecalloc(int num, int length)
   if(ptr == (char *)0)
   {
     /* doesn't return */
-    alloc_failed("c", length);
+    alloc_failed("calloc", length);
   }
   return ptr;
 }
@@ -88,7 +90,25 @@ char *saferealloc(char *src, int length)
   if(ptr == (char *)0)
   {
     /* doesn't return */
-    alloc_failed("re", length);
+    alloc_failed("realloc", length);
   }
   return ptr;
 }
+
+/***********************************************************************
+ *
+ *  Procedure:
+ *	safestrdup - duplicates a string or exits if there's a
+ *		     problem
+ *
+ ***********************************************************************/
+char *safestrdup(const char *src)
+{
+  char *cpy = strdup(src);
+  if (cpy == (char *)0)
+  {
+    /* doesn't return */
+    alloc_failed("strdup", strlen(src) + (size_t)1);
+  }
+  return cpy;
+}
