@@ -19,12 +19,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -153,7 +153,7 @@ int buttonFrameSigned(button_info *b)
 {
   if(b->flags&b_Frame)
     return b->framew;
-  if(b->flags&b_Container)              /* Containers usually gets 0 relief  */
+  if(b->flags&b_Container)		/* Containers usually gets 0 relief  */
     return 0;
   while((b=b->parent))
     if(b->c->flags&b_Frame)
@@ -172,7 +172,7 @@ int buttonXPad(button_info *b)
 {
   if(b->flags&b_Padding)
     return b->xpad;
-  if(b->flags&(b_Container|b_Swallow))  /* Normally no padding for these     */
+  if(b->flags&(b_Container|b_Swallow))	/* Normally no padding for these     */
     return 0;
   while((b=b->parent))
     if(b->c->flags&b_Padding)
@@ -191,7 +191,7 @@ int buttonYPad(button_info *b)
 {
   if(b->flags&b_Padding)
     return b->ypad;
-  if(b->flags&(b_Container|b_Swallow))  /* Normally no padding for these     */
+  if(b->flags&(b_Container|b_Swallow))	/* Normally no padding for these     */
     return 0;
   while((b=b->parent))
     if(b->c->flags&b_Padding)
@@ -206,38 +206,19 @@ int buttonYPad(button_info *b)
 *** buttonFont()
 *** Give the font pointer for this button
 **/
-XFontStruct *buttonFont(button_info *b)
+FlocaleFont *buttonFont(button_info *b)
 {
   if(b->flags&b_Font)
-    return b->font;
+    return b->Ffont;
   while((b=b->parent))
     if(b->c->flags&b_Font)
-      return b->c->font;
+      return b->c->Ffont;
 #ifdef DEBUG
   fprintf(stderr,"%s: BUG: No font definition?\n",MyName);
 #endif
   return None;
 }
 
-#ifdef I18N_MB
-/**
-*** buttonFontSet()
-*** Give the font pointer for this button
-**/
-XFontSet buttonFontSet(button_info *b)
-{
-  if(b->flags&b_Font)
-    return b->fontset;
-  while((b=b->parent))
-    if(b->c->flags&b_Font)
-      return b->c->fontset;
-#ifdef DEBUG
-  fprintf(stderr,"%s: BUG: No fontset definition?\n",MyName);
-#endif
-  return None;
-}
-#endif
-
 /**
 *** buttonFore()
 *** Give the foreground pixel of this button
@@ -467,9 +448,9 @@ void MakeContainer(button_info *b)
   if(b->parent != NULL)
   {
     if (b->parent->c->flags & b_IconBack || b->parent->c->flags & b_IconParent)
-      b->c->flags = b_IconParent;
+      b->c->flags |= b_IconParent;
     if (b->parent->c->flags & b_Colorset)
-      b->c->flags = b_ColorsetParent;
+      b->c->flags |= b_ColorsetParent;
   }
   else /* This applies to the UberButton */
   {
@@ -792,7 +773,7 @@ button_info *NextButton(button_info **ub,button_info **b,int *i,int all)
 /**
 *** button_belongs_to()
 *** Function that finds out which button a given position belongs to.
-*** Returns -1 is not part of any, button if a proper button.
+*** Returns -1 if not part of any, button if a proper button.
 **/
 int button_belongs_to(button_info *ub,int button)
 {
@@ -818,6 +799,28 @@ int button_belongs_to(button_info *ub,int button)
   return -1;
 }
 
+/**
+*** get_xy_button()
+*** Function that returns the button that covers the given row/column in the
+*** button matrix. Returns NULL if none.
+**/
+button_info *get_xy_button(button_info *ub, int row, int column)
+{
+	int i;
+
+	if (!(ub->flags & b_Container))
+	{
+		return NULL;
+	}
+	i = button_belongs_to(ub, column + row * ub->c->num_columns);
+	if (i == -1)
+	{
+		return NULL;
+	}
+
+	return ub->c->buttons[i];
+}
+
 /**
 *** select_button()
 *** Given (x,y) and uberbutton, returns pointer to referred button, or NULL
@@ -849,3 +852,19 @@ button_info *select_button(button_info *ub,int x,int y)
       b, x + ub->c->xpos - buttonXPos(b, i),
       y + ub->c->ypos - buttonYPos(b, i));
 }
+
+void get_button_root_geometry(rectangle *r, button_info *b)
+{
+	int x;
+	int y;
+	int f;
+	Window win;
+
+	r->width = buttonWidth(b);
+	r->height = buttonHeight(b);
+	buttonInfo(b, &r->x, &r->y, &x, &y, &f);
+	XTranslateCoordinates(
+		Dpy, MyWindow, Root, r->x, r->y, &r->x, &r->y, &win);
+
+	return;
+}
