@@ -19,12 +19,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /* ------------------------------- includes -------------------------------- */
@@ -396,7 +396,7 @@ void RedrawButton(button_info *b,int clean)
 
     /* draw the panel indicator, but not if there is a title */
     if (b->slide_direction != SLIDE_GEOMETRY && b->indicator_size != 0 &&
-        (b->indicator_size & 1) == 0)
+	(b->indicator_size & 1) == 0)
     {
       /* make sure we have an odd number */
       b->indicator_size--;
@@ -532,28 +532,35 @@ void DrawTitle(button_info *b,Window win,GC gc)
 
   if(*s && l>0 && BH>=Ffont->height) /* Clip it somehow? */
   {
-    FlocaleWinString *FwinString;
+    FlocaleWinString FwinString;
+    int cset;
 
-    FlocaleAllocateWinString(&FwinString);
-    FwinString->str = s;
-    FwinString->win = win;
-    FwinString->gc = gc;
-    FwinString->x = xpos;
+    memset(&FwinString, 0, sizeof(FwinString));
+    FwinString.str = s;
+    FwinString.win = win;
+    FwinString.gc = gc;
+    cset = buttonColorset(b);
+    if (cset >= 0)
+    {
+	    FwinString.colorset = &Colorset[cset];
+	    FwinString.flags.has_colorset = 1;
+    }
+    FwinString.x = xpos;
     /* If there is more than the title, put it at the bottom */
     /* Unless stack flag is set, put it to the right of icon */
     if((b->flags&b_Icon ||
 	((buttonSwallowCount(b)==3) && (b->flags&b_Swallow))) &&
        !(justify&b_Horizontal))
     {
-      FwinString->y = iy+ih-Ffont->descent;
+      FwinString.y = iy+ih-Ffont->descent;
       /* Shrink the space available for icon/window */
       ih-=Ffont->height;
     }
     /* Or else center vertically */
     else
     {
-      FwinString->y = iy + (ih+ Ffont->ascent - Ffont->descent)/2;
+      FwinString.y = iy + (ih+ Ffont->ascent - Ffont->descent)/2;
     }
-    FlocaleDrawString(Dpy, Ffont, FwinString, 0);
+    FlocaleDrawString(Dpy, Ffont, &FwinString, 0);
   }
 }
