@@ -19,12 +19,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include <unistd.h>
@@ -57,7 +57,7 @@ void DumpButtons(button_info *b)
 	    b->BWidth,b->BHeight,b->flags);
 
   if(b->flags&b_Font)
-    fprintf(stderr,"Font(%s,0x%lx) ",b->font_string,(unsigned long)b->font);
+    fprintf(stderr,"Font(%s,0x%lx) ",b->font_string,(unsigned long)b->Ffont);
   if(b->flags&b_Padding)
     fprintf(stderr,"Padding(%i,%i) ",b->xpad,b->ypad);
   if(b->flags&b_Frame)
@@ -66,8 +66,10 @@ void DumpButtons(button_info *b)
     fprintf(stderr,"Title(%s) ",b->title);
   if(b->flags&b_Icon)
     fprintf(stderr,"Icon(%s,%i) ",b->icon_file,(int)b->IconWin);
+  if(b->flags&b_Icon)
+    fprintf(stderr,"Panelw(%i) ",(int)b->PanelWin);
   if(b->flags&b_Action)
-    fprintf(stderr,"\n  Action(%s,%s,%s,%s) ",
+    fprintf(stderr,"\n	Action(%s,%s,%s,%s) ",
 	    b->action[0]?b->action[0]:"",
 	    b->action[1]?b->action[1]:"",
 	    b->action[2]?b->action[2]:"",
@@ -95,8 +97,8 @@ void DumpButtons(button_info *b)
 	    b->c->allocated_buttons,
 	    b->c->width,b->c->height,b->c->xpos,b->c->ypos);
     /*
-      fprintf(stderr,"  font(%s,%i) framew(%i) pad(%i,%i) { ",
-      b->c->font_string,(int)b->c->font,b->c->framew,b->c->xpad,
+      fprintf(stderr,"	font(%s,%i) framew(%i) pad(%i,%i) { ",
+      b->c->font_string,(int)b->c->Ffont,b->c->framew,b->c->xpad,
       b->c->ypad);
     */
     while(i<b->c->num_buttons)
