@@ -19,12 +19,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -511,7 +511,7 @@ static void ParsePanel(char **ss, unsigned int *flags, unsigned int *mask,
 	case 4: /* left */
 	  *position = SLIDE_POSITION_LEFT_TOP;
 	  break;
-	case 5: /* top  */
+	case 5: /* top	*/
 	  *position = SLIDE_POSITION_LEFT_TOP;
 	  break;
 	case 6: /* right */
@@ -599,8 +599,8 @@ static void ParseContainer(char **ss,button_info *b)
       break;
     case 2: /* Font */
       if (b->c->font_string)
-        free(b->c->font_string);
-      b->font_string = my_get_font(&s);
+	free(b->c->font_string);
+      b->c->font_string = my_get_font(&s);
       if(b->c->font_string)
       {
 	b->c->flags|=b_Font;
@@ -766,7 +766,7 @@ static void ParseContainer(char **ss,button_info *b)
 *** ParseButton()
 ***
 *** parse a buttonconfig string.
-*** *FvwmButtons(option[ options]) title iconname command
+*** *FvwmButtons: (option[ options]) title iconname command
 **/
 /*#define DEBUG_PARSER*/
 static void ParseButton(button_info **uberb,char *s)
@@ -792,6 +792,7 @@ static void ParseButton(button_info **uberb,char *s)
       "swallow",
       "panel",
       "actionignoresclientwindow",
+      "actiononpress",
       "container",
       "end",
       "nosize",
@@ -875,7 +876,7 @@ static void ParseButton(button_info **uberb,char *s)
       case 2: /* Font */
 	if(b->flags&b_Font && b->font_string)
 	  free(b->font_string);
-        b->font_string = my_get_font(&s);
+	b->font_string = my_get_font(&s);
 	if(b->font_string)
 	{
 	  b->flags|=b_Font;
@@ -1082,9 +1083,13 @@ static void ParseButton(button_info **uberb,char *s)
 	b->flags |= b_ActionIgnoresClientWindow;
 	break;
 
+      case 10: /* ActionIgnoresClientWindow */
+	b->flags |= b_ActionOnPress;
+	break;
+
 	/* -------------------------- container ---------------------- */
 
-      case 10: /* Container */
+      case 11: /* Container */
 	b->flags&=b_Frame|b_Back|b_Fore|b_Padding|b_Action;
 	MakeContainer(b);
 	*uberb=b;
@@ -1093,7 +1098,7 @@ static void ParseButton(button_info **uberb,char *s)
 	  ParseContainer(&s,b);
 	break;
 
-      case 11: /* End */
+      case 12: /* End */
 	*uberb=ub->parent;
 	ub->c->buttons[--(ub->c->num_buttons)]=NULL;
 	free(b);
@@ -1104,12 +1109,12 @@ static void ParseButton(button_info **uberb,char *s)
 	}
 	return;
 
-      case 12: /* NoSize */
+      case 13: /* NoSize */
 	b->flags|=b_Size;
 	b->minx=b->miny=0;
 	break;
 
-      case 13: /* Size */
+      case 14: /* Size */
 	i=strtol(s,&t,10);
 	j=strtol(t,&o,10);
 	if(t>s && o>t)
@@ -1123,21 +1128,21 @@ static void ParseButton(button_info **uberb,char *s)
 	  fprintf(stderr,"%s: Illegal size arguments\n",MyName);
 	break;
 
-      case 14: /* Left */
+      case 15: /* Left */
 	b->flags |= b_Left;
 	b->flags &= ~b_Right;
 	break;
 
-      case 15: /* Right */
+      case 16: /* Right */
 	b->flags |= b_Right;
 	b->flags &= ~b_Left;
 	break;
 
-      case 16: /* Center */
+      case 17: /* Center */
 	b->flags &= ~(b_Right|b_Left);
 	break;
 
-      case 17: /* Colorset */
+      case 18: /* Colorset */
 	i = strtol(s, &t, 10);
 	if(t > s)
 	{
@@ -1154,7 +1159,7 @@ static void ParseButton(button_info **uberb,char *s)
 
 	/* --------------------------- action ------------------------ */
 
-      case 18: /* Action */
+      case 19: /* Action */
 	s = trimleft(s);
 	i=0;
 	if(*s=='(')
@@ -1170,27 +1175,27 @@ static void ParseButton(button_info **uberb,char *s)
 	  while(*s && *s!=')')
 	    s++;
 	  if(*s==')')
-            s++;
+	    s++;
 	}
-        {
-          char *r;
-          char *u = s;
+	{
+	  char *r;
+	  char *u = s;
 
-          s = GetQuotedString(s, &t, ",)", NULL, "(", ")");
-          r = s;
-          if (t && r > u + 1)
-          {
-            /* remove unquoted trailing spaces */
-            r -= 2;
-            while (r >= u && isspace(*r))
-              r--;
-            r++;
-            if (isspace(*r))
-            {
-              t[strlen(t) - (s - r - 1)] = 0;
-            }
-          }
-        }
+	  s = GetQuotedString(s, &t, ",)", NULL, "(", ")");
+	  r = s;
+	  if (t && r > u + 1)
+	  {
+	    /* remove unquoted trailing spaces */
+	    r -= 2;
+	    while (r >= u && isspace(*r))
+	      r--;
+	    r++;
+	    if (isspace(*r))
+	    {
+	      t[strlen(t) - (s - r - 1)] = 0;
+	    }
+	  }
+	}
 	if(t)
 	{
 	  AddButtonAction(b,i,t);
@@ -1375,7 +1380,7 @@ static void ParseConfigLine(button_info **ubb,char *s)
   case 2:/* Font */
     if (ub->c->font_string)
       free(ub->c->font_string);
-    CopyString(&ub->c->font_string, s);
+    CopyStringWithQuotes(&ub->c->font_string, s);
     break;
   case 3:/* Padding */
     i=sscanf(s,"%d %d",&j,&k);
@@ -1524,7 +1529,7 @@ void parse_window_geometry(char *geom)
 /**
 *** ParseOptions()
 **/
-extern int save_color_limit;            /* global for xpm color limiting */
+extern int save_color_limit;		/* global for xpm color limiting */
 void ParseConfiguration(button_info *ub)
 {
   char *s;
@@ -1541,7 +1546,7 @@ void ParseConfiguration(button_info *ub)
   items[0]=mymalloc(strlen(MyName)+2);
   sprintf(items[0],"*%s",MyName);
 
-  InitGetConfigLine(fd,items[0]);       /* send config lines with MyName */
+  InitGetConfigLine(fd,items[0]);	/* send config lines with MyName */
   GetConfigLine(fd,&s);
   while(s && s[0])
   {
@@ -1559,7 +1564,7 @@ void ParseConfiguration(button_info *ub)
 	free(imagePath);
       CopyString(&imagePath,rest);
       break;
-    case 2:                         /* colorlimit */
+    case 2:			    /* colorlimit */
       sscanf(rest, "%d", &save_color_limit);
       break;
     case 3:
