@@ -15,7 +15,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -125,7 +125,7 @@ int main ( int argc, char *argv[])
 #else
 #ifdef USE_BSD_SIGNALS
   fvwmSetSignalMask( sigmask(SIGINT) | sigmask(SIGHUP) |
-                     sigmask(SIGQUIT) | sigmask(SIGTERM) );
+		     sigmask(SIGQUIT) | sigmask(SIGTERM) );
 #endif
   signal(SIGINT, sig_quit);
   signal(SIGHUP, sig_quit);
@@ -221,7 +221,7 @@ int main ( int argc, char *argv[])
     if (!dpy_name[0] || ':' == dpy_name[0])
     {
       gethostname(hostname, MAXHOSTNAME);
-      strcat(f_stem, hostname);  /* Put hostname before dpy if not there */
+      strcat(f_stem, hostname);	 /* Put hostname before dpy if not there */
     }
     strcat(f_stem, dpy_name);
   }
@@ -332,32 +332,32 @@ int main ( int argc, char *argv[])
       FD_SET(Fdr, &fdset);
       if( Bg == 0 )
       {
-        FD_SET(STDIN_FILENO, &fdset);
+	FD_SET(STDIN_FILENO, &fdset);
       }
       ncnt = fvwmSelect(FD_SETSIZE, &fdset, 0, 0, NULL);
 
       /* message from fvwm */
       if (FD_ISSET(Fdr, &fdset))
       {
-        process_message();
+	process_message();
       }
 
       if( Bg == 0 )
       {
-        /* command input */
-        if( FD_ISSET(STDIN_FILENO, &fdset) )
-        {
-          if( fgets( cmd, MAX_MODULE_INPUT_TEXT_LEN - 1, stdin ) == 0 )
-          {
-            if( Bg == 0 )
-            {
-              /* other than SIGTTIN */
-              break;
-            }
-            continue;
-          }
-          sendit( cmd );
-        }
+	/* command input */
+	if( FD_ISSET(STDIN_FILENO, &fdset) )
+	{
+	  if( fgets( cmd, MAX_MODULE_INPUT_TEXT_LEN - 1, stdin ) == 0 )
+	  {
+	    if( Bg == 0 )
+	    {
+	      /* other than SIGTTIN */
+	      break;
+	    }
+	    continue;
+	  }
+	  sendit( cmd );
+	}
       }
     }
   }
@@ -368,7 +368,7 @@ int main ( int argc, char *argv[])
       strncpy( cmd, argv[i], MAX_MODULE_INPUT_TEXT_LEN - 1 );
       sendit( cmd );
       if (Opt_info >= 0)
-        receive();
+	receive();
     }
   }
   close_fifos();
@@ -492,38 +492,38 @@ void usage(void)
   fprintf (stderr, "Usage: %s [OPTION] [COMMAND]...\n", MYNAME);
   fprintf (stderr, "Send commands to fvwm via %sS\n\n", MYNAME);
   fprintf (stderr,
-	   "  -c                  read and send commands from stdin\n"
-	   "                      The COMMAND if any is ignored.\n");
+	   "  -c		  read and send commands from stdin\n"
+	   "			  The COMMAND if any is ignored.\n");
   fprintf (stderr,
-	   "  -S <file name>      "
+	   "  -S <file name>	  "
 	   "invoke another %s server with fifo <file name>\n",
 	   MYNAME);
   fprintf (stderr,
-	   "  -f <file name>      use fifo <file name> to connect to %sS\n",
+	   "  -f <file name>	  use fifo <file name> to connect to %sS\n",
 	   MYNAME);
   fprintf (stderr,
-	   "  -i <info level>     0 - error only\n" );
+	   "  -i <info level>	  0 - error only\n" );
   fprintf (stderr,
-	   "                      1 - above and config info (default)\n" );
+	   "			  1 - above and config info (default)\n" );
   fprintf (stderr,
-	   "                      2 - above and static info\n" );
+	   "			  2 - above and static info\n" );
   fprintf (stderr,
-	   "                      3 - above and dynamic info\n" );
+	   "			  3 - above and dynamic info\n" );
   fprintf (stderr,
-	   "                     -1 - none (default, much faster)\n" );
+	   "			 -1 - none (default, much faster)\n" );
   fprintf (stderr,
-	   "  -F <flag info>      0 - no flag info\n");
+	   "  -F <flag info>	  0 - no flag info\n");
   fprintf (stderr,
-	   "                      2 - full flag info (default)\n");
+	   "			  2 - full flag info (default)\n");
   fprintf (stderr,
-	   "  -m                  monitor fvwm message transaction\n");
+	   "  -m		  monitor fvwm message transaction\n");
   fprintf (stderr,
-	   "  -r                  "
+	   "  -r		  "
 	   "wait for a reply (overrides waiting time)\n");
   fprintf (stderr,
-	   "  -v                  print version number\n");
+	   "  -v		  print version number\n");
   fprintf (stderr,
-	   "  -w <micro sec>      waiting time for the reponse from fvwm\n");
+	   "  -w <micro sec>	  waiting time for the reponse from fvwm\n");
   fprintf (stderr, "\nDefault fifo names are ~/.%sC and ~/.%sM\n",
 	   MYNAME, MYNAME);
   fprintf (stderr, "Default waiting time is 500,000 us\n");
@@ -617,7 +617,7 @@ void process_message( void )
       if( Opt_info >=2 )
       {
 	switch(type)
-        {
+	{
 
 	case M_CONFIGURE_WINDOW:
 	  list_configure( body);
@@ -628,9 +628,9 @@ void process_message( void )
 
 	default:
 	  if( Opt_info >= 3 )
-          {
+	  {
 	    switch( type )
-            {
+	    {
 	    case M_NEW_PAGE:
 	      list_new_page(body);
 	      break;
@@ -770,7 +770,7 @@ void list_configure(unsigned long *body)
     printf( "do_reuse_destroyed: %d\n",
 	    DO_REUSE_DESTROYED( cfgpacket ) );
     printf( "has_border: %d\n",
-	    HAS_BORDER( cfgpacket ) );
+	    !HAS_NO_BORDER( cfgpacket ) );
     printf( "has_title: %d\n",
 	    HAS_TITLE( cfgpacket ) );
     printf( "is_deiconify_pending: %d\n",
@@ -923,7 +923,7 @@ void list( unsigned long *body, char *text )
  ************************************************************************/
 void list_new_page(unsigned long *body)
 {
-  printf( "           %-20s x %ld, y %ld, desk %ld, max x %ld, max y %ld\n",
+  printf( "	      %-20s x %ld, y %ld, desk %ld, max x %ld, max y %ld\n",
 	  "new page",
 	  body[0], body[1], body[2], body[3], body[4]);
 }
@@ -935,7 +935,7 @@ void list_new_page(unsigned long *body)
  ************************************************************************/
 void list_new_desk(unsigned long *body)
 {
-  printf( "           %-20s %ld\n",  "new desk", body[0] );
+  printf( "	      %-20s %ld\n",  "new desk", body[0] );
 }
 
 /*************************************************************************
