@@ -5,17 +5,17 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "FvwmConsole.h"
 
-int  s;    /* socket handle */
+int  s;	   /* socket handle */
 FILE *sp;
 char *name;  /* name of this program at executing time */
 char *getline();
@@ -24,7 +24,7 @@ char *getline();
 /******************************************/
 /*  close socket and exit */
 /******************************************/
-void sclose () {
+void sclose (int foo) {
   fclose(sp);
   exit(0);
 }
@@ -40,7 +40,7 @@ void ErrMsg( char *msg ) {
 
 
 /*******************************************************/
-/* setup socket.                                       */
+/* setup socket.				       */
 /* send command to and receive message from the server */
 /*******************************************************/
 int main ( int argc, char *argv[]) {
@@ -53,7 +53,6 @@ int main ( int argc, char *argv[]) {
   char *home;
   char *s_name;
 
-  signal (SIGPIPE, sclose);
   signal (SIGINT, sclose);
   signal (SIGQUIT, sclose);
 
@@ -106,7 +105,7 @@ int main ( int argc, char *argv[]) {
 
 	}
 	kill( getppid(), SIGKILL );
-	sclose();
+	sclose(0);
   }
   while( fgets( data, MAX_MESSAGE_SIZE, sp )  ) {
 	/* get the response */
