@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -55,9 +55,12 @@ widget_get_value (GtkWidget *w)
 
   if (GTK_IS_OPTION_MENU (w))
     {
+      GtkWidget *menu = GTK_OPTION_MENU (w)->menu;
       GtkWidget *item;
 
-      item = gtk_menu_get_active (GTK_MENU (GTK_OPTION_MENU (w)->menu));
+      if (menu == NULL)
+	return NULL;
+      item = gtk_menu_get_active (GTK_MENU (menu));
       if (item)
 	{
 	  return gtk_object_get_data (GTK_OBJECT (item), "value");
@@ -70,7 +73,7 @@ widget_get_value (GtkWidget *w)
   else if (GTK_IS_SCALE (w))
     {
       g_snprintf (buf, sizeof (buf), "%.*f",
-	  	  GTK_RANGE (w)->digits,
+		  GTK_RANGE (w)->digits,
 		  gtk_range_get_adjustment (GTK_RANGE (w))->value);
       return buf;
     }
@@ -130,7 +133,7 @@ update_value (GtkWidget *w)
   if (val)
     {
       gtk_object_set_data_full (GTK_OBJECT (gtk_widget_get_toplevel (w)),
-				gtk_widget_get_name (w), strdup (val), free);
+	gtk_widget_get_name (w), safestrdup (val), free);
     }
 }
 
@@ -272,21 +275,21 @@ open_dialog (int argc, char **argv)
 	(GTK_OBJECT (item), "delete_event",
 	 GTK_SIGNAL_FUNC (gtk_widget_hide), current);
       if (argc >= 3 && strcasecmp ("center", argv[2]) == 0)
-        {
-          gtk_window_position (GTK_WINDOW (item), GTK_WIN_POS_CENTER);
-        }
+	{
+	  gtk_window_position (GTK_WINDOW (item), GTK_WIN_POS_CENTER);
+	}
       else
-        {
-          gtk_window_position (GTK_WINDOW (item), GTK_WIN_POS_MOUSE);
-        }
+	{
+	  gtk_window_position (GTK_WINDOW (item), GTK_WIN_POS_MOUSE);
+	}
       if (argc >= 4)
-        {
-          int border_width;
+	{
+	  int border_width;
 
-          border_width = atoi (argv[3]);
+	  border_width = atoi (argv[3]);
 
-          gtk_container_border_width (GTK_CONTAINER (item), border_width);
-        }
+	  gtk_container_border_width (GTK_CONTAINER (item), border_width);
+	}
     }
   if (GTK_IS_MENU (item))
     {
@@ -335,7 +338,7 @@ dialog_notebook (int argc, char **argv)
       free (notebook_label);
       notebook_label = NULL;
     }
-  notebook_label = strdup (argv[0]);
+  notebook_label = safestrdup (argv[0]);
 }
 
 
@@ -393,7 +396,7 @@ dialog_button (int argc, char **argv)
 	{
 	  break;
 	}
-      vals[i] = strdup(argv[i + 1]);
+      vals[i] = safestrdup(argv[i + 1]);
     }
   vals[i] = NULL;
   gtk_object_set_data (GTK_OBJECT (item), "return_values", vals);
@@ -414,8 +417,8 @@ dialog_checkbutton (int argc, char **argv)
 
   item = gtk_check_button_new_with_label (argv[1]);
   gtk_widget_set_name (item, argv[0]);
-  gtk_object_set_data (GTK_OBJECT (item), "on-value", strdup (argv[2]));
-  gtk_object_set_data (GTK_OBJECT (item), "off-value", strdup (argv[3]));
+  gtk_object_set_data (GTK_OBJECT (item), "on-value", safestrdup (argv[2]));
+  gtk_object_set_data (GTK_OBJECT (item), "off-value", safestrdup (argv[3]));
   if (argc >= 5 && strcasecmp (argv[4], "on") == 0)
     {
       gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (item), TRUE);
@@ -463,7 +466,7 @@ dialog_radiobutton (int argc, char **argv)
   item = gtk_radio_button_new_with_label (radio_group, argv[0]);
   radio_group = gtk_radio_button_group (GTK_RADIO_BUTTON (item));
   gtk_widget_set_name (item, group_name);
-  gtk_object_set_data (GTK_OBJECT (item), "on-value", strdup (argv[1]));
+  gtk_object_set_data (GTK_OBJECT (item), "on-value", safestrdup (argv[1]));
   if (argc >= 3 && strcasecmp (argv[2], "on") == 0)
     {
       gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (item), TRUE);
@@ -490,7 +493,7 @@ dialog_start_radiogroup (int argc, char **argv)
     {
       free (group_name);
     }
-  group_name = strdup (argv[0]);
+  group_name = safestrdup (argv[0]);
   radio_group = NULL;
 }
 
@@ -526,9 +529,9 @@ dialog_color (int argc, char **argv)
 		       &color))
 	{
 	  double rgb[3];
-	  rgb[0] = (double) color.red   / 65536.0;
+	  rgb[0] = (double) color.red	/ 65536.0;
 	  rgb[1] = (double) color.green / 65536.0;
-	  rgb[2] = (double) color.blue  / 65536.0;
+	  rgb[2] = (double) color.blue	/ 65536.0;
 	  gtk_color_selection_set_color (GTK_COLOR_SELECTION (item), rgb);
 	}
     }
@@ -734,7 +737,7 @@ dialog_option_menu_item (int argc, char **argv)
 
   item = menu_item_new_with_pixmap_and_label ("", argv[0], NULL);
 
-  gtk_object_set_data (GTK_OBJECT (item), "value", strdup (argv[1]));
+  gtk_object_set_data (GTK_OBJECT (item), "value", safestrdup (argv[1]));
   gtk_widget_show (item);
 
   if (argc >= 3 && strcasecmp (argv[2], "on") == 0)
