@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include <stdlib.h>
@@ -53,7 +53,7 @@ split_string (char *val, str *pre)
 	  curr->next = (str *) safemalloc (sizeof (str));
 	  curr = curr->next;
 	  *s = '\0';
-	  curr->s = strdup (v);
+	  curr->s = safestrdup (v);
 	  curr->is_var = 0;
 	  *s = '$';
 
@@ -62,7 +62,7 @@ split_string (char *val, str *pre)
 	  curr = curr->next;
 	  curr->next = NULL;
 	  *t = '\0';
-	  curr->s = strdup (s + 2);
+	  curr->s = safestrdup (s + 2);
 	  curr->is_var = 1;
 	  *t = ')';
 
@@ -74,7 +74,7 @@ split_string (char *val, str *pre)
 	  curr->next = (str *) safemalloc (sizeof (str));
 	  curr = curr->next;
 	  curr->next = NULL;
-	  curr->s = strdup (v);
+	  curr->s = safestrdup (v);
 	  curr->is_var = 0;
 	  v = NULL;
 	}
@@ -115,7 +115,7 @@ recursive_replace (GtkWidget *d, char *val)
 
   head = (str *) safemalloc (sizeof (str));
   head->is_var = 0;
-  head->s = strdup("");
+  head->s = safestrdup("");
   head->next = NULL;
 
   split_string (val, head);
@@ -127,11 +127,11 @@ recursive_replace (GtkWidget *d, char *val)
 	  nval = (char *) gtk_object_get_data (GTK_OBJECT (d), next->s);
 	  if (nval)
 	    {
-              /* this changes r->next, thus freeing next is safe */
+	      /* this changes r->next, thus freeing next is safe */
 	      tail = split_string (nval, r);
 	      tail->next = next->next;
 	      free (next->s);
-              free (next);
+	      free (next);
 	    }
 	  else
 	    {
