@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -73,8 +73,8 @@ typedef union {
   ConfigWinPacket      add_config_data;
   m_new_page_data      new_page_data;
   m_minimal_data       minimal_data;
-  m_icon_data          icon_data;
-  m_name_data          name_data;
+  m_icon_data	       icon_data;
+  m_name_data	       name_data;
   m_mini_icon_data     mini_icon_data;
   m_property_data      property_data;
 } FvwmPacketBody;
@@ -221,23 +221,28 @@ static void set_win_configuration (WinData *win, FvwmPacketBody *body)
 
 static void handle_config_info (unsigned long *body)
 {
-  char *tline, *token;
+  char *tline, *token, *rest;
   int color;
+  extern void process_dynamic_config_line(char *line);
 
   tline = (char*)&(body[3]);
-  token = PeekToken(tline, &tline);
+  token = PeekToken(tline, &rest);
   if (StrEquals(token, "Colorset"))
   {
-    color = LoadColorset(tline);
+    color = LoadColorset(rest);
     change_colorset(color);
   }
   else if (StrEquals(token, XINERAMA_CONFIG_STRING))
   {
-    FScreenConfigureModule(tline);
+    FScreenConfigureModule(rest);
   }
   else if (StrEquals(token, "IgnoreModifiers"))
   {
-    sscanf(tline, "%d", &mods_unused);
+    sscanf(rest, "%d", &mods_unused);
+  }
+  else if (strncasecmp(tline, Module, ModuleLen) == 0)
+  {
+    process_dynamic_config_line(tline);
   }
 }
 
@@ -503,20 +508,24 @@ static void iconify (FvwmPacketBody *body, int dir)
   check_in_window (win);
 }
 
-/* only used by new_desk */
+/* only used by remanage_winlist */
 
-static void update_win_in_hashtab (void *arg)
+static void update_win_in_hashtab(void *arg)
 {
-  WinData *p = (WinData *)arg;
-  check_in_window (p);
+	WinData *p = (WinData *)arg;
+	check_in_window(p);
+}
+
+void remanage_winlist()
+{
+	walk_hashtab(update_win_in_hashtab);
+	draw_managers();
 }
 
 static void new_desk (FvwmPacketBody *body)
 {
-  globals.desknum = body->new_desk_data.desknum;
-  walk_hashtab (update_win_in_hashtab);
-
-  draw_managers ();
+	globals.desknum = body->new_desk_data.desknum;
+	remanage_winlist();
 }
 
 static void sendtomodule (FvwmPacketBody *body)
@@ -675,7 +684,7 @@ static void ProcessMessage (Ulong type, FvwmPacketBody *body)
     globals.y = body->new_page_data.y;
     globals.desknum = body->new_page_data.desknum;
     if (fvwm_focus_win && fvwm_focus_win->manager &&
-        fvwm_focus_win->manager->followFocus)
+	fvwm_focus_win->manager->followFocus)
     {
       /* need to set the focus on a page change */
       add_win_state (fvwm_focus_win, FOCUS_CONTEXT);
