@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include <limits.h>
@@ -20,9 +20,6 @@
 
 #define DEFAULT_MOUSE "0 N sendcommand \"Silent Iconify\""
 
-static char const rcsid[] =
-  "$Id: globals.c,v 1.17 2001/08/28 10:53:23 domivogt Exp $";
-
 GlobalData globals;
 ContextDefaults contextDefaults[] = {
   { "plain", BUTTON_UP, { "black", "black" }, { "white", "gray"} },
@@ -75,6 +72,9 @@ static void init_win_manager (int id)
   globals.managers[id].dontshow.mask = ALL_NAME;
   globals.managers[id].usewinlist = 1;
   globals.managers[id].sort = SortName;
+  globals.managers[id].weighted_sorts = NULL;
+  globals.managers[id].weighted_sorts_len = 0;
+  globals.managers[id].weighted_sorts_size = 0;
   globals.managers[id].bindings[MOUSE] = ParseMouseEntry (DEFAULT_MOUSE);
   globals.managers[id].we_are_drawing = 1;
   globals.managers[id].showonlyiconic = 0;
@@ -148,6 +148,5 @@ void init_globals (void)
   globals.focus_win = NULL;
   globals.select_win = NULL;
   globals.transient = 0;
-  globals.shapes_supported = 0;
   globals.got_window_list = 0;
 }
