@@ -5,21 +5,17 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef IN_X_H
 #define IN_X_H
 
-#ifdef SHAPE
-#include <X11/extensions/shape.h>
-#endif
-
 extern Display *theDisplay;
 extern Window theRoot;
 extern int theScreen;
@@ -33,5 +29,6 @@ extern void init_display (void);
 extern void xevent_loop (void);
 extern void create_manager_window (int man_id);
 extern void X_init_manager (int man_id);
+extern void change_colorset(int color);
 
 #endif
