@@ -5,22 +5,18 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #ifndef IN_XMANAGER_H
 #define IN_XMANAGER_H
 
-#ifdef MULTIBYTE
 #define FONT_STRING "-*-fixed-medium-r-normal--13-*"
-#else
-#define FONT_STRING "8x13"
-#endif
 #define DEFAULT_BUTTON_WIDTH 200
 #define DEFAULT_BUTTON_HEIGHT 17
 #define DEFAULT_NUM_COLS  1
