@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "libs/fvwmlib.h"
@@ -39,6 +39,9 @@ struct target_struct
   window_flags flags;
   long title_h;
   long border_w;
+  long ewmh_hint_layer;
+  unsigned long ewmh_hint_desktop;
+  long ewmh_window_type;
 };
 
 struct Item
@@ -56,10 +59,12 @@ struct Item
 void Loop(int *fd);
 void DeadPipe(int nonsense) __attribute__((noreturn));
 void process_message(unsigned long type, unsigned long *body);
-void RedrawWindow(void);
+void PixmapDrawWindow(int h, int w);
+void DrawItems(Drawable d);
 void change_window_name(char *str);
 Pixel GetColor(char *name);
 void nocolor(char *a, char *b);
+void DestroyList(void);
 void AddToList(char *, char *);
 void MakeList(void);
 
@@ -69,13 +74,6 @@ void list_window_name(unsigned long *body);
 void list_icon_name(unsigned long *body);
 void list_class(unsigned long *body);
 void list_res_name(unsigned long *body);
+void list_property_change(unsigned long *body);
 void list_end(void);
 
-/* I18N_MB stuff */
-#ifdef I18N_MB
-#ifdef __STDC__
-#define XTextWidth(x,y,z)       XmbTextEscapement(x ## set,y,z)
-#else
-#define XTextWidth(x,y,z)       XmbTextEscapement(x/**/set,y,z)
-#endif
-#endif
