@@ -14,12 +14,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -46,6 +46,7 @@
 #include "libs/fvwmlib.h"
 #include "libs/FScreen.h"
 #include "libs/FShape.h"
+#include "libs/FRenderInit.h"
 #include "libs/Colorset.h"
 #include "libs/Flocale.h"
 #ifdef DEBUG
@@ -210,10 +211,10 @@ int main(int argc, char **argv)
   /* We don't have sigaction(), so fall back to less robust methods.  */
 #ifdef USE_BSD_SIGNALS
   fvwmSetSignalMask( sigmask(SIGPIPE) |
-                     sigmask(SIGTERM) |
-                     sigmask(SIGQUIT) |
-                     sigmask(SIGINT) |
-                     sigmask(SIGHUP) );
+		     sigmask(SIGTERM) |
+		     sigmask(SIGQUIT) |
+		     sigmask(SIGINT) |
+		     sigmask(SIGHUP) );
 #endif
   signal(SIGPIPE, TerminateHandler);
   signal(SIGTERM, TerminateHandler);
@@ -314,6 +315,7 @@ int main(int argc, char **argv)
   FScreenInit(dpy);
   AllocColorset(0);
   FShapeInit(dpy);
+  FRenderInit(dpy);
 
   Scr.screen = DefaultScreen(dpy);
   Scr.Root = RootWindow(dpy, Scr.screen);
@@ -326,15 +328,15 @@ int main(int argc, char **argv)
 
   SetMessageMask(fd,
 		 M_VISIBLE_NAME |
-                 M_ADD_WINDOW|
-                 M_CONFIGURE_WINDOW|
-                 M_DESTROY_WINDOW|
-                 M_FOCUS_CHANGE|
-                 M_NEW_PAGE|
-                 M_NEW_DESK|
-                 M_RAISE_WINDOW|
-                 M_LOWER_WINDOW|
-                 M_ICONIFY|
+		 M_ADD_WINDOW|
+		 M_CONFIGURE_WINDOW|
+		 M_DESTROY_WINDOW|
+		 M_FOCUS_CHANGE|
+		 M_NEW_PAGE|
+		 M_NEW_DESK|
+		 M_RAISE_WINDOW|
+		 M_LOWER_WINDOW|
+		 M_ICONIFY|
 		 M_ICON_LOCATION|
 		 M_DEICONIFY|
 		 M_RES_NAME|
@@ -455,7 +457,7 @@ int main(int argc, char **argv)
   if (debug_term_signal)
   {
     fprintf(stderr,"[main]: Terminated due to signal %d\n",
-                   debug_term_signal);
+		   debug_term_signal);
   }
 #endif
   return 0;
@@ -880,7 +882,6 @@ void list_new_desk(unsigned long *body)
     XStoreName(dpy, Scr.Pager_w, Desks[0].label);
     XSetIconName(dpy, Scr.Pager_w, Desks[0].label);
 
-
     if (Desks[0].bgPixmap != NULL)
     {
       PDestroyFvwmPicture(dpy, Desks[0].bgPixmap);
@@ -969,6 +970,25 @@ void list_new_desk(unsigned long *body)
     XClearWindow(dpy, Desks[0].w);
     XClearWindow(dpy, Desks[0].title_w);
   } /* if (fAlwaysCurrentDesk && oldDesk != Scr.CurrentDesk) */
+  else if (!fAlwaysCurrentDesk)
+  {
+    int i;
+    char *name;
+    char line[100];
+
+    i = Scr.CurrentDesk - desk1;
+    if (i >= 0 && i < ndesks && Desks[i].label != NULL)
+    {
+      name = Desks[i].label;
+    }
+    else
+    {
+      sprintf(line, "Desk %d", Scr.CurrentDesk);
+      name = &(line[0]);
+    }
+      XStoreName(dpy, Scr.Pager_w, name);
+      XSetIconName(dpy, Scr.Pager_w, name);
+  }
 
   MovePage(True);
   DrawGrid(oldDesk - desk1,1);
@@ -1149,20 +1169,20 @@ void list_window_name(unsigned long *body,unsigned long type)
     {
       switch (type) {
       case M_RES_CLASS:
-        if(t->res_class != NULL)
-          free(t->res_class);
-        CopyString(&t->res_class,(char *)(&body[3]));
-        break;
+	if(t->res_class != NULL)
+	  free(t->res_class);
+	CopyString(&t->res_class,(char *)(&body[3]));
+	break;
       case M_RES_NAME:
-        if(t->res_name != NULL)
-          free(t->res_name);
-        CopyString(&t->res_name,(char *)(&body[3]));
-        break;
+	if(t->res_name != NULL)
+	  free(t->res_name);
+	CopyString(&t->res_name,(char *)(&body[3]));
+	break;
       case M_VISIBLE_NAME:
-        if(t->window_name != NULL)
-          free(t->window_name);
-        CopyString(&t->window_name,(char *)(&body[3]));
-        break;
+	if(t->window_name != NULL)
+	  free(t->window_name);
+	CopyString(&t->window_name,(char *)(&body[3]));
+	break;
       }
       /* repaint by clearing window */
       if ((FwindowFont != NULL) && (t->icon_name != NULL)
@@ -1235,12 +1255,12 @@ void list_mini_icon(unsigned long *body)
     t = t->next;
   if (t)
   {
-    t->mini_icon.width   = mip->width;
-    t->mini_icon.height  = mip->height;
-    t->mini_icon.depth   = mip->depth;
+    t->mini_icon.width	 = mip->width;
+    t->mini_icon.height	 = mip->height;
+    t->mini_icon.depth	 = mip->depth;
     t->mini_icon.picture = mip->picture;
-    t->mini_icon.mask    = mip->mask;
-    t->mini_icon.alpha   = mip->alpha;
+    t->mini_icon.mask	 = mip->mask;
+    t->mini_icon.alpha	 = mip->alpha;
     /* repaint by clearing window */
     if (MiniIcons && t->mini_icon.picture) {
       if (t->PagerView)
@@ -1443,7 +1463,7 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 	miss_counter++;
 #ifdef WORRY_ABOUT_MISSED_XEVENTS
 	if(miss_counter > 100)
-          DeadPipe(0);
+	  DeadPipe(0);
 #endif
     }
 
@@ -1718,19 +1738,19 @@ void ParseOptions(void)
       {
 	window_x = g_x;
 	usposition = 1;
-        if (flags & XNegative)
-        {
-          xneg = 1;
-        }
+	if (flags & XNegative)
+	{
+	  xneg = 1;
+	}
       }
       if (flags & YValue)
       {
 	window_y = g_y;
 	usposition = 1;
-        if (flags & YNegative)
-        {
-          yneg = 1;
-        }
+	if (flags & YNegative)
+	{
+	  yneg = 1;
+	}
       }
     }
     else if (StrEquals(resource, "IconGeometry"))
@@ -1749,18 +1769,18 @@ void ParseOptions(void)
       if (flags & XValue)
       {
 	icon_x = g_x;
-        if (flags & XNegative)
-        {
-          icon_xneg = 1;
-        }
+	if (flags & XNegative)
+	{
+	  icon_xneg = 1;
+	}
       }
       if (flags & YValue)
       {
 	icon_y = g_y;
-        if (flags & YNegative)
-        {
-          icon_yneg = 1;
-        }
+	if (flags & YNegative)
+	{
+	  icon_yneg = 1;
+	}
       }
     }
     else if (StrEquals(resource, "Label"))
@@ -1780,22 +1800,7 @@ void ParseOptions(void)
     {
       if (font_string)
 	free(font_string);
-      if (next && next[0] == '\"')
-      {
-	int l;
-
-	next++;
-	CopyString(&font_string, next);
-	l = strlen(font_string);
-	if (l > 0 && font_string[l - 1] == '\"')
-	{
-	  font_string[l - 1] = 0;
-	}
-      }
-      else
-      {
-	CopyString(&font_string,next);
-      }
+      CopyStringWithQuotes(&font_string, next);
       if(strncasecmp(font_string,"none",4) == 0)
       {
 	uselabel = 0;
@@ -1997,22 +2002,7 @@ void ParseOptions(void)
     {
       if (smallFont)
 	free(smallFont);
-      if (next && next[0] == '\"')
-      {
-	int l;
-
-	next++;
-	CopyString(&smallFont, next);
-	l = strlen(smallFont);
-	if (l > 0 && smallFont[l - 1] == '\"')
-	{
-	  smallFont[l - 1] = 0;
-	}
-      }
-      else
-      {
-	CopyString(&smallFont,next);
-      }
+      CopyStringWithQuotes(&smallFont, next);
       if (strncasecmp(smallFont,"none",4) == 0)
       {
 	free(smallFont);
@@ -2176,7 +2166,7 @@ void ParseOptions(void)
     {
       if (BalloonFont)
 	free(BalloonFont);
-      CopyString(&BalloonFont, next);
+      CopyStringWithQuotes(&BalloonFont, next);
     }
 
     else if (StrEquals(resource, "BalloonBorderColor"))
