@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /***********************************************************************
@@ -119,7 +119,7 @@ static char l_g_bits[] = {0x08, 0x02};
 static char s_g_bits[] = {0x01, 0x02, 0x04, 0x08};
 
 
-Window icon_win;               /* icon window */
+Window icon_win;	       /* icon window */
 
 static char *GetBalloonLabel(const PagerWindow *pw,const char *fmt);
 extern void ExitPager(void);
@@ -151,10 +151,10 @@ static void discard_events(long event_type, Window w, XEvent *last_ev)
  *	given the real window size.
  *	You can always tell bad code by the size of the comments.
  *
- *      dv: Some people say that good code does not nee lengthy comments. :-)
+ *	dv: Some people say that good code does not nee lengthy comments. :-)
  ***********************************************************************/
 static void CalcGeom(PagerWindow *t, int win_w, int win_h,
-                     int *x_ret, int *y_ret, int *w_ret, int *h_ret)
+		     int *x_ret, int *y_ret, int *w_ret, int *h_ret)
 {
   int virt, virt2, edge, edge2, size, page, over;
 
@@ -197,14 +197,14 @@ static void CalcGeom(PagerWindow *t, int win_w, int win_h,
     if (page == ((virt - t->width + 1) / Scr.MyDisplayWidth)) {
       /* calculate how far the mini-window right edge overlaps the page line */
       /* beware that the "over" is actually one greater than on screen, but
-         this discrepancy is catered for in the next two lines */
+	 this discrepancy is catered for in the next two lines */
       over = edge + size - ((page + 1) * win_w * Scr.MyDisplayWidth) /
 	Scr.VWidth;
 
       /* if the mini-window right edge is beyond the mini-window pager grid */
       if (over > 0) {
-        /* move it left by the amount of pager grid overlap (!== the growth) */
-        edge -= over;
+	/* move it left by the amount of pager grid overlap (!== the growth) */
+	edge -= over;
       }
     }
   }
@@ -228,7 +228,7 @@ static void CalcGeom(PagerWindow *t, int win_w, int win_h,
       over = edge + size - ((page + 1) * win_h * Scr.MyDisplayHeight) /
 	Scr.VHeight;
       if (over > 0)
-        edge -= over;
+	edge -= over;
     }
   }
   *y_ret = edge;
@@ -239,7 +239,7 @@ static void CalcGeom(PagerWindow *t, int win_w, int win_h,
  *
  *  Procedure:
  *	Initialize_viz_pager - creates a temp window of the correct visual
- *      so that pixmaps may be created for use with the main window
+ *	so that pixmaps may be created for use with the main window
  ***********************************************************************/
 void initialize_viz_pager(void)
 {
@@ -280,13 +280,13 @@ char *pager_name = "Fvwm Pager";
 XSizeHints sizehints =
 {
   (PMinSize | PResizeInc | PBaseSize | PWinGravity),
-  0, 0, 100, 100,	                /* x, y, width and height */
-  1, 1,		                        /* Min width and height */
-  0, 0,		                        /* Max width and height */
-  1, 1,	                         	/* Width and height increments */
-  {0, 0}, {0, 0},                       /* Aspect ratio - not used */
-  1, 1,                 		/* base size */
-  (NorthWestGravity)                    /* gravity */
+  0, 0, 100, 100,			/* x, y, width and height */
+  1, 1,					/* Min width and height */
+  0, 0,					/* Max width and height */
+  1, 1,					/* Width and height increments */
+  {0, 0}, {0, 0},			/* Aspect ratio - not used */
+  1, 1,					/* base size */
+  (NorthWestGravity)			/* gravity */
 };
 
 void initialize_pager(void)
@@ -612,10 +612,10 @@ void initialize_pager(void)
 
   for(i=0;i<ndesks;i++)
   {
-    w = window_w/ndesks;
-    h = window_h;
-    x = w*i;
-    y = 0;
+    w = window_w / Columns;
+    h = window_h / Rows;
+    x = (w + 1) * (i % Columns);
+    y = (h + 1) * (i / Columns);
 
     /* create the GC for desk labels */
     gcv.foreground = (Desks[i].colorset < 0) ? fore_pix
@@ -624,10 +624,10 @@ void initialize_pager(void)
     if (uselabel && Ffont && Ffont->font) {
       gcv.font = Ffont->font->fid;
       Desks[i].NormalGC =
-        fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground | GCFont, &gcv);
+	fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground | GCFont, &gcv);
     } else {
       Desks[i].NormalGC =
-        fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground, &gcv);
+	fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground, &gcv);
     }
     /* create the active desk hilite GC */
     if(Pdepth < 2)
@@ -647,10 +647,10 @@ void initialize_pager(void)
 
     if (uselabel && Ffont && Ffont->font) {
       Desks[i].rvGC =
-        fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground | GCFont, &gcv);
+	fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground | GCFont, &gcv);
     } else {
       Desks[i].rvGC =
-        fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground, &gcv);
+	fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground, &gcv);
     }
     /* create the virtual page boundary GC */
     gcv.foreground = (Desks[i].colorset < 0) ? fore_pix
@@ -673,25 +673,27 @@ void initialize_pager(void)
     valuemask = (CWBorderPixel | CWColormap | CWEventMask);
     if (Desks[i].colorset >= 0 && Colorset[Desks[i].colorset].pixmap)
     {
-        valuemask |= CWBackPixmap;
-        attributes.background_pixmap = Colorset[Desks[i].colorset].pixmap;
+	valuemask |= CWBackPixmap;
+	attributes.background_pixmap = Colorset[Desks[i].colorset].pixmap;
     }
     else
     {
-        valuemask |= CWBackPixel;
-        attributes.background_pixel = (Desks[i].colorset < 0) ?
-            (Desks[i].Dcolor ? GetColor(Desks[i].Dcolor) : back_pix)
-            : Colorset[Desks[i].colorset].bg;
+	valuemask |= CWBackPixel;
+	attributes.background_pixel = (Desks[i].colorset < 0) ?
+	    (Desks[i].Dcolor ? GetColor(Desks[i].Dcolor) : back_pix)
+	    : Colorset[Desks[i].colorset].bg;
     }
 
     attributes.border_pixel = (Desks[i].colorset < 0) ? fore_pix
       : Colorset[Desks[i].colorset].fg;
     attributes.event_mask = (ExposureMask | ButtonReleaseMask);
-    Desks[i].title_w = XCreateWindow(dpy, Scr.Pager_w, x, y, w, h, 1,
-				     CopyFromParent, InputOutput,
-				     CopyFromParent, valuemask, &attributes);
+    Desks[i].title_w = XCreateWindow(
+      dpy, Scr.Pager_w,
+      x - 1, y - 1, w, h,
+      1, CopyFromParent, InputOutput, CopyFromParent, valuemask, &attributes);
     attributes.event_mask = (ExposureMask | ButtonReleaseMask |
 			     ButtonPressMask |ButtonMotionMask);
+    /* or just: desk_h = h - label_h; */
     desk_h = (window_h - Rows * label_h - Rows + 1) / Rows;
 
     valuemask &= ~(CWBackPixel);
@@ -725,15 +727,16 @@ void initialize_pager(void)
 	: Colorset[Desks[i].colorset].bg;
     }
 
-    Desks[i].w = XCreateWindow(dpy, Desks[i].title_w, x, y, w, desk_h, 1,
-			       CopyFromParent, InputOutput, CopyFromParent,
-			       valuemask, &attributes);
+    Desks[i].w = XCreateWindow(
+      dpy, Desks[i].title_w,
+      x - 1, LabelsBelow ? y - 1 : y + label_h - 1, w, desk_h,
+      1, CopyFromParent, InputOutput, CopyFromParent, valuemask, &attributes);
     if (Desks[i].colorset > -1 &&
 	Colorset[Desks[i].colorset].pixmap)
     {
       SetWindowBackground(
-          dpy, Desks[i].w, w, desk_h, &Colorset[Desks[i].colorset], Pdepth,
-          Scr.NormalGC, True);
+	  dpy, Desks[i].w, w, desk_h, &Colorset[Desks[i].colorset], Pdepth,
+	  Scr.NormalGC, True);
     }
 
 
@@ -761,8 +764,8 @@ void initialize_pager(void)
 	  : Colorset[Desks[i].highcolorset].bg;
       }
 
-      w = (window_w - n)/(n+1);
-      h = (window_h - label_h - m)/(m+1);
+      w = w / (n + 1);
+      h = desk_h / (m + 1);
       Desks[i].CPagerWin=XCreateWindow(dpy, Desks[i].w, -32768, -32768, w, h, 0,
 				       CopyFromParent, InputOutput,
 				       CopyFromParent, valuemask, &attributes);
@@ -770,8 +773,8 @@ void initialize_pager(void)
 	  Colorset[Desks[i].highcolorset].pixmap)
       {
 	SetWindowBackground(
-            dpy, Desks[i].CPagerWin, w, h, &Colorset[Desks[i].highcolorset],
-            Pdepth, Scr.NormalGC, True);
+	    dpy, Desks[i].CPagerWin, w, h, &Colorset[Desks[i].highcolorset],
+	    Pdepth, Scr.NormalGC, True);
       }
       XMapRaised(dpy,Desks[i].CPagerWin);
     }
@@ -799,11 +802,11 @@ void initialize_pager(void)
 	? balloon_back_pix
 	: Colorset[Desks[i].ballooncolorset].bg;
       if (Desks[i].ballooncolorset > -1 &&
-          Colorset[Desks[i].ballooncolorset].pixmap)
+	  Colorset[Desks[i].ballooncolorset].pixmap)
       {
-        valuemask |= CWBackPixmap;
-        valuemask &= ~CWBackPixel;
-        attributes.background_pixmap = None; /* set later */
+	valuemask |= CWBackPixmap;
+	valuemask &= ~CWBackPixel;
+	attributes.background_pixmap = None; /* set later */
       }
 
       /* get font for balloon */
@@ -858,7 +861,7 @@ void initialize_pager(void)
       }
 /* don't do this yet, wait for map since size will change
       if (Desks[i].ballooncolorset > -1 &&
-          Colorset[Desks[i].ballooncolorset].pixmap)
+	  Colorset[Desks[i].ballooncolorset].pixmap)
       {
 	SetWindowBackground(dpy, Desks[i].balloon.w, 100,
 			    Desks[i].balloon.height,
@@ -1283,15 +1286,15 @@ void ReConfigure(void)
 	XMoveResizeWindow(dpy,Desks[i].title_w,
 			  (desk_w+1)*j-1,(desk_h+label_h+1)*k-1,
 			  desk_w,desk_h+label_h);
-	y_pos = (LabelsBelow ? 0 : label_h - 1);
+	y_pos = (LabelsBelow ? -1 : label_h - 1);
 	XMoveResizeWindow(dpy,Desks[i].w,-1, y_pos,
 			  desk_w,desk_h);
-        if (Desks[i].colorset > -1 &&
-            Colorset[Desks[i].colorset].pixmap)
-        {
-          SetWindowBackground(
-              dpy, Desks[i].w, desk_w, desk_h, &Colorset[Desks[i].colorset],
-              Pdepth, Scr.NormalGC, True);
+	if (Desks[i].colorset > -1 &&
+	    Colorset[Desks[i].colorset].pixmap)
+	{
+	  SetWindowBackground(
+	      dpy, Desks[i].w, desk_w, desk_h, &Colorset[Desks[i].colorset],
+	      Pdepth, Scr.NormalGC, True);
 	}
 	if (HilightDesks)
 	{
@@ -1303,8 +1306,8 @@ void ReConfigure(void)
 	      Colorset[Desks[i].highcolorset].pixmap)
 	  {
 	    SetWindowBackground(
-                dpy, Desks[i].CPagerWin, w, h, &Colorset[Desks[i].highcolorset],
-                Pdepth, Scr.NormalGC, True);
+		dpy, Desks[i].CPagerWin, w, h, &Colorset[Desks[i].highcolorset],
+		Pdepth, Scr.NormalGC, True);
 	  }
 	}
 
@@ -1418,6 +1421,7 @@ void DrawGrid(int desk, int erase)
 {
   int y, y1, y2, x, x1, x2,d,w;
   char str[15], *ptr;
+  int cs;
 
   if((desk < 0 ) || (desk >= ndesks))
     return;
@@ -1472,17 +1476,25 @@ void DrawGrid(int desk, int erase)
     FwinString->str = ptr;
     FwinString->win = Desks[desk].title_w;
     if(desk == (Scr.CurrentDesk - desk1))
+    {
+      cs = Desks[desk].highcolorset;
       FwinString->gc = Desks[desk].rvGC;
+    }
     else
+    {
+      cs = Desks[desk].highcolorset;
       FwinString->gc = Desks[desk].NormalGC;
+    }
+
+    FwinString->flags.has_colorset = False;
+    if (cs >= 0)
+    {
+      FwinString->colorset = &Colorset[cs];
+      FwinString->flags.has_colorset = True;
+    }
     FwinString->x = (desk_w -w)/2;
     FwinString->y = (LabelsBelow ?
 		     desk_h + Ffont->ascent + 1 : Ffont->ascent + 1);
-    if(desk == (Scr.CurrentDesk - desk1))
-      FwinString->gc = Desks[desk].rvGC;
-    else
-      FwinString->gc = Desks[desk].NormalGC;
-
     FlocaleDrawString(dpy, Ffont, FwinString, 0);
   }
   if (FShapesSupported)
@@ -1512,7 +1524,7 @@ void DrawIconGrid(int erase)
     {
       if (Desks[tmp].bgPixmap)
 	XSetWindowBackgroundPixmap(
-            dpy, icon_win,Desks[tmp].bgPixmap->picture);
+	    dpy, icon_win,Desks[tmp].bgPixmap->picture);
       else if (Desks[tmp].Dcolor)
 	XSetWindowBackground(dpy, icon_win, GetColor(Desks[tmp].Dcolor));
       else if (PixmapBack)
@@ -1532,7 +1544,7 @@ void DrawIconGrid(int erase)
     x1 = x * icon_w / Scr.VWidth;
     if (!use_no_separators)
       for(i=0;i<ndesks;i++)
-        XDrawLine(dpy,icon_win,Desks[i].DashedGC,x1,y1,x1,y2);
+	XDrawLine(dpy,icon_win,Desks[i].DashedGC,x1,y1,x1,y2);
     x += Scr.MyDisplayWidth;
   }
 
@@ -1544,7 +1556,7 @@ void DrawIconGrid(int erase)
     y1 = y * icon_h / Scr.VHeight;
     if (!use_no_separators)
       for(i=0;i<ndesks;i++)
-        XDrawLine(dpy,icon_win,Desks[i].DashedGC,x1,y1,x2,y1);
+	XDrawLine(dpy,icon_win,Desks[i].DashedGC,x1,y1,x2,y1);
     y += Scr.MyDisplayHeight;
   }
   n1 = Scr.Vx / Scr.MyDisplayWidth;
@@ -2301,7 +2313,7 @@ void MoveWindow(XEvent *Event)
 /***********************************************************************
  *
  *  Procedure:
- *      FvwmErrorHandler - displays info on internal errors
+ *	FvwmErrorHandler - displays info on internal errors
  *
  ************************************************************************/
 int FvwmErrorHandler(Display *dpy, XErrorEvent *event)
@@ -2358,10 +2370,18 @@ void BorderIconWindow(PagerWindow *t)
 
 static void do_label_window(PagerWindow *t, Window w)
 {
+  int cs;
+
   if (t == FocusWin)
+  {
     XSetForeground(dpy, Scr.NormalGC, focus_fore_pix);
+    cs =  activecolorset;
+  }
   else
+  {
     XSetForeground(dpy, Scr.NormalGC, t->text);
+    cs = windowcolorset;
+  }
 
   if (FwindowFont == NULL)
   {
@@ -2388,6 +2408,12 @@ static void do_label_window(PagerWindow *t, Window w)
     FwinString->str = t->window_label;
     FwinString->win = w;
     FwinString->gc = Scr.NormalGC;
+    FwinString->flags.has_colorset = False;
+    if (cs >= 0)
+    {
+	    FwinString->colorset = &Colorset[cs];
+	    FwinString->flags.has_colorset = True;
+    }
     FwinString->x = 2;
     FwinString->y = FwindowFont->ascent+2;
     FlocaleDrawString(dpy, FwindowFont, FwinString, 0);
@@ -2650,7 +2676,7 @@ void MapBalloonWindow(PagerWindow *t, Bool is_icon_view)
   /* balloon is a top-level window, therefore need to
      translate pager window coords to root window coords */
   XTranslateCoordinates(dpy, view, Scr.Root, x, y,
-                        &window_changes.x, &window_changes.y, &dummy);
+			&window_changes.x, &window_changes.y, &dummy);
 
 
   /* make sure balloon doesn't go off screen
@@ -2679,7 +2705,7 @@ void MapBalloonWindow(PagerWindow *t, Bool is_icon_view)
 
   /* too close to right */
   else if ( window_changes.x + window_changes.width >
-            Scr.MyDisplayWidth - (2 * Desks[i].balloon.border) - 2 )
+	    Scr.MyDisplayWidth - (2 * Desks[i].balloon.border) - 2 )
     window_changes.x = Scr.MyDisplayWidth - window_changes.width -
       (2 * Desks[i].balloon.border) - 2;
 
@@ -2736,21 +2762,21 @@ char *GetBalloonLabel(const PagerWindow *pw,const char *fmt)
       pos++;
       switch (*pos) {
       case 'i':
-        InsertExpand(&dest, pw->icon_name);
-        break;
+	InsertExpand(&dest, pw->icon_name);
+	break;
       case 't':
-        InsertExpand(&dest, pw->window_name);
-        break;
+	InsertExpand(&dest, pw->window_name);
+	break;
       case 'r':
-        InsertExpand(&dest, pw->res_name);
-        break;
+	InsertExpand(&dest, pw->res_name);
+	break;
       case 'c':
-        InsertExpand(&dest, pw->res_class);
-        break;
+	InsertExpand(&dest, pw->res_class);
+	break;
       case '%':
-        buffer[0] = '%';
-        InsertExpand(&dest, buffer);
-        break;
+	buffer[0] = '%';
+	InsertExpand(&dest, buffer);
+	break;
       default:;
       }
     } else {
@@ -2788,6 +2814,15 @@ void DrawInBalloonWindow (int i)
   FwinString->str = Desks[i].balloon.label;
   FwinString->win = Desks[i].balloon.w;
   FwinString->gc = Desks[i].BalloonGC;
+  if (Desks[i].ballooncolorset >= 0)
+  {
+    FwinString->colorset = &Colorset[Desks[i].ballooncolorset];
+    FwinString->flags.has_colorset = True;
+  }
+  else
+  {
+    FwinString->flags.has_colorset = False;
+  }
   FwinString->x = 2;
   FwinString->y = Desks[i].balloon.Ffont->ascent;
   FlocaleDrawString(dpy, Desks[i].balloon.Ffont, FwinString, 0);
@@ -2833,10 +2868,10 @@ void change_colorset(int colorset)
 	    dpy, Desks[i].title_w, 0, 0, &Colorset[colorset], Pdepth,
 	    Scr.NormalGC, True);
 	}
-        SetWindowBackground(
+	SetWindowBackground(
 	  dpy, Desks[i].CPagerWin, 0, 0, &Colorset[colorset], Pdepth,
 	  Scr.NormalGC, True);
-        XLowerWindow(dpy,Desks[i].CPagerWin);
+	XLowerWindow(dpy,Desks[i].CPagerWin);
       }
     }
 
