@@ -5,18 +5,17 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include <libs/fvwmlib.h>
-
-#define STICKY 1
-#define ICONIFIED     32 /* is it an icon now? */
+#include <fvwm/fvwm.h>
+#include <libs/vpacket.h>
 
 struct list
 {
@@ -31,7 +30,7 @@ struct list
   int frame_y;
   int title_height;
   int boundary_width;
-  unsigned long flags;
+  window_flags flags;
   unsigned long gravity;
   struct list *next;
 };
