@@ -5,19 +5,19 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "Tools.h"
 
 
 /***********************************************/
-/* Fonction pour Rectangle                      */
+/* Fonction pour Rectangle			*/
 /***********************************************/
 void InitRectangle(struct XObj *xobj)
 {
@@ -37,7 +37,7 @@ void InitRectangle(struct XObj *xobj)
   xobj->TabColor[shad] = GetColor(xobj->shadcolor);
  }
 
- xobj->gc=XCreateGC(dpy,*xobj->ParentWin,0,NULL);
+ xobj->gc=fvwmlib_XCreateGC(dpy,*xobj->ParentWin,0,NULL);
  XSetForeground(dpy,xobj->gc,xobj->TabColor[fore]);
  XSetBackground(dpy,xobj->gc,xobj->TabColor[back]);
  XSetLineAttributes(dpy,xobj->gc,1,LineSolid,CapRound,JoinMiter);
