@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "Tools.h"
@@ -18,7 +18,7 @@
 extern int fd[2];
 
 /***********************************************/
-/* Fonction pour Swallow                       */
+/* Fonction pour Swallow		       */
 /***********************************************/
 
 void DrawRelief(struct XObj *xobj)
@@ -69,10 +69,10 @@ void InitSwallow(struct XObj *xobj)
 
  /* Enregistrement des couleurs et de la police */
  if (xobj->colorset >= 0) {
-  xobj->TabColor[fore] = Colorset[xobj->colorset % nColorsets].fg;
-  xobj->TabColor[back] = Colorset[xobj->colorset % nColorsets].bg;
-  xobj->TabColor[hili] = Colorset[xobj->colorset % nColorsets].hilite;
-  xobj->TabColor[shad] = Colorset[xobj->colorset % nColorsets].shadow;
+  xobj->TabColor[fore] = Colorset[xobj->colorset].fg;
+  xobj->TabColor[back] = Colorset[xobj->colorset].bg;
+  xobj->TabColor[hili] = Colorset[xobj->colorset].hilite;
+  xobj->TabColor[shad] = Colorset[xobj->colorset].shadow;
  } else {
   xobj->TabColor[fore] = GetColor(xobj->forecolor);
   xobj->TabColor[back] = GetColor(xobj->backcolor);
