@@ -5,21 +5,21 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "Tools.h"
 
 
 /***********************************************/
-/* Fonction pour VDipstick                     */
-/* Cration d'une jauge verticale              */
-/* plusieurs options                           */
+/* Fonction pour VDipstick		       */
+/* Cration d'une jauge verticale	       */
+/* plusieurs options			       */
 /***********************************************/
 void InitVDipstick(struct XObj *xobj)
 {
@@ -52,7 +52,7 @@ void InitVDipstick(struct XObj *xobj)
 		xobj->x,xobj->y,xobj->width,xobj->height,0,
 		CopyFromParent,InputOutput,CopyFromParent,
 		mask,&Attr);
- xobj->gc=XCreateGC(dpy,xobj->win,0,NULL);
+ xobj->gc=fvwmlib_XCreateGC(dpy,xobj->win,0,NULL);
  if (xobj->colorset >= 0)
    SetWindowBackground(dpy, xobj->win, xobj->width, xobj->height,
 		       &Colorset[xobj->colorset], Pdepth,
