@@ -2,7 +2,7 @@
  *
  * (Much reworked version of FvwmWinList)
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
- *                               Mike_Finger@atk.com)
+ *				 Mike_Finger@atk.com)
  *
  * Two little hacks by DYB: 1) make size of a strip in hidden state tunable
  * (with *FvwmTaskBar: AutoHide <pixels>); 2) make process of TaskBar
@@ -36,12 +36,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -74,6 +74,8 @@
 #include "libs/Colorset.h"
 #include "libs/Flocale.h"
 #include "libs/gravity.h"
+#include "libs/FRender.h"
+#include "libs/FRenderInit.h"
 
 #include "FvwmTaskBar.h"
 #include "ButtonArray.h"
@@ -96,7 +98,7 @@
 #define gray_width  8
 #define gray_height 8
 unsigned char gray_bits[] = { 0xaa, 0x55, 0xaa, 0x55,
-                              0xaa, 0x55, 0xaa, 0x55 };
+			      0xaa, 0x55, 0xaa, 0x55 };
 
 #define DEFAULT_VISIBLE_PIXELS 3
 
@@ -106,31 +108,31 @@ int   x_fd;
 
 /* X related things */
 Display *dpy;
-Window  Root, win;
-int     screen;
+Window	Root, win;
+int	screen;
 Pixel back;
 Pixel fore;
 static Pixel iconfore;
 static Pixel iconback;
 static Pixel focusfore;
 static Pixel focusback;
-GC      icongraph = None;
-GC      iconbackgraph = None;
-GC      focusgraph = None;
-GC      focusbackgraph = None;
-GC      graph = None;
-GC      shadow = None;
-GC      hilite = None;
-GC      iconshadow = None;
-GC      iconhilite = None;
-GC      focusshadow = None;
-GC      focushilite = None;
-GC      blackgc = None;
-GC      whitegc = None;
-GC      checkered = None;
-int     colorset = -1;
-int     iconcolorset = -1;
-int     focuscolorset = -1;
+GC	icongraph = None;
+GC	iconbackgraph = None;
+GC	focusgraph = None;
+GC	focusbackgraph = None;
+GC	graph = None;
+GC	shadow = None;
+GC	hilite = None;
+GC	iconshadow = None;
+GC	iconhilite = None;
+GC	focusshadow = None;
+GC	focushilite = None;
+GC	blackgc = None;
+GC	whitegc = None;
+GC	checkered = None;
+int	colorset = -1;
+int	iconcolorset = -1;
+int	focuscolorset = -1;
 FlocaleFont *FButtonFont, *FSelButtonFont;
 FlocaleWinString *FwinString;
 int fontheight;
@@ -140,8 +142,8 @@ static Bool is_dead_pipe = False;
 
 /* Module related information */
 char *Module;
-int  win_width    = 5,
-     win_height   = 5,
+int  win_width	  = 5,
+     win_height	  = 5,
      win_grav,
      win_x,
      win_y,
@@ -152,12 +154,12 @@ int  win_width    = 5,
      win_is_shaded = 0,
      button_width = DEFAULT_BTN_WIDTH,
      Clength,
-     ButPressed   = -1,
+     ButPressed	  = -1,
      ButReleased  = -1,
-     Checked      = 0,
+     Checked	  = 0,
      WindowState  = -2, /* -2 unmaped, 1 not hidden, -1 hidden,
 			 *  0 hidden -> not hidden (for the events loop) */
-     FocusInWin = 0;    /* 1 if the Taskbar has the focus */
+     FocusInWin = 0;	/* 1 if the Taskbar has the focus */
 
 static volatile sig_atomic_t AlarmSet = NOT_SET;
 static volatile sig_atomic_t tip_window_alarm = False;
@@ -176,32 +178,32 @@ char *ClickAction[max(NUMBER_OF_MOUSE_BUTTONS, 3)] =
   DEFAULT_CLICK3
 },
      *EnterAction,
-     *BackColor      = "white",
-     *ForeColor      = "black",
+     *BackColor	     = "white",
+     *ForeColor	     = "black",
      *IconBackColor  = "white",
      *IconForeColor  = "black",
      *FocusBackColor = NULL,
      *FocusForeColor = NULL,
-     *geometry       = NULL,
+     *geometry	     = NULL,
      *font_string    = NULL,
      *selfont_string = NULL;
 
 static char *AnimCommand = NULL;
 
-int UseSkipList    = False,
+int UseSkipList	   = False,
     UseIconNames   = False,
     ShowTransients = False,
-    adjust_flag    = False,
-    AutoStick      = False,
-    AutoHide       = False,
-    AutoFocus      = False,
+    adjust_flag	   = False,
+    AutoStick	   = False,
+    AutoHide	   = False,
+    AutoFocus	   = False,
     HighlightFocus = False,
-    DeskOnly       = False,
-    PageOnly       = False,
-    ScreenOnly     = False,
+    DeskOnly	   = False,
+    PageOnly	   = False,
+    ScreenOnly	   = False,
     NoBrightFocus  = False,
-    ThreeDfvwm     = False,
-    RowsNumber     = 1;
+    ThreeDfvwm	   = False,
+    RowsNumber	   = 1;
 
 int VisiblePixels  = DEFAULT_VISIBLE_PIXELS;
 /* This macro should be used when calculating geometry */
@@ -213,12 +215,12 @@ rectangle global_scr_g;
 int NRows, RowHeight, Midline;
 
 #define COUNT_LIMIT    10000
-long DeskNumber;               /* Added by Balaji R */
+long DeskNumber;	       /* Added by Balaji R */
 int  First = 1;
 int  Count = 0;
 
 /* Imported from Goodies */
-extern int stwin_width, goodies_width;
+extern int stwin_width, goodies_width, goodies_fontheight;
 extern TipStruct Tip;
 
 /* Imported from Start */
@@ -356,8 +358,8 @@ int main(int argc, char **argv)
 
   /* init the array of buttons */
   InitArray(&buttons, StartButtonWidth + 4, 0,
-                      win_width - stwin_width - 8 - StartButtonWidth -10,
-                      RowHeight, button_width);
+		      win_width - stwin_width - 8 - StartButtonWidth -10,
+		      RowHeight, button_width);
   InitList(&windows);
 
   /* Request a list of all windows,
@@ -385,12 +387,12 @@ int main(int argc, char **argv)
 
 
 /******************************************************************************
-  EndLessLoop -  Read and redraw until we get killed, blocking when can't read
+  EndLessLoop -	 Read and redraw until we get killed, blocking when can't read
 ******************************************************************************/
 void EndLessLoop(void)
 {
   fd_set readset;
-  fd_set_size_t  fd_width;
+  fd_set_size_t	 fd_width;
   struct timeval tv;
 
   fd_width = x_fd;
@@ -413,12 +415,12 @@ void EndLessLoop(void)
 
       if (FD_ISSET(x_fd, &readset) || XPending(dpy))
       {
-        LoopOnEvents();
+	LoopOnEvents();
       }
 
       if (FD_ISSET(Fvwm_fd[1], &readset))
       {
-        ReadFvwmPipe();
+	ReadFvwmPipe();
       }
     }
     DoAlarmAction();
@@ -544,13 +546,13 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 	}
 
 	XGetWMNormalHints(dpy,win,&hints,&dumy);
-	hints.min_width   = win_width;
+	hints.min_width	  = win_width;
 	hints.base_width  = win_width;
-	hints.max_width   = win_width;
+	hints.max_width	  = win_width;
 
 	XSetWMNormalHints(dpy,win,&hints);
 
- 	if (AutoStick)
+	if (AutoStick)
 	  XMoveResizeWindow(dpy, win, win_x, win_y, win_width, win_height);
 	else
 	  XResizeWindow(dpy, win, win_width, win_height);
@@ -735,7 +737,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 
   case M_VISIBLE_NAME:
   case MX_VISIBLE_ICON_NAME:
-    if ((type == MX_VISIBLE_ICON_NAME   && !UseIconNames) ||
+    if ((type == MX_VISIBLE_ICON_NAME	&& !UseIconNames) ||
 	(type == M_VISIBLE_NAME &&  UseIconNames)) break;
     string = (char *) &body[3];
     if ((i = UpdateItemName(&windows, body[0], (char *)&body[3])) == -1)
@@ -772,7 +774,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
     iconified = IsItemIconified(&windows, body[0]);
     if (((i = FindItem(&windows, body[0])) == -1)
 	|| (type == M_DEICONIFY && !iconified)
-	|| (type == M_ICONIFY   && iconified))
+	|| (type == M_ICONIFY	&& iconified))
     {
       if (AnimCommand && AnimCommand[0] != 0)
 	SendUnlockNotification(Fvwm_fd);
@@ -809,7 +811,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 	  SendText(Fvwm_fd, buff, 0);
 	}
 	temp->needsupdate = 1;
-  	temp->iconified = iconified;
+	temp->iconified = iconified;
 	DrawButtonArray(&buttons, 0);
       }
       if (AnimCommand && AnimCommand[0] != 0)
@@ -886,7 +888,8 @@ void redraw_buttons()
 
   for (item=windows.head; item; item=item->next)
   {
-    if ((DeskNumber == item->Desk || IS_STICKY(item)) &&
+    if ((DeskNumber == item->Desk || IS_STICKY(item) ||
+	 (IS_ICONIFIED(item) && IS_ICON_STICKY(item))) &&
 	(!DO_SKIP_WINDOW_LIST(item) || !UseSkipList))
     {
       AddButton(&buttons, item->name, &(item->p), BUTTON_UP, item->count,
@@ -1069,10 +1072,10 @@ static void ParseConfigLine(char *tline)
     switch(index)
     {
     case 0: /* Font */
-      CopyString(&font_string, rest);
+      CopyStringWithQuotes(&font_string, rest);
       break;
-    case 1: /* Selfont */
-      CopyString(&selfont_string, rest);
+    case 1: /* SelFont */
+      CopyStringWithQuotes(&selfont_string, rest);
       break;
     case 2: /* Geometry */
       while (isspace((unsigned char)*rest) && *rest != '\n' && *rest != 0)
@@ -1280,8 +1283,8 @@ void CheckForTip(int x, int y)
     num = LocateButton(&buttons, x, y, &bx, &by, &name, &trunc);
     if (num != -1) {
       if ((Tip.type != num)  ||
-          (Tip.text == NULL) || (!trunc && (strcmp(name, Tip.text) != 0)))
-        PopupTipWindow(bx+3, by, name);
+	  (Tip.text == NULL) || (!trunc && (strcmp(name, Tip.text) != 0)))
+	PopupTipWindow(bx+3, by, name);
       Tip.type = num;
     } else {
       Tip.type = NO_TIP;
@@ -1800,13 +1803,13 @@ static void CreateOrUpdateGCs(void)
 
    /* brighting */
    gcmask = GCForeground | GCBackground | GCTile |
-            GCFillStyle  | GCGraphicsExposures;
+	    GCFillStyle	 | GCGraphicsExposures;
    if (focuscolorset >= 0 || FocusBackColor != NULL)
      gcval.foreground = pfocusback;
    else
      gcval.foreground = philite;
    gcval.fill_style = FillTiled;
-   gcval.tile       = XCreatePixmapFromBitmapData(dpy, win, (char *)gray_bits,
+   gcval.tile	    = XCreatePixmapFromBitmapData(dpy, win, (char *)gray_bits,
 						  gray_width, gray_height,
 						  gcval.foreground,
 						  gcval.background,Pdepth);
@@ -1865,6 +1868,7 @@ void StartMeUp(void)
    }
    AllocColorset(0);
    FShapeInit(dpy);
+   FRenderInit(dpy);
    FlocaleAllocateWinString(&FwinString);
    x_fd = XConnectionNumber(dpy);
    screen= DefaultScreen(dpy);
@@ -1898,9 +1902,12 @@ void StartMeUp(void)
      fprintf(stderr, "%s: Couldn't load font. Exiting!\n",Module);
      exit(1);
    }
+   LoadGoodiesFont();
 
    fontheight = (FButtonFont->height > FSelButtonFont->height)?
      FButtonFont->height : FSelButtonFont->height;
+   if (goodies_fontheight > fontheight)
+	   fontheight = goodies_fontheight;
 
    NRows = 1;
    RowHeight = fontheight + 8;
@@ -1951,9 +1958,9 @@ void StartMeUp(void)
 
    hints.flags=USPosition|PPosition|USSize|PSize|PResizeInc|
      PWinGravity|PMinSize|PMaxSize|PBaseSize;
-   hints.x           = screen_g.x;
-   hints.width       = win_width;
-   hints.height      = win_height;
+   hints.x	     = screen_g.x;
+   hints.width	     = win_width;
+   hints.height	     = win_height;
    hints.width_inc   = 1;
    hints.height_inc  = RowHeight+2;
    hints.min_width   = win_width;
@@ -2023,7 +2030,7 @@ void StartMeUp(void)
 		 GrabModeAsync,None,None);
    }
 
-   /*   SetMwmHints(MWM_DECOR_ALL|MWM_DECOR_MAXIMIZE|MWM_DECOR_MINIMIZE,
+   /*	SetMwmHints(MWM_DECOR_ALL|MWM_DECOR_MAXIMIZE|MWM_DECOR_MINIMIZE,
 	       MWM_FUNC_ALL|MWM_FUNC_MAXIMIZE|MWM_FUNC_MINIMIZE,
 	       MWM_INPUT_MODELESS);
 	       */
@@ -2037,8 +2044,8 @@ void StartMeUp(void)
    }
 
    XSelectInput(dpy,win,(ExposureMask | KeyPressMask | PointerMotionMask |
-                         EnterWindowMask | LeaveWindowMask |
-                         StructureNotifyMask));
+			 EnterWindowMask | LeaveWindowMask |
+			 StructureNotifyMask));
 
    InitGoodies();
    atexit(ShutMeDown);
@@ -2311,6 +2318,8 @@ ErrorHandler(Display *d, XErrorEvent *event)
     return 0;
   if (event->error_code == BadDrawable)
     return 0;
+  if (FRenderGetErrorCodeBase() + FRenderBadPicture == event->error_code)
+    return 0;
 
   PrintXErrorAndCoredump(d, event, Module);
   return 0;
