@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
@@ -61,7 +61,7 @@ GC tipsgc = 0;
 FlocaleFont *FStatusFont;
 int stwin_width = 100, goodies_width = 0;
 int anymail, unreadmail, newmail, mailcleared = 0;
-int fontheight, clock_width;
+int goodies_fontheight, clock_width;
 char *mailpath = NULL;
 char *clockfmt = NULL;
 char *datefmt = NULL;
@@ -88,7 +88,7 @@ void cool_get_inboxstatus();
 #define gray_height 8
 extern unsigned char gray_bits[];
 
-/*                x  y  w  h  tw th open type *text   win */
+/*		  x  y	w  h  tw th open type *text   win */
 TipStruct Tip = { 0, 0, 0, 0,  0, 0,   0,   0, NULL, None };
 
 
@@ -209,7 +209,7 @@ Bool GoodiesParseConfig(char *tline)
     UpdateString(&clockfmt, rest);
     break;
   case 4: /* StatusFont */
-    CopyString(&statusfont_string, rest);
+    CopyStringWithQuotes(&statusfont_string, rest);
     break;
   case 5: /* TipsFore */
     CopyString(&TipsFore, rest);
@@ -244,6 +244,17 @@ Bool GoodiesParseConfig(char *tline)
   return True;
 }
 
+void LoadGoodiesFont(void)
+{
+	if ((FStatusFont =
+	     FlocaleLoadFont(dpy, statusfont_string, Module)) == NULL)
+	{
+		fprintf(stderr, "%s: Couldn't load font. Exiting!\n",Module);
+		exit(1);
+	}
+	goodies_fontheight = FStatusFont->height;
+}
+
 void InitGoodies(void)
 {
   struct passwd *pwent;
@@ -256,13 +267,6 @@ void InitGoodies(void)
     UpdateString(&mailpath, tmp);
   }
 
-  if ((FStatusFont = FlocaleLoadFont(dpy, statusfont_string, Module)) == NULL)
-  {
-    fprintf(stderr, "%s: Couldn't load font. Exiting!\n",Module);
-    exit(1);
-  }
-
-  fontheight = FStatusFont->height;
   CreateOrUpdateGoodyGC();
   if (clockfmt)
   {
@@ -312,7 +316,16 @@ void DrawGoodies(void)
   FwinString->gc = statusgc;
   FwinString->str = str;
   FwinString->x = win_width - stwin_width + 4;
-  FwinString->y = ((RowHeight - fontheight) >> 1) + FStatusFont->ascent;
+  FwinString->y = ((RowHeight - goodies_fontheight) >> 1) + FStatusFont->ascent;
+  if (colorset >= 0)
+  {
+    FwinString->colorset = &Colorset[colorset];
+    FwinString->flags.has_colorset = True;
+  }
+  else
+  {
+    FwinString->flags.has_colorset = False;
+  }
   FlocaleDrawString(dpy, FStatusFont, FwinString, 0);
 
   if (!do_check_mail)
@@ -331,14 +344,14 @@ void DrawGoodies(void)
 	      ((RowHeight - minimail_height) >> 1));
   else if (!IgnoreOldMail /*&& !mailcleared*/ && anymail)
     XCopyArea(dpy, mailpix, win, statusgc, 0, 0,
-              minimail_width, minimail_height,
-              win_width - stwin_width + clock_width + 3,
-              ((RowHeight - minimail_height) >> 1));
+	      minimail_width, minimail_height,
+	      win_width - stwin_width + clock_width + 3,
+	      ((RowHeight - minimail_height) >> 1));
 
   if (Tip.open) {
     if (Tip.type == DATE_TIP)
       if (tms->tm_mday != last_date) /* reflect date change */
-        CreateDateWindow(); /* This automatically deletes any old window */
+	CreateDateWindow(); /* This automatically deletes any old window */
     last_date = tms->tm_mday;
     RedrawTipWindow();
   }
@@ -396,9 +409,20 @@ void RedrawTipWindow(void)
     FwinString->gc = tipsgc;
     FwinString->str = Tip.text;
     FwinString->x = 3;
-    FwinString->y = Tip.th-4;
+    FwinString->y = 2 + FStatusFont->ascent;
+    if (tipscolorset >= 0)
+    {
+       FwinString->colorset = &Colorset[tipscolorset];
+       FwinString->flags.has_colorset = True;
+    }
+    else
+    {
+       FwinString->flags.has_colorset = False;
+    }
     if (FftSupport && FStatusFont->fftf.fftfont != NULL)
-      XClearArea(dpy, Tip.win, 0, 0, Tip.w, Tip.h, False);
+    {
+       XClearArea(dpy, Tip.win, 0, 0, Tip.w, Tip.h, False);
+    }
     FlocaleDrawString(dpy, FStatusFont, FwinString, 0);
     XRaiseWindow(dpy, Tip.win);
   }
@@ -461,7 +485,7 @@ void CreateTipWindow(int x, int y, int w, int h)
 {
   unsigned long gcmask;
   unsigned long winattrmask = CWBackPixel | CWBorderPixel | CWEventMask |
-                              CWColormap |CWSaveUnder | CWOverrideRedirect;
+			      CWColormap |CWSaveUnder | CWOverrideRedirect;
   XSetWindowAttributes winattr;
   GC cgc = None;
   GC gc0 = None;
@@ -511,7 +535,7 @@ void CreateTipWindow(int x, int y, int w, int h)
   pclip = XCreatePixmap(dpy, Tip.win, w+4, h+4, 1);
 
   gcmask = GCForeground | GCBackground | GCFillStyle | GCStipple |
-           GCGraphicsExposures;
+	   GCGraphicsExposures;
   gcval.foreground = 1;
   gcval.background = 0;
   gcval.fill_style = FillStippled;
@@ -549,7 +573,7 @@ void CreateTipWindow(int x, int y, int w, int h)
   if (FShapesSupported)
   {
     FShapeCombineMask(dpy, Tip.win, FShapeBounding, 0, 0, pmask, FShapeSet);
-    FShapeCombineMask(dpy, Tip.win, FShapeClip,     0, 0, pclip, FShapeSet);
+    FShapeCombineMask(dpy, Tip.win, FShapeClip,	    0, 0, pclip, FShapeSet);
   }
   if (tipscolorset >= 0 && (cset->pixmap || cset->shape_mask))
   {
@@ -576,7 +600,7 @@ void DestroyTipWindow()
 }
 
 /*-----------------------------------------------------*/
-/* Get file modification time                          */
+/* Get file modification time			       */
 /* (based on the code of 'coolmail' By Byron C. Darrah */
 /*-----------------------------------------------------*/
 
@@ -590,8 +614,8 @@ void cool_get_inboxstatus()
    fd = open (mailpath, O_RDONLY, 0);
    if (fd < 0)
    {
-      anymail    = 0;
-      newmail    = 0;
+      anymail	 = 0;
+      newmail	 = 0;
       unreadmail = 0;
       newsize = 0;
    }
@@ -602,21 +626,21 @@ void cool_get_inboxstatus()
       newsize = st.st_size;
 
       if (newsize > 0)
-         anymail = 1;
+	 anymail = 1;
       else
-         anymail = 0;
+	 anymail = 0;
 
       if (st.st_mtime >= st.st_atime && newsize > 0)
-         unreadmail = 1;
+	 unreadmail = 1;
       else
-         unreadmail = 0;
+	 unreadmail = 0;
 
       if (newsize > oldsize && unreadmail) {
-         newmail = 1;
-         mailcleared = 0;
+	 newmail = 1;
+	 mailcleared = 0;
       }
       else
-         newmail = 0;
+	 newmail = 0;
    }
 
    oldsize = newsize;
