@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /*
@@ -20,8 +20,7 @@
 #ifndef START_H
 #define START_H
 
-extern void StartButtonParseConfig(const char *tline, char *Module);
-
+extern Bool StartButtonParseConfig(char *tline);
 extern void StartButtonInit(int height);
 extern int StartButtonUpdate(const char *title, int state);
 extern void StartButtonDraw(int force);
