@@ -1,7 +1,7 @@
 /* FvwmWinList Module for Fvwm.
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
- *                               Mike_Finger@atk.com)
+ *				 Mike_Finger@atk.com)
  *
  * The functions in this header file that are the original work of Mike Finger.
  *
@@ -19,12 +19,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include <libs/Picture.h>
@@ -38,7 +38,7 @@ typedef struct button
   char *truncate_title;
   int up, needsupdate, tw, set, truncatewidth;
   struct button *next;
-  Picture p;
+  FvwmPicture p;
   int reliefwidth;
   long desk;
   Bool is_sticky;
@@ -54,18 +54,18 @@ typedef struct
 } ButtonArray;
 
 /* Function Prototypes */
-extern Button *ButtonNew(char *title, Picture *p, int up);
+extern Button *ButtonNew(char *title, FvwmPicture *p, int up);
 extern void InitArray(ButtonArray *array,int x,int y,int w,int h,int rw);
 extern void UpdateArray(ButtonArray *array,int w);
-extern int AddButton(ButtonArray *array, char *title, Picture *p,int up);
+extern int AddButton(ButtonArray *array, char *title, FvwmPicture *p,int up);
 extern int UpdateButton(ButtonArray *array, int butnum, char *title, int up);
 extern void UpdateButtonIconified(
     ButtonArray *array, int butnum, int iconified);
-extern void RadioButton(ButtonArray *array, int butnum);
+extern void RadioButton(ButtonArray *array, int butnum, int butnumpressed);
 extern void ReorderButtons(ButtonArray *array, int butnum, int FlipFocus);
-extern int UpdateButtonDeskFlags(ButtonArray *array, int butnum, long desk, 
+extern int UpdateButtonDeskFlags(ButtonArray *array, int butnum, long desk,
 				 int is_sticky, int skip);
-extern int UpdateButtonPicture(ButtonArray *array, int butnum, Picture *p);
+extern int UpdateButtonPicture(ButtonArray *array, int butnum, FvwmPicture *p);
 extern int UpdateButtonSet(ButtonArray *array, int butnum, int set);
 extern void RemoveButton(ButtonArray *array, int butnum);
 extern Button *find_n(ButtonArray *array, int n);
@@ -78,8 +78,6 @@ extern void SwitchButton(ButtonArray *array,int butnum);
 extern int WhichButton(ButtonArray *array,int x, int y);
 extern char *ButtonName(ButtonArray *array, int butnum);
 extern void PrintButtons(ButtonArray *array);
-#ifdef MINI_ICONS
-extern Picture *ButtonPicture(ButtonArray *array, int butnum);
-#endif
+extern FvwmPicture *ButtonPicture(ButtonArray *array, int butnum);
 extern int IsButtonVisible(Button *btn);
 extern int IsButtonIndexVisible(ButtonArray *array, int butnum);
