@@ -1,7 +1,7 @@
 /* FvwmWinList Module for Fvwm.
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
- *                               Mike_Finger@atk.com)
+ *				 Mike_Finger@atk.com)
  *
  * The functions in this source file that are the original work of Mike Finger.
  *
@@ -19,12 +19,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 /* Structure definitions */
@@ -49,7 +49,7 @@ extern void ReorderList(List *list, long id, long FlipFocus);
 
 extern void AddItem(List *list, ConfigWinPacket *cfgpacket);
 extern int FindItem(List *list, long id);
-extern int FindItemDesk(List *list, long id, long desk);
+extern int FindItemVisible(List *list, long id);
 extern long ItemDesk(List *list, long id);
 extern int UpdateItemName(List *list, long id, char *string);
 extern int UpdateItemDesk(List *list, ConfigWinPacket *cfgpacket);
@@ -61,11 +61,10 @@ extern void PrintList(List *list);
 extern char *ItemName(List *list, int n);
 
 extern Item *ItemFlags(List *list, long id );
-extern int IsItemSticky(List *list, long id);
-extern int IsItemIconSuppressed(List *list, long id);
-extern int IsItemSkipWindowList(List *list, long id);
 
 extern int ItemCount(List *list);
-extern int ItemCountDesk(List *list, long desk);
+extern int ItemCountVisible(List *list);
 extern long ItemID(List *list, int n);
 extern void CopyItem(List *dest,List *source,int n);
+extern int IsItemVisible(Item *temp);
+extern int IsItemIndexVisible(List *list,int n);
