@@ -1,7 +1,7 @@
 /* FvwmWinList Module for Fvwm.
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
- *                               Mike_Finger@atk.com)
+ *				 Mike_Finger@atk.com)
  *
  * The author makes not guarantees or warantees, either express or
  * implied.  Feel free to use any contained here for any purpose, as long
@@ -25,44 +25,17 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
  */
 
 #include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <ctype.h>
-#include <string.h>
-#include <sys/time.h>
 #include "libs/fvwmlib.h"
 
-extern char *Module;
-
-/******************************************************************************
-  saferealloc - safely reallocate memory or exit if fails. (Doesn't work right)
-  (No kidding! Try it now ...)
-******************************************************************************/
-char *saferealloc(char *ptr, size_t length)
-{
-char *newptr;
-
-  if(length <=0) length=1;
-
-  /* If ptr is NULL then realloc does a malloc */
-  newptr=realloc(ptr,length);
-    if (newptr == (char *)0) {
-      fprintf(stderr,"%s:realloc failed",Module);
-      exit(1);
-    }
-  return newptr;
-}
-
 void UpdateString(char **string,const char *value)
 {
   if (value==NULL) return;
